( function ( $ ) {
	"use strict";

	// Form Builder JS.
	var mcp_builder = {

		// Defaults
		default_state: 	$( '.save_form' ).find( 'span' ).html(),
		save_btn: 		$( '.save_form' ).find( 'span' ),
		btn:			$( '.save_form' ),
		state:			$( '.mcp-bld-topbar span.description' ),
		hidden_row:		$( '.mcp-bld-row.hidden' ),
		new_row:		$( '.mcp-bld-new' ),
		active:			null,
		autosave:		1,
		active_field:	null,
		active_row:     null,

		// Get form data
		getdata: function() {

			// Data objects
			var data = [];

			// Fields
			data['fields'] = [];
			$( '.mcp-bld-col .mcp-bld-elem:visible' ).each( function() {
				var thisdata = {};
				var that = $( this );
				$.each( memberchimp_admin.metakeys, function( index, key ) {
					var attribute = that.attr( 'data-' + key );
					if ( attribute ) {
						thisdata[ key ] = attribute;
					}
				} );
				data.fields.push( {
					'data'	 : thisdata,
					'row' 	 : $( this ).parents( '.mcp-bld-row' ).index( '.mcp-bld-row' ),
					'col'	 : $( this ).parents( '.mcp-bld-col' ).index() + 1
				} );
			} );

			// Rows data
			data['rows'] = [];
			$( '.mcp-bld-row:not(.hidden)' ).each( function() {
				data.rows.push( {
					'index' : $( this ).index( '.mcp-bld-row' ),
					'title' : $( this ).find( '.mcp-bld-label' ).html(),
				} );
			} );

			// Columns
			data['cols'] = [];
			data.cols.push( { count: 0, layout: 0 } );
			$( '.mcp-bld-row:not(.hidden)' ).each( function() {
				var size = [];
				$( this ).find( '.mcp-bld-col' ).each( function() {
					size.push( $( this ).getsize() );
				} );
				data.cols.push( {
					'count'  : $( this ).find( '.mcp-bld-col' ).length,
					'layout' : size
				} );
			} );

			// Global
			data = $.extend( {
				id: 		this.btn.attr( 'data-id' ),
				action: 	'memberchimp_save_form',
				security: 	memberchimp_admin.nonces.save_form,
				row_count:	$( '.mcp-bld-row:not(.hidden)' ).length
			}, data );

			return data;
		},

		// Init
		freshstart: function() {
			if ( $( '.mcp-bld-row' ).length == 0 ) {
				return true;
			}

			if ( this.autosave ) {
				this.btn.hide();
			}

			if ( $( '.mcp-bld-row:not(.hidden)' ).length == 0 ) {
				var $new_row = this.hidden_row.clone().insertBefore( this.new_row ).show().removeClass( 'hidden' ).append( '<div class="mcp-clear"></div>' );
				$new_row.find( '.mcp-bld-elems' ).empty();
			}
		},

		// Add row
		add_row: function() {
			var $new_row = this.hidden_row.clone().insertBefore( this.new_row ).show().removeClass( 'hidden' ).append( '<div class="mcp-clear"></div>' );
			$new_row.find( '.mcp-bld-elems' ).empty();
			this.sortables();
			this.ready_save();
		},

		// Duplicate row
		duplicate_row: function( el ) {
			var $dup_row = el.clone().insertAfter( el );
			this.sortables();
			this.ready_save();
		},

		// Delete row
		delete_row: function( el ) {
			el.remove();
			this.ready_save();
		},

		// Duplicate field
		duplicate_field: function( el ) {
			var $dup_field = el.clone().insertAfter( el );
			this.sortables();
			this.ready_save();
		},

		// Delete element
		delete_field: function( el ) {
			el.remove();
			this.ready_save();
		},

		// Insert element
		insert: function( el ) {

			var placeholder = $( '.mcp-bld-elem.hidden:first' );
			var $e = placeholder.clone().appendTo( this.active );
			var icon = el.attr( 'data-icon' ) ? el.attr( 'data-icon' ) : '';

			$e.html( $e.html().replace( /{label}/i, el.html() ) );
			$e.html( $e.html().replace( /{key}/i, el.attr( 'data-key' ) ) );

			if ( icon ) {
				$e.find( '.mcp-bld-icon svg use' ).attr( 'xlink:href', memberchimp_admin.svg + icon );
			}

			$.each( el.data(), function ( name, value ) {
				$e.attr( 'data-' + name, value );
			} );

			$e.show().removeClass( 'hidden' );

			this.sortables();
			this.ready_save();
		},

		// Sortables
		sortables: function() {
			// Reorder elements.
			$( '.mcp-bld-elems' ).sortable({
				connectWith: '.mcp-bld-elems',
				handle:	'.mcp-move-field',
				placeholder: 'mcp-placeholder',
				tolerance: 'pointer',
				appendTo: $( 'body' ),
				start: function( event, ui ) {
					ui.placeholder.height( ( ui.item.height() - 2 ) );
				},
				update: function( event, ui ) {
					mcp_builder.ready_save();
				}
			});

			// Reorder rows.
			$( '#memberchimp-form-builder .inside' ).sortable({
				items: '> .mcp-bld-row',
				axis: 'y',
				handle:	'.mcp-move-row',
				placeholder: 'mcp-placeholder-row',
				tolerance: 'pointer',
				appendTo: $( 'body' ),
				start: function( event, ui ) {
					ui.placeholder.height( ( ui.item.height() - 2 ) );
				},
				update: function( event, ui ) {
					mcp_builder.ready_save();
				}
			});
		},

		// Toggle
		toggle: function( el ) {
			if ( el.attr( 'data-toggled' ) == 1 ) {
				el.attr( 'data-toggled', 0 ).find( '.mcp-bld-col, .mcp-bld-add, .mcp-bld-bar' ).show();
				el.find( '.mcp-bld-cols' ).height( 'auto' );
				el.find( '.mcp-toggle-row svg use' ).attr( 'xlink:href', memberchimp_admin.svg + 'chevron-up' );
			} else {
				el.attr( 'data-toggled', 1 ).find( '.mcp-bld-col, .mcp-bld-add, .mcp-bld-bar' ).hide();
				el.find( '.mcp-bld-cols' ).height( 20 );
				el.find( '.mcp-toggle-row svg use' ).attr( 'xlink:href', memberchimp_admin.svg + 'chevron-down' );
			}
		},

		// Ready to save
		ready_save: function() {
			$.modal.close();
			if ( this.autosave ) {
				this.save();
			} else {
				this.btn.removeClass( 'disabled' );
			}
		},

		// Saving in progress
		saving: function() {
			this.save_btn.html( memberchimp_admin.states.saving_changes ).parent().addClass( 'disabled' );
			this.state.html( '<span class="spinner"></span>' + memberchimp_admin.states.saving_changes );
			$( '#publish' ).attr( 'disabled', 'disabled' );
		},

		// Saved
		saved: function() {
			this.state.empty();
			this.save_btn.html( this.default_state );
			$( '#publish' ).removeAttr( 'disabled' );
		},

		// Save form
		save: function() {
			this.saving();
			$.ajax( {
				url: ajaxurl,
				data: this.getdata(),
				dataType: 'json',
				type: 'post',
				context: this,
				success: function() {
					setTimeout( () => { this.saved(); }, 1000 );
				}
			} );
		},

		// Add field
		add_field: function( el ) {
			var html = el.html(),
				data = $( '#mcp-add-field :input' ).serialize();

			el.addClass( 'disabled' ).html( memberchimp_admin.states.saving_changes );

			$.ajax( {
				url: ajaxurl,
				data: data + '&action=memberchimp_add_field&security=' + memberchimp_admin.nonces.add_field,
				dataType: 'json',
				type: 'post',
				context: this,
				success: function( res ) {
					el.removeClass( 'disabled' ).html( html );
					if ( res.errors ) {
						$( 'span.error' ).remove();
						$( ':input' ).removeClass( 'error' );
						$.each( res.errors, function(key, error) {
							$( '#' + key ).addClass( 'error' ).parents( 'fieldset' ).append( '<span class="error">' + error + '</span>' );
							$( 'span.error' ).animate( { 'opacity' : 1, 'top' : '0' }, 250 );
						} );
					} else {
						this.insert( $( res.data ) );
					}
				}
			} );
		},

		// Clears modal settings.
		clear_modal_settings: function( el ) {
			var m = $( '#mcp-add-field' );

			// Change heading.
			m.find( 'h3' ).html( memberchimp_admin.modal.creating );

			// Unlock key.
			m.find( '#key' ).removeAttr( 'disabled' );

			// Change buttons.
			m.find( '.button-primary' ).addClass( 'add_field' ).removeClass( 'save_field' ).html( memberchimp_admin.modal.create_button );
			m.find( '.button-secondary' ).attr( 'rel', 'modal:open' );

			// Clear fields as much as we can.
			m.find( 'input[type=text], textarea' ).val( '' );
			m.find( 'select' ).each( function() {
				$( this )[0].selectize.setValue( '', true );
			} );

			// Set the field type.
			m.find( '#type' )[0].selectize.setValue( el.attr( 'data-type' ), true );	
		},

		// Edit row.
		edit_row: function( el ) {
			this.active_row = el;
			var m = $( '#mcp-edit-row' );
			m.find( '#row_title' ).val( el.find( '.mcp-bld-label:first' ).html() );
		},

		// Save row.
		save_row: function( el ) {
			var m = $( '#mcp-edit-row' );
			var title = m.find( '#row_title' ).val();
			if ( title ) {
				el.find( '.mcp-bld-label:first' ).html( title );
			} else {
				el.find( '.mcp-bld-label:first' ).empty();
			}
			this.sortables();
			this.ready_save();
		},

		// Edit field.
		edit_field: function( el ) {
			this.active_field = el;
			this.add_modal_settings( el );
		},

		// Add settings to field modal.
		add_modal_settings: function( el ) {
			var m = $( '#mcp-add-field' );

			// Change heading.
			m.find( 'h3' ).html( memberchimp_admin.modal.editing.replace( '{field}', el.attr( 'data-label' ) ) );

			// Lock key.
			m.find( '#key' ).attr( 'disabled', 'disabled' );

			// Change buttons.
			m.find( '.button-primary' ).removeClass( 'add_field' ).addClass( 'save_field' ).html( memberchimp_admin.modal.save_button );
			m.find( '.button-secondary' ).attr( 'rel', 'modal:close' );

			// loop through each data attribute and set the option in field settings modal.
			$.each( memberchimp_admin.metakeys, function( index, key ) {
				var input = m.find( '#' + key );
				var value = el.attr( 'data-' + key );
				if ( input.length ) {
					var type = input.parents( 'fieldset' ).attr( 'data-type' );
					if ( type == 'select' ) {
						if ( input.prop('multiple') ) {
							if ( value ) {
								var array = value.split(',');
								input[0].selectize.setValue( array, true );
							}
						} else {
							input[0].selectize.setValue( value, true );
						}
					} else if ( type == 'switch' ) {
						if ( value == 1 ) {
							input.parents( 'fieldset' ).find( '.mcp-toggle' ).toggles( true );	
						} else {
							input.parents( 'fieldset' ).find( '.mcp-toggle' ).toggles( false );	
						}
					} else if ( type == 'textarea' ) {
						if ( value ) {
							input.val( value.replace( /\+/g, '\n' ) );
						} else {
							input.val( '' );
						}
					} else {
						input.val( value );
					}
				}
			} );
		},

		// Save field.
		save_field: function( el ) {
			this.save_modal_settings( el );
			this.sortables();
			this.ready_save();
		},

		// Save settings from field modal.
		save_modal_settings: function( el ) {
			var m = $( '#mcp-add-field' );
			$.each( memberchimp_admin.metakeys, function( index, key ) {
				var input = m.find( '#' + key );
				var value = '';
				if ( input.length ) {
					var type = input.parents( 'fieldset' ).attr( 'data-type' );
					if ( type == 'switch' ) {
						value = ( input.parents( 'fieldset' ).find( ':checkbox' ).is( ':checked' ) ) ? 1 : '';
					} else {
						value = input.val();
					}
					if ( key == 'label' ) {
						el.find( '.mcp-bld-label' ).html( value );
					}
					if ( key == 'icon' ) {
						if ( value ) {
							el.find( '.mcp-bld-icon svg use' ).attr( 'xlink:href', memberchimp_admin.svg + value );
						} else {
							el.find( '.mcp-bld-icon svg use' ).attr( 'xlink:href', memberchimp_admin.svg + '' );
						}
					}
					if ( type == 'textarea' ) {
						value = value.replace( /\n/g, '+' );
					}
					el.attr( 'data-' + key, value );
				}
			} );
		}

	}

	// Init builder
	$( document.body ).on( 'mcp-init-builder', function() {
		mcp_builder.freshstart();
		mcp_builder.sortables();
	} ).trigger( 'mcp-init-builder' );

	// Document triggers.
	$( document.body )

		// Delete field.
		.on( 'click', '.mcp-delete-field', function() {
			mcp_builder.delete_field( $( this ).parents( '.mcp-bld-elem' ) );
		} )

		// Delete row.
		.on( 'click', '.mcp-delete-row', function() {
			mcp_builder.delete_row( $( this ).parents( '.mcp-bld-row' ) );
		} )

		// Add row.
		.on( 'click', '.mcp-add-row', function() {
			mcp_builder.add_row();
		} )

		// Insert field.
		.on( 'click', '.insert_field', function() {
			mcp_builder.insert( $( this ) );
		} )

		// Add element.
		.on( 'click', '.mcp-add-element', function() {
			mcp_builder.active = $( this ).parents( '.mcp-bld-col' ).find( '.mcp-bld-elems' );
		} )

		// Toggle row.
		.on( 'click', '.mcp-toggle-row', function() {
			mcp_builder.toggle( $( this ).parents( '.mcp-bld-row' ) );
		} )

		// Duplicate row.
		.on( 'click', '.mcp-duplicate-row', function() {
			mcp_builder.duplicate_row( $( this ).parents( '.mcp-bld-row' ) );
		} )

		// Duplicate field.
		.on( 'click', '.mcp-duplicate-field', function() {
			mcp_builder.duplicate_field( $( this ).parents( '.mcp-bld-elem' ) );
		} )

		// Save form.
		.on( 'click', '.save_form:not(.disabled)', function() {
			mcp_builder.save();
		} )

		// Ajax save field.
		.on( 'click', '.add_field:not(.disabled)', function() {
			mcp_builder.add_field( $( this ) );
		} )

		// New field.
		.on( 'click', '.new_field', function() {
			mcp_builder.clear_modal_settings( $( this ) );
		} )

		// Edit field.
		.on( 'click', '.mcp-edit-field', function() {
			mcp_builder.edit_field( $( this ).parents( '.mcp-bld-elem' ) );
		} )

		// Save field.
		.on( 'click', '.save_field', function() {
			mcp_builder.save_field( mcp_builder.active_field );
		} )

		// Edit row.
		.on( 'click', '.mcp-edit-row', function() {
			mcp_builder.edit_row( $( this ).parents( '.mcp-bld-row' ) );
		} )

		// Save row.
		.on( 'click', '.save_row', function() {
			mcp_builder.save_row( mcp_builder.active_row );
		} )

		// Before field modal is open.
		.on( $.modal.BEFORE_OPEN, '#mcp-add-field', function(e, modal) {
			$( '.modal span.error' ).remove();
			$( '.modal :input' ).removeClass( 'error' );
			$( '.modal div.panel-wrap' ).each( function() {
				$( this ).find( 'ul.mcp-tabs li' ).eq( 0 ).find( 'a' ).click();
			});
		} )

		// After field modal is open.
		.on( $.modal.OPEN, '#mcp-add-field', function(e, modal) {
			$( document.body ).trigger( 'mcp-init-fields' );
		} );

} )(jQuery);