( function ( $ ) {
	"use strict";

	// Tabbed Panels
	$( document.body ).on( 'mcp-init-tabbed-panels', function() {
		$( 'ul.mcp-tabs' ).show();
		$( document.body ).on( 'click', 'ul.mcp-tabs a', function( event ) {
			event.preventDefault();
			var panel_wrap = $( this ).closest( 'div.panel-wrap' );
			$( 'ul.mcp-tabs li', panel_wrap ).removeClass( 'active' );
			$( this ).parent().addClass( 'active' );
			$( 'div.panel', panel_wrap ).hide();
			$( $( this ).attr( 'href' ) ).show();
			$( document.body ).trigger( 'mcp-init-fields' );
		} );
		$( 'div.panel-wrap' ).each( function() {
			$( this ).find( 'ul.mcp-tabs li' ).eq( 0 ).find( 'a' ).click();
		} );
	} ).trigger( 'mcp-init-tabbed-panels' );

	// Conditional fields
	$( document.body ).on( 'mcp-init-fields', function() {
		$( '.memberchimp_options_panel:visible [class*=show_if_]' ).conditional();
	} ).trigger( 'mcp-init-fields' );

	// Toggles
	$( document.body ).on( 'mcp-init-toggles', function() {
		$( '.mcp-toggle' ).each( function() {
			var cb = $( this ).parents( 'fieldset' ).find( 'input[type=checkbox]' );
			$( this ).toggles( {
				'width': 60,
				'height': 20,
				'text': {
					on: memberchimp_admin.yes,
					off: memberchimp_admin.no
				},
				'checkbox': cb
			} ).on( 'toggle', function(e, active) {
				$( document.body ).trigger( 'mcp-init-fields' );
			} );
		} )
	} ).trigger( 'mcp-init-toggles' );

	// Tooltips
	$( document.body ).on( 'mcp-init-tooltips', function() {
		$( '.memberchimp-help-tip, .tips' ).tipTip( {
			'attribute': 'data-tip',
			'fadeIn': 50,
			'fadeOut': 50,
			'delay': 200
		} );

		$( '.mcp-top-tips' ).tipTip( {
			'attribute': 'data-tip',
			'fadeIn': 50,
			'fadeOut': 50,
			'delay': 200,
			'defaultPosition': 'top',
		} );
	} ).trigger( 'mcp-init-tooltips' );

	// Selectize
	$( document.body ).on( 'mcp-init-selects', function() {
		$( '.mcp-select' ).selectize( {
			allowEmptyOption: true,
		} );

		$( '.mcp-select-multi' ).selectize( {
			plugins: [ 'remove_button', 'drag_drop' ],
			delimiter: ',',
			persist: false,
			create: function( input ) {
				return {
					value: input,
					text: input
				}
			}
		} );

		$( '.mcp-user-search' ).selectize( {
			valueField: 'id',
			labelField: 'name',
			searchField: 'name',
			options: [],
			create: false,
			render: {
				option: function (item, escape) {
					return '<div class="option">' + escape( item.name ) + ' (#' + escape( item.id ) + ' &ndash; ' + escape( item.email ) + ')</div>';
				}
			},
			load: function( query, callback ) {
				if ( ! query.length ) return callback();
				$.ajax( {
					url: ajaxurl,
					type: 'get',
					dataType: 'json',
					data: {
						keyword: 	query,
						action: 	'memberchimp_json_search_users',
						security: 	memberchimp_admin.nonces.json_search_users
					},
					error: function() {
						callback();
					},
					success: function( res ) {
						console.log( res );
						callback( res );
					}
				} );
			}
		} );
	} ).trigger( 'mcp-init-selects' );

	// Show additional title action if required
	$( document.body ).on( 'mcp-init-action-button', function() {
		var el = $( '.mcp-page-title-action' );
		$( '.page-title-action' ).after( el );
		el.show();
	} ).trigger( 'mcp-init-action-button' );

	// Document triggers.
	$( document.body )

		// See more or less.
		.on( 'click', '.mcp-togglemore', function( e ) {
			e.preventDefault();
			var el = $( this ),
				contain = el.parents( 'td' );
			if ( contain.find( 'span.hidden' ).length ) {
				el.appendTo( contain ).html( memberchimp_admin.states.show_less );
				contain.find( 'span.hidden' ).removeClass( 'hidden' ).addClass( 'js-temp' );
			} else {
				el.html( memberchimp_admin.states.show_more );
				contain.find( 'span.js-temp' ).addClass( 'hidden' ).removeClass( 'js-temp' );
			}
		} )

		// No links here.
		.on( 'click', ".memberchimp_options_panel a[href=#], .mcp-bld-topbar a[href=#], .mcp-bld-row a[href=#], .mcp-bld-new a[href=#], .modal a[href=#], a[class^='duplicate_'].disabled", function(e) {
			e.preventDefault();
		} )

		// Listen to checkbox change.
		.on( 'change', '.options_group input[type=checkbox]', function() {
			if ( $( this ).is( ':checked' ) ) {
				$( this ).parents( '.form-field' ).find( '.mcp-toggle:not(.disabled)' ).toggles( true );
			} else {
				$( this ).parents( '.form-field' ).find( '.mcp-toggle:not(.disabled)' ).toggles( false );
			}
		} )

		// Listen to select change.
		.on( 'change', '.options_group select', function() {
			$( document.body ).trigger( 'mcp-init-fields' );
		} )

		// Create items.
		.on( 'click', "a[href^='#mcp-create-']", function( e ) {
			e.preventDefault();

			var el    = $( this ),
				type  = el.attr( 'href' ).split( '#mcp-create-' )[1],
				label,
				nonce;

			if ( type == 'forms' ) {
				label = memberchimp_admin.states.create_forms;
				nonce = memberchimp_admin.nonces.create_forms;
			} else if ( type == 'fields' ) {
				label = memberchimp_admin.states.create_fields;
				nonce = memberchimp_admin.nonces.create_fields;
			} else if ( type == 'roles' ) {
				label = memberchimp_admin.states.create_roles;
				nonce = memberchimp_admin.nonces.create_roles;
			} else if ( type == 'memberlists' ) {
				label = memberchimp_admin.states.create_memberlists;
				nonce = memberchimp_admin.nonces.create_memberlists;
			}

			el.addClass( 'disabled' ).html( label );

			$.post( ajaxurl, { action: 'memberchimp_create_' + type, security: nonce }, function( response ) {
				el.html( memberchimp_admin.states.done_redirect );
				if ( response.redirect ) {
					window.location.href = response.redirect;
				} else {
					location.reload();
				}
			} );

		} )

		// Duplicate item.
		.on( 'click', "a[class^='duplicate_']:not(.disabled)", function( e ) {
			e.preventDefault();

			var el 		= $( this ),
				data 	= { action: 'memberchimp_' + el.attr( 'class' ), security: el.getparam( '_wpnonce' ), id: el.getparam( 'post' ) };

			el.addClass( 'disabled' ).html( memberchimp_admin.states.duplicating );

			$.post( ajaxurl, data, function(response) { location.reload(); } );

		} );

} )(jQuery);