(function($) {
	"use strict";

	// Tooltips
	$( document.body ).on( 'mcp-init-tooltips', function() {
		$( '.memberchimp .tips, .memberchimp-help-tip' ).each( function() {
			var tip = $( this );
			tip.tipTip( {
				'attribute': 'data-tip',
				'defaultPosition': 'top',
				'edgeOffset': 3,
				'enter' : function() {
					$( '#tiptip_holder' ).css( { opacity: 1 } );
				},
				'delay' : 200
			} );
		} );

		$( '.mcp-navbar-tip' ).each( function() {
			var tip = $( this );
			tip.tipTip( {
				'attribute': 'data-tip',
				'defaultPosition': 'bottom',
				'edgeOffset': 10,
				'enter' : function() {
					$( '#tiptip_holder' ).css( { opacity: 1 } );
				},
				'delay' : 200
			} );
		} );

		$( '.mcp-tips' ).tipTip( {
			'attribute': 'data-tip',
			'edgeOffset': 5,
			'defaultPosition': 'top',
			'enter' : function() {
				$( '#tiptip_holder' ).css( { opacity: 1 } );
			},
			'delay' : 200
		} );
	} ).trigger( 'mcp-init-tooltips' );

	// Selectize
	$( document.body ).on( 'mcp-init-selects', function() {
		$( '.mcp-select' ).selectize( {
			allowEmptyOption: true,
			create: true,
			dropdownParent: 'body'
		} );
	} ).trigger( 'mcp-init-selects' );

	// Toggles
	$( document.body ).on( 'mcp-init-toggles', function() {
		$( '.mcp-toggle' ).each( function() {
			var cb = $( this ).parents( 'fieldset' ).find( 'input:checkbox' ).attr( 'id' );
			$( this ).toggles( {
				'width': 60,
				'height': 20,
				'text': {
					on: memberchimp_params.yes,
					off: memberchimp_params.no
				},
				'checkbox' : $( '#' + cb )
			} );
		} );
	} ).trigger( 'mcp-init-toggles' );

	// Star rating.
	$( document.body ).on( 'mcp-init-rating', function() {
		$( '.mcp-star' ).each( function() {
			var mcp_rate = $( this );
			var args = {
				starType: 'i',
				number: 5,
				space: false,
				scoreName: mcp_rate.attr( 'data-key' ),
				readOnly: mcp_rate.attr( 'data-readonly' ),
				mouseover: function(score, evt) {
					var hint = mcp_rate.parents( 'fieldset' ).find( '.mcp-star-hint' );
					if ( hint.length == 0 ) {
						return;
					}
					hint.html( $( evt.target ).attr( 'data-hint' ) );
				},
				mouseout: function(score, evt) {
					var hint = mcp_rate.parents( 'fieldset' ).find( '.mcp-star-hint' );
					if ( hint.length == 0 ) {
						return;
					}
					if ( ! score ) {
						hint.html( '' );
					} else {
						hint.html( mcp_rate.find( 'i[data-alt=' + score + ']' ).attr( 'data-hint' ) );
					}
				}	
			}

			if ( mcp_rate.attr( 'data-ratings' ) ) {
				args.hints = mcp_rate.attr( 'data-ratings' ).split( ',' );
			}

			mcp_rate.raty( args );
		} );
	} ).trigger( 'mcp-init-rating' );

	// Set focus on password field when user is editing password.
	$( document.body ).on( 'mcp-init-focus', function() {
		$( '.memberchimp-edit-password' ).find( ':input[value=""]:enabled:visible:first' ).focus();
	} ).trigger( 'mcp-init-focus' );

	// Sets initial global message.
	$( document.body ).on( 'mcp-init-message', function() {
		var $saved;
		$( document.body ).append( '<div class="mcp-message"></div>' );
		$saved = $( document ).mcp_param( 'saved' );
		if ( $saved && $( 'div[role=alert]' ).length == 0 ) {
			$( document ).mcp_message( memberchimp_params.saved[ $saved ] );
		}
	} ).trigger( 'mcp-init-message' );

	// Get pasted code from clipboard.
	$( document.body ).on( 'paste', '.memberchimp-code-input input', function( event ) {
		var data = event.originalEvent.clipboardData.getData( 'text' );
		var split = data.split( '-' );
		var number = split[0] + split[1];
		var number = number.replace( /[^0-9]/g, '' );
		if ( number.length == 6 && /^\+?(0|[1-9]\d*)$/.test( parseInt( number ) ) ) {
			$( '.memberchimp-code input:eq(0)' ).val( number.charAt( 0 ) );
			$( '.memberchimp-code input:eq(1)' ).val( number.charAt( 1 ) );
			$( '.memberchimp-code input:eq(2)' ).val( number.charAt( 2 ) );
			$( '.memberchimp-code input:eq(3)' ).val( number.charAt( 3 ) );
			$( '.memberchimp-code input:eq(4)' ).val( number.charAt( 4 ) );
			$( '.memberchimp-code input:eq(5)' ).val( number.charAt( 5 ) );
			mcp_check_confirmation_code();
		}
	} );

	// A function to detect if confirmation code was filled.
	function mcp_validate_confirmation_code() {
		var isValid = true;
		$( '.memberchimp-code-input input' ).each( function() {
			if ( $( this ).val() === '' )
				isValid = false;
		} );
		return isValid;
	}

	// Get the confirmation code input.
	function mcp_get_confirmation_code() {
		var code = '';
		$( '.memberchimp-code input' ).each( function () {
			code = code + $( this ).val();
		} );
		if ( code == mcp_confirmation_code ) {
			return false;
		} else {
			mcp_confirmation_code = code;
		}
		return code;
	}

	// If confirmation code is filled, submit the ajax request to check it.
	$( '.memberchimp-code-input input' ).on( 'keyup, blur', function() {
		if ( mcp_validate_confirmation_code() ) {
			mcp_check_confirmation_code();
		}
	} );

	// Check the confirmation code with AJAX.
	function mcp_check_confirmation_code() {
		if ( mcp_get_confirmation_code() == false ) {
			return false;
		}
		var container = $( '.memberchimp-code' ),
			cb = $( '.memberchimp-code-callback' ),
			data = {
				user_id: container.attr( 'data-user_id' ),
				confirmation_code: mcp_confirmation_code,
				action: 'memberchimp_check_confirmation_code',
				security: memberchimp_params.nonces.confirmation_code
			};

		cb.find( '.memberchimp-info-area' ).hide();
		cb.find( '.memberchimp-info' ).css( { 'display' : 'inline-block' } );
		cb.find( '.memberchimp-error' ).hide();

		$.post( memberchimp_params.ajaxurl, data, function( response ) {
			if ( response.error ) {
				cb.find( '.memberchimp-info' ).hide();
				cb.find( '.memberchimp-error' ).css( { 'display' : 'inline-block' } );
			} else {
				cb.find( 'span' ).hide();
				window.location.href = response.redirect;
			}
		} );
	}

	// Clicks in the body to hide dropdown.
	$( document.body ).on( 'click', function( event ) {
		var visible_dropdown = $( '.mcp-dropdown:visible' ),
			hide_dropdown = true;

		if ( $( event.target ).hasClass( 'blocker' ) || $( '.blocker' ).has( event.target ).length > 0 ) {
			if ( visible_dropdown.parents( '.modal' ).length == 0 ) {
				hide_dropdown = false;
			}
		}

		if ( hide_dropdown ) {
			$( document ).mcp_hide_menu();
		}
	} );

	// Body events
	$( document.body )

		// No href, assume ajax action and do not jump.
		.on( 'click', '.memberchimp a[href=#], .modal a[href=#]', function( event ) {
			event.preventDefault();
		} )

		// Make the icon trigger input field focus.
		.on( 'click', '.mcp-icon', function( event ) {
			$( this ).parents( 'fieldset' ).find( 'label' ).trigger( 'click' );
		} )

		// Opens / Init a dropdown menu.
		.on( 'click', '.mcp-dropdown-init', function( event ) {
			event.stopPropagation();
			$( document ).mcp_open_menu( $( this ).attr( 'rel' ), $( this ) );
		} )

		// To stop events inside the drop down menu.
		.on( 'click', '.mcp-dropdown', function( event ) {
			event.stopPropagation();
		} )

		// This hides any active drop down menu.
		.on( 'click', 'a[rel=mcp_dropdown_hide]', function() {
			$( document ).mcp_hide_menu();
		} )

		// Listens to checkbox changes.
		.on( 'change', '.memberchimp-field input[type=checkbox]', function() {
			if ( $( this ).is( ':checked' ) ) {
				$( this ).parents( 'fieldset' ).find( '.mcp-toggle' ).toggles( true );
			} else {
				$( this ).parents( 'fieldset' ).find( '.mcp-toggle' ).toggles( false );
			}
		} )

		// Auto-type username in Account page.
		.on( 'keyup', '.user_login_field input[type=text]', function() {
			var field = $( this ).parents( 'fieldset' );
			if ( field.find( '.mcp-ajax' ).length ) {
				field.find( '.mcp-ajax' ).html( $( this ).val() );
			}
		} )

		// Toggle password visibility.
		.on( 'click', '.mcp-pw-visible', function( event ) {
			$( this ).mcp_toggle_password();
		} )

		// Send form using anchor that act as submit.
		.on( 'click', 'a.memberchimp-button.main:not(.disabled,.mcp-crop-cover)', function( event ) {
			$( this ).parents( '.memberchimp' ).find( 'form' ).submit();
		} )

		// Form submit handler.
		.on( 'submit', '.memberchimp form', function( event ) {
			$( this ).mcp_form( event );
		} )

		// Fired when modal is opened.
		.on( $.modal.OPEN, '.modal', function( event, modal ) {

			// Add username to modal where possible.
			if ( mcp_username ) {
				$( event.target ).find( 'b' ).html( mcp_username );
				$( event.target ).find( 'a.memberchimp-button[data-user_id]' ).attr( 'data-user_id', mcp_user_id );
				$( document ).mcp_hide_menu();
			}
			$( event.target ).find( 'a.memberchimp-button:first:visible' ).focus();
		} )

		// Fired when modal is about to close.
		.on( $.modal.BEFORE_CLOSE, '.modal', function( event, modal ) {
			$( event.target ).find( 'a.memberchimp-button' ).removeClass( 'disabled' );
		} )

		// Open a modal.
		.on( 'click', '.mcp-modal-open', function() {
			var modal = '#' + $( this ).attr( 'rel' );

			if ( $( this ).attr( 'data-user' ) ) {
				mcp_username = $( this ).attr( 'data-user' );
				mcp_user_id = $( this ).attr( 'data-user_id' );
			}

			if ( $( this ).parent().hasClass( 'mcp-image' ) ) {
				mcp_image = $( this ).find( 'img' );
				if ( $( this ).parents( 'fieldset' ).find( 'label' ).length ) {
					mcp_image_title = $( this ).parents( 'fieldset' ).find( 'label' ).html();
				} else {
					mcp_image_title = $( this ).parents( '.memberchimp' ).find( '.memberchimp-profile-name a' ).html();
				}
			}

			$( modal ).modal();
		} )

		// Fire AJAX action.
		.on( 'click', '.mcp-ajax-action', function( event ) {
			var $this = $( this ),
				ajax = $this.attr( 'data-action' ),
				data = {
					user_id: $this.attr( 'data-user_id' ) ? $this.attr( 'data-user_id' ) : 0,
					action: 'memberchimp_' + ajax,
					security: memberchimp_params.nonces[ ajax ]
				};

			if ( $this.hasClass( 'mcp-hide-controls' ) ) {
				$this.parents( '.mcp-controls' ).remove();
			}

			$.post( memberchimp_params.ajaxurl, data, function( response ) {
				$( document ).mcp_after_ajax( response );
				if ( $this.attr( 'data-reload' ) === 'true' ) {
					location.reload();
				}
			} );
		} );

})(jQuery);