var $mcp_crop,
	$mcp_cover_crop;

(function($) {
	"use strict";

	// File inputs.
	$( '.mcp-fileinput' ).each( function() {
		var $input	 = $( this ),
			$label	 = $input.next( 'label' ),
			labelVal = $label.html();

		$input.on( 'change', function( event ) {
			var fileName = '';

			if( this.files && this.files.length > 1 ) {
				fileName = ( this.getAttribute( 'data-multiple-caption' ) || '' ).replace( '{count}', this.files.length );
			} else if ( event.target.value ) {
				fileName = event.target.value.split( '\\' ).pop();
			}

			if ( fileName ) {
				$label.find( 'span' ).html( fileName );
				$label.attr( 'title', fileName );
			} else {
				$label.html( labelVal );
				$label.removeAttr( 'title' );
			}
		} );

		// Firefox bug fix
		$input
		.on( 'focus', function(){ $input.addClass( 'has-focus' ); })
		.on( 'blur', function(){ $input.removeClass( 'has-focus' ); });
	} );

	// Body events
	$( document.body )

		// Add image to the modal.
		.on( $.modal.BEFORE_OPEN, '#mcp-modal-view-image', function( event, modal ) {
	
			$( event.target ).find( '.modal-background' ).css( {
				'background-image' : 'url( ' + mcp_image.attr( 'src' ) + ')',
			} ).html( mcp_image.clone() );

			$( event.target ).find( 'h3' ).html( mcp_image_title );
		} )

		// Init the avatar crop zone.
		.on( $.modal.BEFORE_OPEN, '#mcp-modal-photo', function( event, modal ) {
			$mcp_crop = $( '.mcp-cropper' ).croppie( {
				viewport: {
					width: 240,
					height: 240,
					type: 'circle'
				},
				boundary: {
					width: 300,
					height: 300
				}
			} );
		} )

		// Reset avatar and crop when modal is closed.
		.on( $.modal.BEFORE_CLOSE, '#mcp-modal-photo', function( event, modal ) {
			$( '.mcp-input-avatar' ).parent().trigger( 'reset' );
			$mcp_crop.croppie( 'destroy' );
		} )

		// A listener for avatar upload.
		.on( 'change', '.mcp-input-avatar', function( event ) {

			// Open the crop modal.
			$( '#mcp-modal-photo' ).modal();

			// Read file.
			var reader = new FileReader();
			reader.onload = function( event ) {
				$mcp_crop.croppie( 'bind', {
					url: event.target.result
				} ).then( function() {
					$mcp_crop.croppie( 'setZoom', '0' );
				} ).catch( function( e ) {
					if ( e.type == 'error' ) {
						$( '#mcp-modal-error' ).modal();
					}
				} );
			}
			reader.readAsDataURL( this.files[0] );

		} )

		// A listener for header photo upload.
		.on( 'change', '.mcp-input-cover', function( event ) {

			$( document ).mcp_hide_menu();

			$mcp_cover_crop = $( '.mcp-cover-cropper' ).croppie( {
				viewport: {
					width: '100%',
					height: '100%',
					type: 'square'
				},
				boundary: {
					width: '100%',
					height: '100%',
				}
			} );

			$( '.mcp-cover-cropper-holder' ).show();
			$( '.mcp-cover-cropper-actions' ).appendTo( $( '.mcp-cover-cropper-holder .cr-slider-wrap' ) ).find( '.memberchimp-button.main' ).focus();

			// Read file.
			var reader = new FileReader();
			reader.onload = function( event ) {
				$mcp_cover_crop.croppie( 'bind', {
					url: event.target.result
				} ).then( function() {
					$mcp_cover_crop.croppie( 'setZoom', '0' );
				} ).catch( function( e ) {
					if ( e.type == 'error' ) {
						$( document ).mcp_reset_cover();
						$( '#mcp-modal-error' ).modal();
					}
				} );
			}
			reader.readAsDataURL( this.files[0] );

		} )

		// Reset header photo.
		.on( 'click', '.mcp-cancel-cover', function( event ) {
			$( document ).mcp_reset_cover();
		} )

		// Saves the profile photo.
		.on( 'click', '.mcp-crop-avatar:not(.disabled)', function( event ) {
			$( document ).mcp_save_crop( event, $mcp_crop, 400, 400, 'save_avatar' );
		} )

		// Saves the cover photo.
		.on( 'click', '.mcp-crop-cover:not(.disabled)', function( event ) {
			$( document ).mcp_save_crop( event, $mcp_cover_crop, 1500, 555, 'save_cover' );
		} )

		// Fixes hover for upload button in dropdown menu.
		.on( 'mouseenter', '.mcp-dropdown-upload', function() {
			$( this ).addClass( 'mcp-dropdown-hover' );
		} ).on( 'mouseleave', '.mcp-dropdown-upload', function() {
			$( this ).removeClass( 'mcp-dropdown-hover' );
		} )

		// Open item permalinks.
		.on( 'click', '.mcp-item[data-permalink!=""]', function( event ) {
			var $perma = $( this ).attr( 'data-permalink' );
			window.location.href = $perma;
		} )

		// Clicking inside sublink to trigger main anchor link.
		.on( 'click', '.mcp-item-sublink', function( event ) {
			event.stopPropagation();
			var parentlink = $( this ).parents( '.mcp-item' ).find( 'a.mcp-item-head-anchor' );
			window.location.href = parentlink.attr( 'href' );
		} );

})(jQuery);