(function( $ ) {
	"use strict";

	/**
	 * Trigger different select box search based on content type.
	 */
	$( document.body ).on( 'change', '#item_content_type', function() {
		var type = $( this ).val();
		$( '.mcp-terms-search' ).addClass( 'mcp-select-hide' ).hide();
		$( '.selectize-control.mcp-terms-search.' + type ).show().removeClass( 'mcp-select-hide' );
	} );

	var APIView = Backbone.View.extend({
		/**
		 * Element
		 *
		 * @param {Object}
		 */
		el: $( '#drip-fields' ),

		/**
		 * Events
		 *
		 * @type {Object}
		 */
		events: {
			'click input#update_drip_rule': 'saveRule'
		},

		/**
		 * Initialize actions
		 */
		initialize: function(){
			_.bindAll( this, 'saveRule' );
		},

		/**
		 * Init jQuery.BlockUI
		 */
		block: function() {
			$( this.el ).block({
				message: null,
				overlayCSS: {
					background: '#fff',
					opacity: 0.6
				}
			});
		},

		/**
		 * Remove jQuery.BlockUI
		 */
		unblock: function() {
			$( this.el ).unblock();
		},

		/**
		 * Save using ajax
		 *
		 * @param {Object} e
		 */
		saveRule: function( e ) {
			e.preventDefault();

			var self = this;

			self.block();

			Backbone.ajax({
				method:   'POST',
				dataType: 'json',
				url:      memberchimp_admin_drip_content.ajax_url,
				data:     {
					action:       	'memberchimp_update_drip_content',
					security:     	memberchimp_admin_drip_content.update_drip_nonce,
					item_id:      	$( '#item_id', self.el ).val(),
					content_type: 	$( '#item_content_type', self.el ).val(),
					term_id: 		$( '#item_term_id_' + $( '#item_content_type', self.el ).val(), self.el ).val(),
					type: 			$( '#item_type', self.el ).val(),
					number: 		$( '#item_number', self.el ).val(),
					timeframe: 		$( '#item_timeframe', self.el ).val(),
					from_date: 		$( '#item_from_date', self.el ).val(),
					//to_date: 		$( '#item_to_date', self.el ).val(),
					role: 			$( '#item_role', self.el ).val(),
				},
				success: function( response ) {
					$( '.mcp-ajax-message', self.el ).remove();

					if ( response.success ) {
						var data = response.data;

						window.location.href = data.url;

					} else {
						$( 'h2, h3', self.el ).first().append( '<div class="mcp-ajax-message error"><p>' + response.data.message + '</p></div>' );
					}

					self.unblock();
				}
			});
		}
	});

	new APIView();

})( jQuery );