<?php
/**
 * Addon: Content Dripping
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Define MCDC_PLUGIN_FILE.
if ( ! defined( 'MCDC_PLUGIN_FILE' ) ) {
	define( 'MCDC_PLUGIN_FILE', __FILE__ );
}

/**
 * Main class.
 */
final class Memberchimp_Drip_Content {

	/**
	 * The single instance of the class.
	 */
	protected static $_instance = null;

	/**
	 * Main Instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->define_constants();
		$this->includes();
		$this->init_hooks();

		do_action( 'mcp_drip_loaded' );
	}

	/**
	 * Define Constants.
	 */
	public function define_constants() {
		mcp()->define( 'MCDC_ABSPATH', dirname( MCDC_PLUGIN_FILE ) . '/' );
		mcp()->define( 'MCDC_PLUGIN_BASENAME', plugin_basename( MCDC_PLUGIN_FILE ) );
	}

	/**
	 * Include required core files used in admin and on the frontend.
	 */
	public function includes() {

		/**
		 * Core classes.
		 */
		include_once MCDC_ABSPATH . 'includes/class-mcdc-ajax.php';

		if ( mcp()->is_request( 'admin' ) ) {
			include_once MCDC_ABSPATH . 'includes/admin/class-mcdc-admin.php';
		}

		// Front-end use only.
		if ( mcp()->is_request( 'frontend' ) ) {
			$this->frontend_includes();
		}

	}

	/**
	 * Hook into actions and filters.
	 */
	public function init_hooks() {
		if ( mcp()->is_request( 'frontend' ) ) {
			add_action( 'init', array( 'MCDC_Content_Dripping', 'init' ) );
		}
	}

	/**
	 * Include required frontend files.
	 */
	public function frontend_includes() {
		include_once MCDC_ABSPATH . 'includes/class-mcdc-dripping.php';
	}

	/**
	 * Get the plugin path.
	 */
	public function plugin_path() {
		return untrailingslashit( plugin_dir_path( MCDC_PLUGIN_FILE ) );
	}

	/**
	 * Get the plugin URL.
	 */
	public function plugin_url() {
		return untrailingslashit( plugin_dir_url( MCDC_PLUGIN_FILE ) );
	}

}

/**
 * Main instance.
 */
function mcp_drip() {
	return Memberchimp_Drip_Content::instance();
}

// Global for backwards compatibility.
$GLOBALS['mcp_drip'] = mcp_drip();