<?php
/**
 * Content dripping admin.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * MCDC_Admin_Dripping class.
 */
class MCDC_Admin_Dripping {

	/**
	 * Initialize the admin actions.
	 */
	public function __construct() {
		add_action( 'admin_init', array( $this, 'actions' ) );
		add_action( 'memberchimp_settings_page_init', array( $this, 'screen_option' ) );
		add_filter( 'memberchimp_save_settings_dripping', array( $this, 'allow_save_settings' ) );
	}

	/**
	 * Check if should allow save settings.
	 * This prevents "Your settings have been saved." notices on the table list.
	 */
	public function allow_save_settings( $allow ) {
		if ( ! isset( $_GET['create-rule'], $_GET['edit-rule'] ) ) {
			return false;
		}

		return $allow;
	}

	/**
	 * Check if is drip content settings page.
	 */
	private function is_settings_page() {
		return isset( $_GET['page'], $_GET['tab'], $_GET['section'] ) && 'mcp-settings' === $_GET['page'] && 'addons' === $_GET['tab'] && ( $_GET['section'] == 'drip' );
	}

	/**
	 * Page output.
	 */
	public static function page_output() {
		// Hide the save button.
		$GLOBALS['hide_save_button'] = true;

		if ( isset( $_GET['create-rule'] ) || isset( $_GET['edit-rule'] ) ) {
			$item_id = isset( $_GET['edit-rule'] ) ? absint( $_GET['edit-rule'] ) : 0;
			$item 	 = self::get_item( $item_id );

			if ( ! current_user_can( 'manage_memberchimp' ) ) {
				wp_die( esc_html__( 'You do not have permission to edit this.', 'memberchimp' ) );
			}

			include dirname( __FILE__ ) . '/views/html-drip-content-edit.php';
		} else {
			self::table_list_output();
		}
	}

	/**
	 * Add screen option.
	 */
	public function screen_option() {
		global $table_list;

		if ( ! isset( $_GET['create-rule'] ) && ! isset( $_GET['edit-rule'] ) && $this->is_settings_page() ) {
			$table_list = new MCDC_Admin_Dripping_Table_List();

			// Add screen option.
			add_screen_option(
				'per_page', array(
					'default' => 10,
					'option'  => 'memberchimp_items_per_page',
				)
			);
		}
	}

	/**
	 * Table list output.
	 */
	private static function table_list_output() {
		global $wpdb, $table_list;

		echo '<h2>' . esc_html__( 'Drip content', 'memberchimp' ) . ' <a href="' . esc_url( admin_url( 'admin.php?page=mcp-settings&tab=addons&section=drip&create-rule=1' ) ) . '" class="add-new-h2">' . esc_html__( 'Add Rule', 'memberchimp' ) . '</a></h2>';

		// Get the count.
		$count = $wpdb->get_var( "SELECT COUNT(item_id) FROM {$wpdb->prefix}memberchimp_drip_content WHERE 1 = 1;" );

		if ( absint( $count ) && $count > 0 ) {
			$table_list->prepare_items();

			echo '<input type="hidden" name="page" value="mcp-settings" />';
			echo '<input type="hidden" name="tab" value="dripping" />';

			$table_list->views();
			$table_list->search_box( esc_html__( 'Search rules', 'memberchimp' ), 'item_id' );
			$table_list->display();
		} else {
			echo '<div class="memberchimp-BlankState memberchimp-BlankState--dripping">';
			echo mcp_svg_icon( 'cloud-rain' );
			?>
			<h2 class="memberchimp-BlankState-message"><?php esc_html_e( 'Content dripping enables you to release content to your members based on how long they have been a member, or make content available at a specific date.', 'memberchimp' ); ?></h2>
			<a class="memberchimp-BlankState-cta button-primary button" href="<?php echo esc_url( admin_url( 'admin.php?page=mcp-settings&tab=addons&section=drip&create-rule=1' ) ); ?>"><?php esc_html_e( 'Create a new rule', 'memberchimp' ); ?></a>
			<style type="text/css">#posts-filter .wp-list-table, #posts-filter .tablenav.top, .tablenav.bottom .actions { display: none; }</style>
			<?php
		}
	}

	/**
	 * Get item data.
	 */
	private static function get_item( $item_id ) {
		global $wpdb;

		$empty = array(
			'item_id'       => 0,
			'term_id'       => '',
			'content_type'  => '',
			'type'   		=> '',
			'number' 		=> '',
			'timeframe'   	=> '',
			'from_date'   	=> '',
			'to_date'   	=> '',
			'role'   		=> '',
		);

		if ( 0 === $item_id ) {
			return $empty;
		}

		$item = $wpdb->get_row(
			$wpdb->prepare(
				"SELECT item_id, term_id, content_type, type, number, timeframe, from_date, to_date, role 
				FROM {$wpdb->prefix}memberchimp_drip_content
				WHERE item_id = %d",
				$item_id
			), ARRAY_A
		);

		if ( is_null( $item ) ) {
			return $empty;
		}

		return $item;
	}

	/**
	 * Admin actions.
	 */
	public function actions() {
		if ( $this->is_settings_page() ) {
			// Delete.
			if ( isset( $_REQUEST['delete-rule'] ) ) {
				$this->delete_rule();
			}

			// Bulk actions.
			if ( isset( $_REQUEST['action'] ) && isset( $_REQUEST['item'] ) ) {
				$this->bulk_actions();
			}
		}
	}

	/**
	 * Notices.
	 */
	public static function notices() {
		if ( isset( $_GET['deleted'] ) ) {
			$deleted = absint( $_GET['deleted'] );

			/* translators: %d: count */
			WC_Admin_Settings::add_message( sprintf( _n( '%d content dripping rule permanently deleted.', '%d content dripping rules permanently deleted.', $deleted, 'memberchimp' ), $deleted ) );
		}
	}

	/**
	 * Delete rule.
	 */
	private function delete_rule() {
		global $wpdb;

		check_admin_referer( 'delete' );

		if ( isset( $_REQUEST['delete-rule'] ) ) {
			$item_id = absint( $_REQUEST['delete-rule'] );

			if ( $item_id && current_user_can( 'manage_memberchimp' ) ) {
				$this->remove_item( $item_id );
			} else {
				wp_die( esc_html__( 'You do not have permission to delete this.', 'memberchimp' ) );
			}
		}

		wp_safe_redirect( esc_url_raw( add_query_arg( array( 'deleted' => 1 ), admin_url( 'admin.php?page=mcp-settings&tab=addons&section=drip' ) ) ) );
		exit();
	}

	/**
	 * Bulk actions.
	 */
	private function bulk_actions() {
		check_admin_referer( 'memberchimp-settings' );

		if ( ! current_user_can( 'manage_memberchimp' ) ) {
			wp_die( esc_html__( 'You do not have permission to edit rules.', 'memberchimp' ) );
		}

		if ( isset( $_REQUEST['action'] ) ) {
			$action = sanitize_text_field( wp_unslash( $_REQUEST['action'] ) );
			$items  = isset( $_REQUEST['item'] ) ? array_map( 'absint', (array) $_REQUEST['item'] ) : array();

			if ( 'delete' === $action ) {
				$this->bulk_delete_rules( $items );
			}
		}
	}

	/**
	 * Bulk delete.
	 */
	private function bulk_delete_rules( $items ) {
		if ( ! current_user_can( 'remove_users' ) ) {
			wp_die( esc_html__( 'You do not have permission to delete these rules.', 'memberchimp' ) );
		}

		$qty = 0;
		foreach ( $items as $item_id ) {
			$result = $this->remove_item( $item_id );

			if ( $result ) {
				$qty++;
			}
		}

		// Redirect to page.
		wp_safe_redirect( esc_url_raw( add_query_arg( array( 'deleted' => $qty ), admin_url( 'admin.php?page=mcp-settings&tab=addons&section=drip' ) ) ) );
		exit();
	}

	/**
	 * Remove item.
	 */
	private function remove_item( $item_id ) {
		global $wpdb;

		$delete = $wpdb->delete( $wpdb->prefix . 'memberchimp_drip_content', array( 'item_id' => $item_id ), array( '%d' ) );

		return $delete;
	}

	/**
	 * Get drip content types.
	 */
	public static function get_drip_types() {
		$types = apply_filters( 'memberchimp_drip_types', array(
			'drip'	=> esc_html__( 'Drip', 'memberchimp' ),
			'date'	=> esc_html__( 'Date', 'memberchimp' )
		) );
		return $types;
	}

	/**
	 * Get content types that can be dripped.
	 */
	public static function get_content_types() {
		$types = apply_filters( 'memberchimp_drip_content_types', array(
			'posts' 	 => esc_html__( 'Posts', 'memberchimp' ),
			'pages' 	 => esc_html__( 'Pages', 'memberchimp' ),
			'categories' => esc_html__( 'Categories', 'memberchimp' ),
		) );
		return $types;
	}

	/**
	 * Get time frames for content dripping.
	 */
	public static function get_timeframes() {
		$timeframes = apply_filters( 'memberchimp_drip_content_timeframes', array(
			'days' 	 	 => esc_html__( 'Days', 'memberchimp' ),
			'weeks' 	 => esc_html__( 'Weeks', 'memberchimp' ),
			'months'	 => esc_html__( 'Months', 'memberchimp' ),
		) );
		return $timeframes;
	}

	/**
	 * Get content title based on term nature.
	 */
	public static function get_content_title( $id, $type ) {
		if ( $type == 'posts' || $type == 'pages' ) {
			return get_the_title( $id );
		}

		if ( $type == 'categories' ) {
			return get_cat_name( $id );
		}
	}

}

new MCDC_Admin_Dripping();