<?php
/**
 * Admin view: Edit Drip Content Rules.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
?>

<div id="drip-fields" class="settings-panel">
	<h2><?php echo $item_id > 0 ? esc_html__( 'Edit drip content', 'memberchimp' ) : esc_html__( 'Create drip content', 'memberchimp' ); ?></h2>

	<input type="hidden" name="item_id" id="item_id" value="<?php echo esc_attr( $item_id ); ?>" />

	<table id="drip-options" class="form-table">
		<tbody>
			<tr valign="top">
				<th scope="row" class="titledesc">
					<label for="item_content_type">
						<?php esc_html_e( 'Type', 'memberchimp' ); ?>
						<?php echo mcp_help_tip( esc_html__( 'Which content type do you want to drip?', 'memberchimp' ) ); ?>
					</label>
				</th>
				<td class="forminp">
					<select name="item_content_type" id="item_content_type">
						<?php
							foreach( self::get_content_types() as $key => $value ) {
								echo '<option value="' . esc_attr( $key ) . '" ' . selected( $key, $item['content_type'], 0 ) . '>' . esc_html( $value ) . '</option>';
							}
						?>
					</select>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" class="titledesc">&nbsp;</th>
				<td class="forminp">
					<?php foreach( self::get_content_types() as $key => $value ) { ?>
					<select class="mcp-terms-search <?php echo esc_attr( $key ); ?> <?php if ( ( $item_id > 0 && $item['content_type'] !== $key ) || ( ! $item_id && $key != 'posts' ) ) echo 'mcp-select-hide'; ?>" data-type="<?php echo esc_attr( $key ); ?>" name="item_term_id_<?php echo esc_attr( $key ); ?>" id="item_term_id_<?php echo esc_attr( $key ); ?>" data-placeholder="<?php echo sprintf( esc_html__( 'Search %s&hellip;', 'memberchimp' ), esc_attr( strtolower( $value ) ) ); ?>" >
						<?php if ( $item['content_type'] == $key ) { ?>
						<option value="<?php echo absint( $item['term_id'] ); ?>" selected="selected"><?php echo wp_kses_post( self::get_content_title( $item['term_id'], $item['content_type'] ) ); ?></option>
						<?php } ?>
					</select>
					<?php } ?>
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" class="titledesc">
					<label for="item_type">
						<?php esc_html_e( 'Delay Access', 'memberchimp' ); ?>
						<?php echo mcp_help_tip( esc_html__( 'Drip when user has been active member for specific period or release on a specific date.', 'memberchimp' ) ); ?>
					</label>
				</th>
				<td class="forminp">
					<select name="item_type" id="item_type">
						<?php
							foreach( self::get_drip_types() as $key => $value ) {
								echo '<option value="' . esc_attr( $key ) . '" ' . selected( $key, $item['type'], 0 ) . '>' . esc_html( $value ) . '</option>';
							}
						?>
					</select>
					<p class="description"><?php esc_html_e( 'You can delay access based on user registration date or specify a date in the future.', 'memberchimp' ); ?></p>
				</td>
			</tr>
			<tr valign="top" data-condition="item_type:drip">
				<th scope="row" class="titledesc">
					<label for="item_number">
						<?php esc_html_e( 'User has been registered for', 'memberchimp' ); ?>
					</label>
				</th>
				<td class="forminp">
					<input type="number" name="item_number" id="item_number" class="small-text" value="<?php echo absint( $item['number'] ); ?>" autocomplete="time-span" />
					<select name="item_timeframe" id="item_timeframe" style="vertical-align: baseline;">
						<?php
							foreach( self::get_timeframes() as $key => $value ) {
								echo '<option value="' . esc_attr( $key ) . '" ' . selected( $key, $item['timeframe'], 0 ) . '>' . esc_html( $value ) . '</option>';
							}
						?>
					</select>
				</td>
			</tr>
			<tr valign="top" data-condition="item_type:date">
				<th scope="row" class="titledesc">
					<label for="item_from_date">
						<?php esc_html_e( 'When It will become available?', 'memberchimp' ); ?>
					</label>
				</th>
				<td class="forminp">
					<input type="date" id="item_from_date" name="item_from_date" value="<?php echo esc_attr( $item['from_date'] ); ?>" class="mcp-datepicker" placeholder="<?php echo current_time( 'mysql' ); ?>" />
				</td>
			</tr>
			<tr valign="top">
				<th scope="row" class="titledesc">
					<label for="item_role">
						<?php esc_html_e( 'Role', 'memberchimp' ); ?>
						<?php echo mcp_help_tip( esc_html__( 'If you want this rule to apply to a specific user role only.', 'memberchimp' ) ); ?>
					</label>
				</th>
				<td class="forminp">
					<select name="item_role" id="item_role">
						<option value="0"><?php esc_html_e( '&ndash; None specified &ndash;', 'memberchimp' ); ?></option>
						<?php foreach( memberchimp_get_roles() as $role => $name ) { ?>
						<option value="<?php echo esc_attr( $role ); ?>" <?php selected( $role, $item['role'] ); ?> ><?php esc_html_e( $name ); ?></option>
						<?php } ?>
					</select>
					<p class="description"><?php esc_html_e( 'If specified, the content will be available only If a user has been a member of this user role.', 'memberchimp' ); ?></p>
				</td>
			</tr>
		</tbody>
	</table>

	<?php do_action( 'memberchimp_admin_dripping_fields', $item ); ?>

	<?php
	if ( 0 === intval( $item_id ) ) {
		submit_button( esc_html__( 'Create Rule', 'memberchimp' ), 'primary', 'update_drip_rule' );
	} else {
		?>
		<p class="submit">
			<?php submit_button( esc_html__( 'Save changes', 'memberchimp' ), 'primary', 'update_drip_rule', false ); ?>
			<a style="color: #a00; text-decoration: none; margin-left: 10px;" href="<?php echo esc_url( wp_nonce_url( add_query_arg( array( 'delete-rule' => $item_id ), admin_url( 'admin.php?page=mcp-settings&tab=dripping' ) ), 'delete' ) ); ?>"><?php esc_html_e( 'Delete rule', 'memberchimp' ); ?></a>
		</p>
		<?php
	}
	?>
</div>