<?php
/**
 * AJAX Events.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * MCDC_AJAX class.
 */
class MCDC_AJAX {

	/**
	 * Hook in ajax handlers.
	 */
	public static function init() {
		self::add_ajax_events();
	}

	/**
	 * Hook in methods - uses WordPress ajax handlers (admin-ajax).
	 */
	public static function add_ajax_events() {
		// memberchimp_EVENT => nopriv.
		$ajax_events = array(
			'update_drip_content'		=> false,
		);

		foreach ( $ajax_events as $ajax_event => $nopriv ) {
			add_action( 'wp_ajax_memberchimp_' . $ajax_event, array( __CLASS__, $ajax_event ) );

			if ( $nopriv ) {
				add_action( 'wp_ajax_nopriv_memberchimp_' . $ajax_event, array( __CLASS__, $ajax_event ) );
			}
		}
	}

	/**
	 * Create/Update drip content rule.
	 */
	public static function update_drip_content() {
		ob_start();

		global $wpdb;

		check_ajax_referer( 'update-drip-content', 'security' );

		if ( ! current_user_can( 'manage_memberchimp' ) ) {
			wp_die( -1 );
		}

		$response = array();

		try {
			$item_id      	= isset( $_POST['item_id'] ) ? absint( $_POST['item_id'] ) : 0;
			$content_type	= sanitize_text_field( wp_unslash( $_POST['content_type'] ) );
			$term_id      	= isset( $_POST['term_id'] ) ? absint( $_POST['term_id'] ) : 0;
			$type			= sanitize_text_field( wp_unslash( $_POST['type'] ) );
			$number      	= isset( $_POST['number'] ) ? absint( $_POST['number'] ) : 0;
			$timeframe		= sanitize_text_field( wp_unslash( $_POST['timeframe'] ) );
			$from_date		= sanitize_text_field( wp_unslash( $_POST['from_date'] ) );
			$role			= sanitize_text_field( wp_unslash( $_POST['role'] ) );

			if ( empty( $term_id ) ) {
				throw new Exception( esc_html__( 'You need to restrict some content.', 'memberchimp' ) );
			}

			if ( $item_id > 0 ) {

				$data = array(
					'content_type'	=> $content_type,
					'term_id'     	=> $term_id,
					'type'    		=> $type,
					'number'    	=> $number,
					'timeframe' 	=> $timeframe,
					'from_date'   	=> $from_date,
					'role'			=> $role
				);

				$wpdb->update(
					$wpdb->prefix . 'memberchimp_drip_content',
					$data,
					array( 'item_id' => $item_id ),
					array(
						'%s',
						'%d',
						'%s',
						'%d',
						'%s',
						'%s',
					),
					array( '%d' )
				);

			} else {
				$data = array(
					'content_type'	=> $content_type,
					'term_id'     	=> $term_id,
					'type'    		=> $type,
					'number'    	=> $number,
					'timeframe' 	=> $timeframe,
					'from_date'   	=> $from_date,
					'role'			=> $role
				);

				$wpdb->insert(
					$wpdb->prefix . 'memberchimp_drip_content',
					$data,
					array(
						'%s',
						'%d',
						'%s',
						'%d',
						'%s',
						'%s',
					)
				);

				$item_id = $wpdb->insert_id;
			}

			$response['url'] = admin_url( 'admin.php?page=mcp-settings&tab=addons&section=drip' );

		} catch ( Exception $e ) {
			wp_send_json_error( array( 'message' => $e->getMessage() ) );
		}

		// wp_send_json_success must be outside the try block not to break phpunit tests.
		wp_send_json_success( $response );
	}

}

MCDC_AJAX::init();