<?php
/**
 * Addon: Followers
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Define MCFO_PLUGIN_FILE.
if ( ! defined( 'MCFO_PLUGIN_FILE' ) ) {
	define( 'MCFO_PLUGIN_FILE', __FILE__ );
}

/**
 * Main class.
 */
final class Memberchimp_Followers {

	/**
	 * The single instance of the class.
	 */
	protected static $_instance = null;

	/**
	 * Main Instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->define_constants();
		$this->includes();
		$this->init_hooks();

		do_action( 'mcp_followers_loaded' );
	}

	/**
	 * Define Constants.
	 */
	public function define_constants() {
		mcp()->define( 'MCFO_ABSPATH', dirname( MCFO_PLUGIN_FILE ) . '/' );
		mcp()->define( 'MCFO_PLUGIN_BASENAME', plugin_basename( MCFO_PLUGIN_FILE ) );
	}

	/**
	 * Include required core files used in admin and on the frontend.
	 */
	public function includes() {

		/**
		 * Core classes.
		 */
		include_once MCFO_ABSPATH . 'includes/class-mcfo-ajax.php';
		include_once MCFO_ABSPATH . 'includes/class-mcfo-install.php';

		if ( mcp()->is_request( 'admin' ) ) {
			include_once MCFO_ABSPATH . 'includes/admin/class-mcfo-admin.php';
		}

		// Front-end use only.
		if ( mcp()->is_request( 'frontend' ) ) {
			$this->frontend_includes();
		}

	}

	/**
	 * Hook into actions and filters.
	 */
	public function init_hooks() {

	}

	/**
	 * Include required frontend files.
	 */
	public function frontend_includes() {
		include_once MCFO_ABSPATH . 'includes/mcfo-frontend-functions.php';
	}

	/**
	 * Get the plugin path.
	 */
	public function plugin_path() {
		return untrailingslashit( plugin_dir_path( MCFO_PLUGIN_FILE ) );
	}

	/**
	 * Get the plugin URL.
	 */
	public function plugin_url() {
		return untrailingslashit( plugin_dir_url( MCFO_PLUGIN_FILE ) );
	}

}

/**
 * Main instance.
 */
function mcp_followers() {
	return Memberchimp_Followers::instance();
}

// Global for backwards compatibility.
$GLOBALS['mcp_followers'] = mcp_followers();