<?php
/**
 * Admin Settings.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * MCSO_Admin_Settings class.
 */
class MCSO_Admin_Settings {

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_filter( 'memberchimp_get_sections_addons', array( $this, 'add_settings_tab' ), 10 );
		add_filter( 'memberchimp_get_settings_addons', array( $this, 'add_settings' ), 10, 2 );
	}

	/**
	 * Add settings tab.
	 */
	public function add_settings_tab( $sections = array() ) {
		$sections[ 'social' ] = esc_html__( 'Social Login', 'memberchimp' );

		return $sections;
	}

	/**
	 * Add settings.
	 */
	public function add_settings( $settings = array(), $section = null ) {
		if ( $section == 'social' ) {
			$settings = apply_filters(
				'memberchimp_social_login_options', array(

					array(
						'title' => esc_html__( 'Integration', 'memberchimp' ),
						'type'  => 'title',
						'desc'  => '',
						'id'    => 'social_integration_options',
					),

					array(
						'title'    => esc_html__( 'Automatic Integration', 'memberchimp' ),
						'desc'     => esc_html__( 'Automatically integrate social login into your existing forms', 'memberchimp' ),
						'id'       => 'memberchimp_auto_integration',
						'default'  => 'yes',
						'type'     => 'checkbox',
						'desc_tip' => esc_html__( 'This is the simplest way to add social login to your site. If unchecked, you will have to add the social login manually by editing form settings.', 'memberchimp' ),
					),

					array(
						'title'    => esc_html__( 'New user default role', 'memberchimp' ),
						'desc'     => esc_html__( 'If you want users who sign up with social profile to have a different role than plugin default role.', 'memberchimp' ),
						'id'       => 'memberchimp_social_default_role',
						'default'  => '',
						'type'     => 'select',
						'class'    => 'mcp-select short',
						'options'  => array_merge( array( '' => esc_html__( 'Use Default', 'memberchimp' ) ), memberchimp_get_roles() ),
						'custom_attributes' => array(
							'placeholder'	=> esc_html__( 'Select an option...', 'memberchimp' ),
						),
					),

					array(
						'type' => 'sectionend',
						'id'   => 'social_integration_options',
					),

					array(
						'title' => esc_html__( 'Facebook options', 'memberchimp' ),
						'type'  => 'title',
						'desc'  => '',
						'id'    => 'facebook_options',
					),

					array(
						'title'    => esc_html__( 'Enable this network', 'memberchimp' ),
						'desc'     => '',
						'id'       => 'memberchimp_facebook_enabled',
						'default'  => 'no',
						'type'     => 'checkbox',
						'desc'	   => __( 'Enable Facebook social connect', 'memberchimp' ),
					),

					array(
						'title'       => esc_html__( 'App ID', 'memberchimp' ),
						'id'          => 'memberchimp_facebook_app_id',
						'type'        => 'text',
						'default'     => '',
						'autoload'    => false,
					),

					array(
						'title'       => esc_html__( 'App Secret', 'memberchimp' ),
						'id'          => 'memberchimp_facebook_app_secret',
						'type'        => 'text',
						'default'     => '',
						'autoload'    => false,
					),

					array(
						'type' => 'sectionend',
						'id'   => 'facebook_options',
					),

					array(
						'title' => esc_html__( 'Twitter options', 'memberchimp' ),
						'type'  => 'title',
						'desc'  => '',
						'id'    => 'twitter_options',
					),

					array(
						'title'    => esc_html__( 'Enable this network', 'memberchimp' ),
						'desc'     => '',
						'id'       => 'memberchimp_twitter_enabled',
						'default'  => 'no',
						'type'     => 'checkbox',
						'desc'	   => __( 'Enable Twitter social connect', 'memberchimp' ),
					),

					array(
						'title'       => esc_html__( 'API key', 'memberchimp' ),
						'id'          => 'memberchimp_twitter_api_key',
						'type'        => 'text',
						'default'     => '',
						'autoload'    => false,
					),

					array(
						'title'       => esc_html__( 'API secret key', 'memberchimp' ),
						'id'          => 'memberchimp_twitter_api_secret',
						'type'        => 'text',
						'default'     => '',
						'autoload'    => false,
					),

					array(
						'type' => 'sectionend',
						'id'   => 'twitter_options',
					),

				)
			);
		}
		return $settings;
	}

}

return new MCSO_Admin_Settings();