<?php
/**
 * Facebook.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * MCSO_Facebook class.
 */
class MCSO_Facebook {

	public static $app_id = null;
	public static $app_secret = null;
	public static $fb = null;
	public static $login_url = null;

	/**
	 * Init.
	 */
	public static function init() {
		self::$app_id 		= get_option( 'memberchimp_facebook_app_id' );
		self::$app_secret 	= get_option( 'memberchimp_facebook_app_secret' );

		if ( ! self::is_enabled() ) {
			return;
		}

		include_once MCSO_ABSPATH . 'includes/libraries/Facebook/autoload.php';
	}

	/**
	 * Checks if a social network is enabled.
	 */
	public static function is_enabled() {
		if ( ! self::$app_id || ! self::$app_secret || 'yes' !== get_option( 'memberchimp_facebook_enabled' ) ) {
			return false;
		}

		return true;
	}

	/**
	 * Get button.
	 */
	public static function get_button_html() {
		?>
		<div class="mcp-element">
			<a href="<?php echo esc_url( self::get_login_url() ); ?>" class="mcp-button mcp-facebook">
				<svg aria-hidden="true" class="svg-icon icon-facebook" width="18" height="18" viewBox="0 0 18 18"><path d="M1.88 1C1.4 1 1 1.4 1 1.88v14.24c0 .48.4.88.88.88h7.67v-6.2H7.46V8.4h2.09V6.61c0-2.07 1.26-3.2 3.1-3.2.88 0 1.64.07 1.87.1v2.16h-1.29c-1 0-1.19.48-1.19 1.18V8.4h2.39l-.31 2.42h-2.08V17h4.08c.48 0 .88-.4.88-.88V1.88c0-.48-.4-.88-.88-.88H1.88z"></path></svg> <?php esc_html_e( 'Continue with Facebook', 'memberchimp' ); ?>
			</a>
		</div>
		<?php
	}

	/**
	 * Get login URL.
	 */
	public static function get_login_url() {
		self::$fb = new Facebook\Facebook( [
			'app_id'                => self::$app_id,
			'app_secret'            => self::$app_secret,
			'default_graph_version' => 'v3.2',
		] );

		$helper 	 		= self::$fb->getRedirectLoginHelper();
		self::$login_url 	= $helper->getLoginUrl( self::get_request_uri(), array( 'email' ) );

		return self::$login_url;
	}

	/**
	 * Get the auth URL for request.
	 */
	public static function get_request_uri() {
		return add_query_arg( 'auth', 'facebook', trailingslashit( mcp_get_current_url() ) );
	}

	/**
	 * Complete authorization.
	 */
	public static function authorize() {
		self::$fb = new Facebook\Facebook( [
			'app_id'                => self::$app_id,
			'app_secret'            => self::$app_secret,
			'default_graph_version' => 'v3.2',
		] );

		$helper = self::$fb->getRedirectLoginHelper();

		try {
			$access_token = $helper->getAccessToken();
		} catch( Facebook\Exceptions\FacebookResponseException $e ) {
			die( $e->getMessage() );
		} catch( Facebook\Exceptions\FacebookSDKException $e ) {
			die( $e->getMessage() );
		}

		if ( isset( $access_token ) ) {
			mcp()->session->set( 'facebook_access_token', (string) $access_token );
			$oauth = self::$fb->getOAuth2Client();
			$token = $oauth->getLongLivedAccessToken( mcp()->session->get( 'facebook_access_token' ) );
			self::$fb->setDefaultAccessToken( $token );

			try {
				$response = self::$fb->get( '/me?fields=id,name,email', $token );
				$metadata = $response->getGraphUser();
			} catch( Facebook\Exceptions\FacebookResponseException $e ) {
				die( $e->getMessage() );
			} catch( Facebook\Exceptions\FacebookSDKException $e ) {
				die( $e->getMessage() );
			}
		}

		// The captured data.
		if ( isset( $metadata ) ) {
			$uid    = $metadata->getProperty( 'id' );
			$email  = $metadata->getProperty( 'email' );
			$name   = $metadata->getProperty( 'name' );

			// This is the final array data that we will use to process this connection.
			$data = array(
				'provider'  => 'facebook',
				'uid'    	=> $uid,
				'email' 	=> $email,
				'name'		=> $name,
				'avatar'    => 'https://graph.facebook.com/' . $uid. '/picture?type=large',
			);

			MCSO_Networks::process( $data );
		}

	}

}

MCSO_Facebook::init();