<?php
/**
 * Twitter.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Abraham\TwitterOAuth\TwitterOAuth;

/**
 * MCSO_Twitter class.
 */
class MCSO_Twitter {

	public static $api_key = null;
	public static $api_secret = null;
	public static $twitter = null;
	public static $request_token = null;
	public static $login_url = null;

	/**
	 * Init.
	 */
	public static function init() {
		self::$api_key 		= get_option( 'memberchimp_twitter_api_key' );
		self::$api_secret 	= get_option( 'memberchimp_twitter_api_secret' );

		if ( ! self::is_enabled() ) {
			return;
		}

		include_once MCSO_ABSPATH . 'includes/libraries/Twitter/autoload.php';
	}

	/**
	 * Checks if a social network is enabled.
	 */
	public static function is_enabled() {
		if ( ! self::$api_key || ! self::$api_secret || 'yes' !== get_option( 'memberchimp_twitter_enabled' ) ) {
			return false;
		}

		return true;
	}

	/**
	 * Get button.
	 */
	public static function get_button_html() {
		?>
		<div class="mcp-element">
			<a href="<?php echo esc_url( self::get_login_url() ); ?>" class="mcp-button mcp-twitter">
				<svg xmlns="http://www.w3.org/2000/svg" width="18" height="18" viewBox="0 0 24 24"><path d="M24 4.557c-.883.392-1.832.656-2.828.775 1.017-.609 1.798-1.574 2.165-2.724-.951.564-2.005.974-3.127 1.195-.897-.957-2.178-1.555-3.594-1.555-3.179 0-5.515 2.966-4.797 6.045-4.091-.205-7.719-2.165-10.148-5.144-1.29 2.213-.669 5.108 1.523 6.574-.806-.026-1.566-.247-2.229-.616-.054 2.281 1.581 4.415 3.949 4.89-.693.188-1.452.232-2.224.084.626 1.956 2.444 3.379 4.6 3.419-2.07 1.623-4.678 2.348-7.29 2.04 2.179 1.397 4.768 2.212 7.548 2.212 9.142 0 14.307-7.721 13.995-14.646.962-.695 1.797-1.562 2.457-2.549z"/></svg> <?php esc_html_e( 'Continue with Twitter', 'memberchimp' ); ?>
			</a>
		</div>
		<?php
	}

	/**
	 * Get login URL.
	 */
	public static function get_login_url() {
		self::$twitter = new TwitterOAuth( self::$api_key, self::$api_secret );

		self::$request_token = self::$twitter->oauth( 'oauth/request_token', array( 'oauth_callback' => self::get_request_uri() ) );

		mcp()->session->set( 'oauth_token', self::$request_token['oauth_token'] );
		mcp()->session->set( 'oauth_token_secret', self::$request_token['oauth_token_secret'] );

		self::$login_url = self::$twitter->url( 'oauth/authorize', array( 'oauth_token' => self::$request_token['oauth_token'] ) );

		return self::$login_url;
	}

	/**
	 * Get the auth URL for request.
	 */
	public static function get_request_uri() {
		return add_query_arg( 'auth', 'twitter', trailingslashit( mcp_get_current_url() ) );
	}

	/**
	 * Complete authorization.
	 */
	public static function authorize() {

		$request_token = array();
		$request_token['oauth_token'] = mcp()->session->get( 'oauth_token' );
		$request_token['oauth_token_secret'] = mcp()->session->get( 'oauth_token_secret' );

		if ( isset( $_REQUEST['oauth_token'] ) && $request_token['oauth_token'] !== $_REQUEST['oauth_token'] ) {
			return;
		}

		self::$twitter = new TwitterOAuth( self::$api_key, self::$api_secret, $request_token['oauth_token'], $request_token['oauth_token_secret'] );
		$access_token = self::$twitter->oauth( 'oauth/access_token', ["oauth_verifier" => $_REQUEST['oauth_verifier'] ] );
		mcp()->session->set( 'access_token', $access_token );

		self::$twitter = new TwitterOAuth( self::$api_key, self::$api_secret, $access_token['oauth_token'], $access_token['oauth_token_secret'] );
		$metadata = self::$twitter->get( 'account/verify_credentials', array( 'include_email' => 'true', 'include_entities' => 'false', 'skip_status' => 'true' ) );

		// The captured data.
		if ( isset( $metadata ) ) {

			$uid			= $metadata->id;
			$email 			= $metadata->email;
			$screen_name 	= $metadata->screen_name;
			$name			= $metadata->name;

			// This is the final array data that we will use to process this connection.
			$data = array(
				'provider'  => 'twitter',
				'uid'    	=> $uid,
				'email' 	=> $email,
				'username'  => $screen_name,
				'name'		=> $name,
			);

			MCSO_Networks::process( $data );
		}

	}

}

MCSO_Twitter::init();