<?php
/**
 * Addon: Social Login
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Define MCSO_PLUGIN_FILE.
if ( ! defined( 'MCSO_PLUGIN_FILE' ) ) {
	define( 'MCSO_PLUGIN_FILE', __FILE__ );
}

/**
 * Main class.
 */
final class Memberchimp_Social_Login {

	/**
	 * The single instance of the class.
	 */
	protected static $_instance = null;

	/**
	 * Main Instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->define_constants();
		$this->includes();
		$this->init_hooks();

		do_action( 'mcp_social_loaded' );
	}

	/**
	 * Define Constants.
	 */
	public function define_constants() {
		mcp()->define( 'MCSO_ABSPATH', dirname( MCSO_PLUGIN_FILE ) . '/' );
		mcp()->define( 'MCSO_PLUGIN_BASENAME', plugin_basename( MCSO_PLUGIN_FILE ) );
	}

	/**
	 * Include required core files used in admin and on the frontend.
	 */
	public function includes() {

		/**
		 * Core classes.
		 */
		include_once MCSO_ABSPATH . 'includes/mcso-core-functions.php';
		include_once MCSO_ABSPATH . 'includes/class-mcso-install.php';
		include_once MCSO_ABSPATH . 'includes/class-mcso-networks.php';

		if ( mcp()->is_request( 'admin' ) ) {
			include_once MCSO_ABSPATH . 'includes/admin/class-mcso-admin.php';
		}

		// Front-end use only.
		if ( mcp()->is_request( 'frontend' ) ) {
			$this->frontend_includes();
		}

	}

	/**
	 * Hook into actions and filters.
	 */
	public function init_hooks() {
		add_action( 'init', array( 'MCSO_Networks', 'init' ), 5 );
		add_action( 'template_redirect', array( 'MCSO_Networks', 'authorize' ), 30 );
	}

	/**
	 * Include required frontend files.
	 */
	public function frontend_includes() {
		include_once MCSO_ABSPATH . 'includes/mcso-template-hooks.php';
	}

	/**
	 * Get the plugin path.
	 */
	public function plugin_path() {
		return untrailingslashit( plugin_dir_path( MCSO_PLUGIN_FILE ) );
	}

}

/**
 * Main instance.
 */
function mcp_social() {
	return Memberchimp_Social_Login::instance();
}

// Global for backwards compatibility.
$GLOBALS['mcp_social'] = mcp_social();