<?php
/**
 * Load assets
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * MCP_Admin_Assets class.
 */
class MCP_Admin_Assets {

	/**
	 * Hook in tabs.
	 */
	public function __construct() {
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_styles' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );
		remove_action( 'admin_enqueue_scripts', 'wp_auth_check_load' );
	}

	/**
	 * Enqueue styles.
	 */
	public function admin_styles() {
		global $wp_scripts;

		$screen    = get_current_screen();
		$screen_id = $screen ? $screen->id : '';

		// Register admin styles.
		wp_register_style( 'memberchimp_admin_menu_styles', mcp()->plugin_url() . '/assets/css/menu.css', array(), MCP_VERSION );
		wp_register_style( 'memberchimp_admin_styles', mcp()->plugin_url() . '/assets/css/admin.css', array(), MCP_VERSION );
		wp_register_style( 'memberchimp_admin_dashboard_styles', mcp()->plugin_url() . '/assets/css/dashboard.css', array(), MCP_VERSION );

		// Add RTL support for admin styles.
		wp_style_add_data( 'memberchimp_admin_menu_styles', 'rtl', 'replace' );
		wp_style_add_data( 'memberchimp_admin_styles', 'rtl', 'replace' );
		wp_style_add_data( 'memberchimp_admin_dashboard_styles', 'rtl', 'replace' );

		// Sitewide menu CSS.
		wp_enqueue_style( 'memberchimp_admin_menu_styles' );

		// Admin styles for plugin pages only.
		if ( in_array( $screen_id, mcp_get_screen_ids() ) ) {
			wp_enqueue_style( 'memberchimp_admin_styles' );
			wp_enqueue_style( 'wp-color-picker' );
		}

		if ( in_array( $screen_id, array( 'dashboard' ) ) ) {
			wp_enqueue_style( 'memberchimp_admin_dashboard_styles' );
		}

	}	

	/**
	 * Enqueue scripts.
	 */
	public function admin_scripts() {
		global $wp_query, $post;

		$screen       = get_current_screen();
		$screen_id    = $screen ? $screen->id : '';
		$mcp_screen_id = sanitize_title( __( 'Member Chimp', 'memberchimp' ) );

		// Register scripts.
		wp_register_script( 'jquery-tiptip', mcp()->plugin_url() . '/assets/js/jquery-tiptip/jquery-tiptip.js', array( 'jquery' ), MCP_VERSION, true );
		wp_register_script( 'jquery-toggles', mcp()->plugin_url() . '/assets/js/jquery-toggles/jquery-toggles.js', array( 'jquery' ), MCP_VERSION, true );
		wp_register_script( 'jquery-modal', mcp()->plugin_url() . '/assets/js/jquery-modal/jquery-modal.js', array( 'jquery' ), MCP_VERSION, true );
		wp_register_script( 'jquery-selectize', mcp()->plugin_url() . '/assets/js/jquery-selectize/jquery-selectize.js', array( 'jquery' ), MCP_VERSION, true );
		wp_register_script( 'jquery-helper', mcp()->plugin_url() . '/assets/js/jquery-helper/jquery-helper.js', array( 'jquery' ), MCP_VERSION, true );
		wp_register_script( 'memberchimp_admin', mcp()->plugin_url() . '/assets/js/admin/memberchimp_admin.js', array( 'jquery', 'jquery-blockui', 'jquery-ui-sortable', 'jquery-tiptip', 'jquery-toggles', 'jquery-modal', 'jquery-selectize', 'jquery-helper' ), MCP_VERSION, true );
		wp_register_script( 'jquery-blockui', mcp()->plugin_url() . '/assets/js/jquery-blockui/jquery-blockui.js', array( 'jquery' ), MCP_VERSION, true );

		// Admin pages.
		if ( in_array( $screen_id, mcp_get_screen_ids() ) ) {
			$dummy = new MCP_Field();

			wp_enqueue_script( 'iris' );
			wp_enqueue_script( 'memberchimp_admin' );

			$params = array(
				'ajax_url'	=> admin_url( 'admin-ajax.php' ),
				'metakeys'	=> $dummy->internal_meta_keys,
				'yes'		=> esc_html__( 'yes', 'memberchimp' ),
				'no'		=> esc_html__( 'no', 'memberchimp' ),
				'svg'		=> mcp()->plugin_url() . '/assets/images/feather-sprite.svg#',
				'nonces'	=> array(
					'save_form'				=> wp_create_nonce( 'memberchimp-save-form' ),
					'create_forms' 			=> wp_create_nonce( 'memberchimp-create-forms' ),
					'create_fields' 		=> wp_create_nonce( 'memberchimp-create-fields' ),
					'create_roles'			=> wp_create_nonce( 'memberchimp-create-roles' ),
					'create_memberlists'	=> wp_create_nonce( 'memberchimp-create-memberlists' ),
					'add_field'				=> wp_create_nonce( 'memberchimp-add-field' ),
					'json_search_users'		=> wp_create_nonce( 'memberchimp-json-search-users' ),
					'json_search_terms'		=> wp_create_nonce( 'memberchimp-json-search-terms' ),
				),
				'states'	=> array(
					'create_forms'			=> esc_html__( 'Creating forms...', 'memberchimp' ),
					'create_fields'			=> esc_html__( 'Creating fields...', 'memberchimp' ),
					'create_roles'			=> esc_html__( 'Creating roles...', 'memberchimp' ),
					'create_memberlists'	=> esc_html__( 'Creating member lists...', 'memberchimp' ),
					'done_redirect'			=> esc_html__( 'That&#39;s It! Please hold on.', 'memberchimp' ),
					'show_less'				=> esc_html__( 'Show less', 'memberchimp' ),
					'show_more'				=> esc_html__( 'Show more', 'memberchimp' ),
					'ajax_error'			=> esc_html__( 'An error has occured.', 'memberchimp' ),
					'duplicating'			=> esc_html__( 'Duplicating...', 'memberchimp' ),
					'saving_changes'		=> esc_html__( 'Saving changes...', 'memberchimp' ),
					'unsaved_changes'		=> esc_html__( 'Your changes will not take effect until you press on <b>Save changes &rarr;</b> button.', 'memberchimp' ),
					'saved_changes'			=> esc_html__( 'Changes have been saved.', 'memberchimp' ),
				),
				'modal'		=> array(
					'creating'				=> esc_html__( 'Create a Custom Field', 'memberchimp' ),
					'editing'				=> esc_html__( 'Editing "{field}"', 'memberchimp' ),
					'save_button'			=> esc_html__( 'Save Field &rarr;', 'memberchimp' ),
					'create_button'			=> esc_html__( 'Create &rarr;', 'memberchimp' ),
				),
			);

			wp_localize_script( 'memberchimp_admin', 'memberchimp_admin', $params );
		}

		// Form builder.
		if ( in_array( $screen_id, array( 'mcp_form' ) ) ) {
			wp_register_script( 'mcp-forms', mcp()->plugin_url() . '/assets/js/admin/mcp-forms.js', array( 'jquery' ), MCP_VERSION, true );
			wp_enqueue_script( 'mcp-forms' );
			wp_localize_script(
				'mcp-forms',
				'mcp_forms_params',
				array(

				)
			);
		}

		// Users admin.
		if ( in_array( $screen_id, array( 'users' ) ) ) {
			wp_register_script( 'mcp-users', mcp()->plugin_url() . '/assets/js/admin/users.js', array( 'jquery' ), MCP_VERSION, true );
			wp_enqueue_script( 'mcp-users' );
			wp_localize_script(
				'mcp-users',
				'mcp_users_params',
				array(

				)
			);
		}

		// API settings.
		if ( $mcp_screen_id . '_page_mcp-settings' === $screen_id && isset( $_GET['section'] ) && 'keys' == $_GET['section'] ) {
			wp_register_script( 'mcp-api-keys', mcp()->plugin_url() . '/assets/js/admin/api-keys.js', array( 'jquery', 'memberchimp_admin', 'underscore', 'backbone', 'wp-util' ), MCP_VERSION, true );
			wp_enqueue_script( 'mcp-api-keys' );
			wp_localize_script(
				'mcp-api-keys',
				'memberchimp_admin_api_keys',
				array(
					'ajax_url'         => admin_url( 'admin-ajax.php' ),
					'update_api_nonce' => wp_create_nonce( 'update-api-key' ),
				)
			);
		}
	}

}

return new MCP_Admin_Assets();