<?php
/**
 * Create menus in WP admin.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * MCP_Admin_Menus class.
 */
class MCP_Admin_Menus {

	/**
	 * Hook in tabs.
	 */
	public function __construct() {
		// Add menus.
		add_action( 'admin_menu', array( $this, 'admin_menu' ), 9 );
		add_action( 'admin_menu', array( $this, 'settings_menu' ), 50 );

		add_action( 'admin_head', array( $this, 'menu_highlight' ) );
		add_action( 'admin_head', array( $this, 'menu_order_fix' ) );

		add_filter( 'menu_order', 		 array( $this, 'menu_order' ) );
		add_filter( 'custom_menu_order', array( $this, 'custom_menu_order' ) );
	}

	/**
	 * Add menu items.
	 */
	public function admin_menu() {
		global $menu;

		if ( current_user_can( 'manage_memberchimp' ) ) {
			$menu[] = array( '', 'read', 'separator-memberchimp', '', 'wp-menu-separator memberchimp' );
		}

		add_menu_page( esc_html__( 'Member Chimp', 'memberchimp' ), esc_html__( 'Member Chimp', 'memberchimp' ), 'manage_memberchimp', 'memberchimp', null, null, '27.5471' );
	}

	/**
	 * Add menu item.
	 */
	public function settings_menu() {
		$settings_page = add_submenu_page( 'memberchimp', esc_html__( 'Settings', 'memberchimp' ), esc_html__( 'Settings', 'memberchimp' ), 'mcp_settings', 'mcp-settings', array( $this, 'settings_page' ) );
		add_action( 'load-' . $settings_page, array( $this, 'settings_page_init' ) );
	}

	/**
	 * Loads gateways and shipping methods into memory for use within settings.
	 */
	public function settings_page_init() {
		global $current_tab, $current_section;

		// Include settings pages.
		MCP_Admin_Settings::get_settings_pages();

		// Get current tab/section.
		$current_tab     = empty( $_GET['tab'] ) ? 'general' : sanitize_title( wp_unslash( $_GET['tab'] ) );
		$current_section = empty( $_REQUEST['section'] ) ? '' : sanitize_title( wp_unslash( $_REQUEST['section'] ) );

		// Save settings if data has been posted.
		if ( '' !== $current_section && apply_filters( "memberchimp_save_settings_{$current_tab}_{$current_section}", ! empty( $_POST['save'] ) ) ) {
			MCP_Admin_Settings::save();
		} elseif ( '' === $current_section && apply_filters( "memberchimp_save_settings_{$current_tab}", ! empty( $_POST['save'] ) ) ) {
			MCP_Admin_Settings::save();
		}

		// Add any posted messages.
		if ( ! empty( $_GET['mcp_error'] ) ) {
			MCP_Admin_Settings::add_error( wp_kses_post( wp_unslash( $_GET['mcp_error'] ) ) );
		}

		if ( ! empty( $_GET['mcp_message'] ) ) {
			MCP_Admin_Settings::add_message( wp_kses_post( wp_unslash( $_GET['mcp_message'] ) ) );
		}

		if ( ! empty( $_GET['mcp_saved'] ) ) {
			MCP_Admin_Settings::add_message( wp_kses_post( wp_unslash( __( 'Your settings have been saved.', 'memberchimp' ) ) ) );
		}

		do_action( 'memberchimp_settings_page_init' );
	}

	/**
	 * Highlights the correct top level admin menu item for post type add screens.
	 */
	public function menu_highlight() {
		global $parent_file, $submenu_file, $post_type;

		switch ( $post_type ) {

		}
	}

	/**
	 * Removes the parent menu item.
	 */
	public function menu_order_fix() {
		global $submenu;

		if ( isset( $submenu['memberchimp'] ) ) {
			// Remove 'memberchimp' sub menu item.
			unset( $submenu['memberchimp'][0] );
		}
	}

	/**
	 * Reorder the menu items in admin.
	 */
	public function menu_order( $menu_order ) {
		// Initialize our custom order array.
		$memberchimp_menu_order = array();

		// Get the index of our custom separator.
		$memberchimp_separator = array_search( 'separator-memberchimp', $menu_order, true );

		// Loop through menu order and do some rearranging.
		foreach ( $menu_order as $index => $item ) {

			if ( 'memberchimp' === $item ) {
				$memberchimp_menu_order[] = 'separator-memberchimp';
				$memberchimp_menu_order[] = $item;
				$memberchimp_menu_order[] = 'edit.php?post_type=product';
				unset( $menu_order[ $memberchimp_separator ] );
			} elseif ( ! in_array( $item, array( 'separator-memberchimp' ), true ) ) {
				$memberchimp_menu_order[] = $item;
			}
		}

		// Return order.
		return $memberchimp_menu_order;
	}

	/**
	 * Custom menu order.
	 */
	public function custom_menu_order( $enabled ) {
		return $enabled || current_user_can( 'manage_memberchimp' );
	}

	/**
	 * Init the settings page.
	 */
	public function settings_page() {
		MCP_Admin_Settings::output();
	}

}

return new MCP_Admin_Menus();