<?php
/**
 * Post Types Admin
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * MCP_Admin_Post_Types class.
 */
class MCP_Admin_Post_Types {

	/**
	 * Constructor.
	 */
	public function __construct() {
		include_once dirname( __FILE__ ) . '/class-mcp-admin-meta-boxes.php';

		// Load correct list table classes for current screen.
		add_action( 'current_screen', array( $this, 'setup_screen' ) );
		add_action( 'check_ajax_referer', array( $this, 'setup_screen' ) );

		// Admin notices.
		add_filter( 'post_updated_messages', array( $this, 'post_updated_messages' ) );
		add_filter( 'bulk_post_updated_messages', array( $this, 'bulk_post_updated_messages' ), 10, 2 );

		// Extra post data and screen elements.
		add_action( 'edit_form_top', array( $this, 'edit_form_top' ) );
		add_filter( 'enter_title_here', array( $this, 'enter_title_here' ), 1, 2 );

		// Fire when specific post type is deleted.
		add_action( 'before_delete_post', array( $this, 'before_delete_post' ) );
	}

	/**
	 * Looks at the current screen and loads the correct list table handler.
	 */
	public function setup_screen() {
		global $mcp_list_table;

		$screen_id = false;

		if ( function_exists( 'get_current_screen' ) ) {
			$screen    = get_current_screen();
			$screen_id = isset( $screen, $screen->id ) ? $screen->id : '';
		}

		if ( ! empty( $_REQUEST['screen'] ) ) {
			$screen_id = mcp_clean( wp_unslash( $_REQUEST['screen'] ) );
		}

		switch ( $screen_id ) {
			case 'edit-mcp_form':
				include_once 'list-tables/class-mcp-admin-list-table-forms.php';
				$mcp_list_table = new MCP_Admin_List_Table_Forms();
				break;
			case 'edit-mcp_field':
				include_once 'list-tables/class-mcp-admin-list-table-fields.php';
				$mcp_list_table = new MCP_Admin_List_Table_Fields();
				break;
			case 'edit-mcp_role':
				include_once 'list-tables/class-mcp-admin-list-table-roles.php';
				$mcp_list_table = new MCP_Admin_List_Table_Roles();
				break;
			case 'edit-mcp_memberlist':
				include_once 'list-tables/class-mcp-admin-list-table-memberlists.php';
				$mcp_list_table = new MCP_Admin_List_Table_Memberlists();
				break;
		}

		// Ensure the table handler is only loaded once. Prevents multiple loads if a plugin calls check_ajax_referer many times.
		remove_action( 'current_screen', array( $this, 'setup_screen' ) );
		remove_action( 'check_ajax_referer', array( $this, 'setup_screen' ) );
	}

	/**
	 * Change messages when a post type is updated.
	 */
	public function post_updated_messages( $messages ) {
		global $post;

		$messages['mcp_form'] = array(
			0  => '', // Unused. Messages start at index 1.
			1  => esc_html__( 'Form updated.', 'memberchimp' ),
			2  => esc_html__( 'Custom field updated.', 'memberchimp' ),
			3  => esc_html__( 'Custom field deleted.', 'memberchimp' ),
			4  => esc_html__( 'Form updated.', 'memberchimp' ),
			5  => esc_html__( 'Revision restored.', 'memberchimp' ),
			6  => esc_html__( 'Form updated.', 'memberchimp' ),
			7  => esc_html__( 'Form saved.', 'memberchimp' ),
			8  => esc_html__( 'Form submitted.', 'memberchimp' ),
			9  => sprintf(
				__( 'Form scheduled for: %s.', 'memberchimp' ),
				'<strong>' . date_i18n( __( 'M j, Y @ G:i', 'memberchimp' ), strtotime( $post->post_date ) ) . '</strong>'
			),
			10 => esc_html__( 'Form draft updated.', 'memberchimp' ),
			11 => esc_html__( 'Form updated and sent.', 'memberchimp' ),
		);

		$messages['mcp_field'] = array(
			0  => '', // Unused. Messages start at index 1.
			1  => esc_html__( 'Custom field updated.', 'memberchimp' ),
			2  => esc_html__( 'Custom field updated.', 'memberchimp' ),
			3  => esc_html__( 'Custom field deleted.', 'memberchimp' ),
			4  => esc_html__( 'Custom field updated.', 'memberchimp' ),
			5  => esc_html__( 'Revision restored.', 'memberchimp' ),
			6  => esc_html__( 'Custom field updated.', 'memberchimp' ),
			7  => esc_html__( 'Custom field saved.', 'memberchimp' ),
			8  => esc_html__( 'Custom field submitted.', 'memberchimp' ),
			9  => sprintf(
				__( 'Custom field scheduled for: %s.', 'memberchimp' ),
				'<strong>' . date_i18n( __( 'M j, Y @ G:i', 'memberchimp' ), strtotime( $post->post_date ) ) . '</strong>'
			),
			10 => esc_html__( 'Custom field draft updated.', 'memberchimp' ),
			11 => esc_html__( 'Custom field updated and sent.', 'memberchimp' ),
		);

		$messages['mcp_role'] = array(
			0  => '', // Unused. Messages start at index 1.
			1  => esc_html__( 'User role updated.', 'memberchimp' ),
			2  => esc_html__( 'Custom field updated.', 'memberchimp' ),
			3  => esc_html__( 'Custom field deleted.', 'memberchimp' ),
			4  => esc_html__( 'User role updated.', 'memberchimp' ),
			5  => esc_html__( 'Revision restored.', 'memberchimp' ),
			6  => esc_html__( 'User role updated.', 'memberchimp' ),
			7  => esc_html__( 'User role saved.', 'memberchimp' ),
			8  => esc_html__( 'User role submitted.', 'memberchimp' ),
			9  => sprintf(
				__( 'User role scheduled for: %s.', 'memberchimp' ),
				'<strong>' . date_i18n( __( 'M j, Y @ G:i', 'memberchimp' ), strtotime( $post->post_date ) ) . '</strong>'
			),
			10 => esc_html__( 'User role draft updated.', 'memberchimp' ),
			11 => esc_html__( 'User role updated and sent.', 'memberchimp' ),
		);

		$messages['mcp_memberlist'] = array(
			0  => '', // Unused. Messages start at index 1.
			1  => esc_html__( 'Member list updated.', 'memberchimp' ),
			2  => esc_html__( 'Custom field updated.', 'memberchimp' ),
			3  => esc_html__( 'Custom field deleted.', 'memberchimp' ),
			4  => esc_html__( 'Member list updated.', 'memberchimp' ),
			5  => esc_html__( 'Revision restored.', 'memberchimp' ),
			6  => esc_html__( 'Member list updated.', 'memberchimp' ),
			7  => esc_html__( 'Member list saved.', 'memberchimp' ),
			8  => esc_html__( 'Member list submitted.', 'memberchimp' ),
			9  => sprintf(
				__( 'Member list scheduled for: %s.', 'memberchimp' ),
				'<strong>' . date_i18n( __( 'M j, Y @ G:i', 'memberchimp' ), strtotime( $post->post_date ) ) . '</strong>'
			),
			10 => esc_html__( 'Member list draft updated.', 'memberchimp' ),
			11 => esc_html__( 'Member list updated and sent.', 'memberchimp' ),
		);

		return $messages;
	}

	/**
	 * Specify custom bulk actions messages for different post types.
	 */
	public function bulk_post_updated_messages( $bulk_messages, $bulk_counts ) {
		$bulk_messages['mcp_form'] = array(
			'updated'   => _n( '%s form updated.', '%s forms updated.', $bulk_counts['updated'], 'memberchimp' ),
			'locked'    => _n( '%s form not updated, somebody is editing it.', '%s forms not updated, somebody is editing them.', $bulk_counts['locked'], 'memberchimp' ),
			'deleted'   => _n( '%s form permanently deleted.', '%s forms permanently deleted.', $bulk_counts['deleted'], 'memberchimp' ),
			'trashed'   => _n( '%s form moved to the Trash.', '%s forms moved to the Trash.', $bulk_counts['trashed'], 'memberchimp' ),
			'untrashed' => _n( '%s form restored from the Trash.', '%s forms restored from the Trash.', $bulk_counts['untrashed'], 'memberchimp' ),
		);

		$bulk_messages['mcp_field'] = array(
			'updated'   => _n( '%s custom field updated.', '%s custom fields updated.', $bulk_counts['updated'], 'memberchimp' ),
			'locked'    => _n( '%s custom field not updated, somebody is editing it.', '%s custom fields not updated, somebody is editing them.', $bulk_counts['locked'], 'memberchimp' ),
			'deleted'   => _n( '%s custom field permanently deleted.', '%s custom fields permanently deleted.', $bulk_counts['deleted'], 'memberchimp' ),
			'trashed'   => _n( '%s custom field moved to the Trash.', '%s custom fields moved to the Trash.', $bulk_counts['trashed'], 'memberchimp' ),
			'untrashed' => _n( '%s custom field restored from the Trash.', '%s custom fields restored from the Trash.', $bulk_counts['untrashed'], 'memberchimp' ),
		);

		$bulk_messages['mcp_role'] = array(
			'updated'   => _n( '%s user role updated.', '%s user roles updated.', $bulk_counts['updated'], 'memberchimp' ),
			'locked'    => _n( '%s user role not updated, somebody is editing it.', '%s user roles not updated, somebody is editing them.', $bulk_counts['locked'], 'memberchimp' ),
			'deleted'   => _n( '%s user role permanently deleted.', '%s user roles permanently deleted.', $bulk_counts['deleted'], 'memberchimp' ),
			'trashed'   => _n( '%s user role moved to the Trash.', '%s user roles moved to the Trash.', $bulk_counts['trashed'], 'memberchimp' ),
			'untrashed' => _n( '%s user role restored from the Trash.', '%s user roles restored from the Trash.', $bulk_counts['untrashed'], 'memberchimp' ),
		);

		$bulk_messages['mcp_memberlist'] = array(
			'updated'   => _n( '%s member list updated.', '%s member lists updated.', $bulk_counts['updated'], 'memberchimp' ),
			'locked'    => _n( '%s member list not updated, somebody is editing it.', '%s member lists not updated, somebody is editing them.', $bulk_counts['locked'], 'memberchimp' ),
			'deleted'   => _n( '%s member list permanently deleted.', '%s member lists permanently deleted.', $bulk_counts['deleted'], 'memberchimp' ),
			'trashed'   => _n( '%s member list moved to the Trash.', '%s member lists moved to the Trash.', $bulk_counts['trashed'], 'memberchimp' ),
			'untrashed' => _n( '%s member list restored from the Trash.', '%s member lists restored from the Trash.', $bulk_counts['untrashed'], 'memberchimp' ),
		);

		return $bulk_messages;
	}

	/**
	 * Output extra data on post forms.
	 */
	public function edit_form_top( $post ) {
		echo '<input type="hidden" id="original_post_title" name="original_post_title" value="' . esc_attr( $post->post_title ) . '" />';
	}

	/**
	 * Change title boxes in admin.
	 */
	public function enter_title_here( $text, $post ) {
		switch ( $post->post_type ) {
			case 'mcp_form':
				$text = esc_html__( 'e.g. Registration', 'memberchimp' );
				break;
			case 'mcp_field':
				$text = esc_html__( 'e.g. Location', 'memberchimp' );
				break;
			case 'mcp_role':
				$text = esc_html__( 'e.g. Premium member', 'memberchimp' );
				break;
			case 'mcp_memberlist':
				$text = esc_html__( 'e.g. Member Directory', 'memberchimp' );
				break;
		}
		return $text;
	}

	/**
	 * Before a post is completely removed.
	 */
	public function before_delete_post( $post_id ) {
		global $post_type;
		if ( in_array( $post_type, mcp_get_post_types() ) ) {
			$object = new $post_type( $post_id );
			$object->delete();
		}
	}

}

new MCP_Admin_Post_Types();