<?php
/**
 * List tables: custom fields.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'MCP_Admin_List_Table', false ) ) {
	include_once 'abstract-class-mcp-admin-list-table.php';
}

/**
 * MCP_Admin_List_Table_Fields class.
 */
class MCP_Admin_List_Table_Fields extends MCP_Admin_List_Table {

	/**
	 * Post type.
	 */
	protected $list_table_type = 'mcp_field';

	/**
	 * Constructor.
	 */
	public function __construct() {
		parent::__construct();
		add_filter( 'disable_months_dropdown', '__return_true' );
		add_filter( 'get_search_query', array( $this, 'search_label' ) );
	}

	/**
	 * Render blank state.
	 */
	protected function render_blank_state() {
		echo '<div class="memberchimp-BlankState">' . mcp_svg_icon( 'database' );
		echo '<h2 class="memberchimp-BlankState-message">' . esc_html__( 'Create unlimited custom fields to fully customize the content of login, registration and profile forms.', 'memberchimp' ) . '</h2>';
		echo '<a class="memberchimp-BlankState-cta button-primary button" href="' . esc_url( admin_url( 'post-new.php?post_type=mcp_field' ) ) . '">' . esc_html__( 'Create a custom field', 'memberchimp' ) . '</a>';
		echo '<a class="memberchimp-BlankState-cta button" target="_blank" href="">' . esc_html__( 'Learn more about custom fields', 'memberchimp' ) . '</a>';
		echo '</div>';
		if ( current_user_can( 'publish_mcp_fields' ) ) {
			echo '<a href="#mcp-create-fields" class="mcp-page-title-action button button-primary">' . esc_html__( 'Create default custom fields', 'memberchimp' ) . '</a>';
		}
	}

	/**
	 * Define primary column.
	 */
	protected function get_primary_column() {
		return 'name';
	}

	/**
	 * Get row actions to show in the list table.
	 */
	protected function get_row_actions( $actions, $post ) {
		$actions = array_merge( array( 'id' => sprintf( esc_html__( 'ID: %d', 'memberchimp' ), $post->ID ) ), $actions );
		if ( $post->post_status == 'publish' ) {
			$actions = mcp_array_insert_after( 'inline hide-if-no-js', $actions, 'duplicate', sprintf( '<a href="' . admin_url( 'post.php?post=' . $post->ID . '&amp;action=duplicate&amp;_wpnonce=' . wp_create_nonce( 'duplicate-field' ) ) . '" class="duplicate_field" aria-label="%s">%s</a>', esc_html__( 'Duplicate this field', 'memberchimp' ), esc_html__( 'Duplicate', 'memberchimp' ) ) );
		}
		return $actions;
	}

	/**
	 * Define which columns are sortable.
	 */
	public function define_sortable_columns( $columns ) {
		$custom = array(
			'name'  	=> 'title',
			'key'		=> 'key',
			'type'		=> 'type',
			'mcp_date'	=> 'date',
		);
		return wp_parse_args( $custom, $columns );
	}

	/**
	 * Define which columns to show on this screen.
	 */
	public function define_columns( $columns ) {
		$show_columns               = array();
		$show_columns['cb']         = $columns['cb'];
		$show_columns['name']  		= esc_html__( 'Name', 'memberchimp' );
		$show_columns['key']  		= esc_html__( 'Key', 'memberchimp' );
		$show_columns['type']  		= esc_html__( 'Type', 'memberchimp' );
		$show_columns['options']  	= esc_html__( 'Options', 'memberchimp' );
		$show_columns['can_view']  	= esc_html__( 'Who can view?', 'memberchimp' );
		$show_columns['mcp_date']  	= esc_html__( 'Date Added', 'memberchimp' );

		return $show_columns;
	}

	/**
	 * Pre-fetch any data for the row each column has access to it. global is there for bw compat.
	 */
	protected function prepare_row_data( $post_id ) {
		global $the_field;

		if ( empty( $this->object ) || $this->object->id !== $post_id ) {
			$this->object = new MCP_Field( $post_id );
			$the_field = $this->object;
		}
	}

	/**
	 * Render column: name.
	 */
	protected function render_name_column() {
		global $post;

		$edit_link = get_edit_post_link( $this->object->id );
		$title     = _draft_or_post_title();

		echo '<strong><a class="row-title" href="' . esc_url( $edit_link ) . '">' . esc_html__( $title, 'memberchimp' ) . '</a>';
		_post_states( $post );
		echo '</strong>';

		get_inline_data( $post );

		/* Custom inline data. */
		echo '
			<div class="hidden" id="memberchimp_inline_' . absint( $this->object->id ) . '">
			</div>
		';
	}

	/**
	 * Render columm: key.
	 */
	protected function render_key_column() {
		if ( $this->object->key ) {
			echo '<span class="mcp-tag">' . esc_html__( $this->object->key ) . '</span>';
		}
	}

	/**
	 * Render columm: type.
	 */
	protected function render_type_column() {
		if ( $this->object->type ) {
			echo mcp_get_field_type( $this->object->type, 'html' );
		}
	}

	/**
	 * Render columm: options.
	 */
	protected function render_options_column() {

		// Required
		if ( $this->object->is_required ) {
			echo '<span class="mcp-icon yes tips" data-tip="' . esc_html__( 'Required', 'memberchimp' ) . '">' . mcp_svg_icon( 'star' ) . '</span>';
		} else {
			echo '<span class="mcp-icon no tips" data-tip="' . esc_html__( 'Optional', 'memberchimp' ) . '">' . mcp_svg_icon( 'star' ) . '</span>';
		}

		// Private
		if ( $this->object->is_private ) {
			echo '<span class="mcp-icon yes tips" data-tip="' . esc_html__( 'Private', 'memberchimp' ) . '">' . mcp_svg_icon( 'shield' ) . '</span>';
		} else {
			echo '<span class="mcp-icon no tips" data-tip="' . esc_html__( 'Public', 'memberchimp' ) . '">' . mcp_svg_icon( 'shield-off' ) . '</span>';
		}

		// Read only
		if ( $this->object->is_readonly ) {
			echo '<span class="mcp-icon yes tips" data-tip="' . esc_html__( 'Read Only', 'memberchimp' ) . '">' . mcp_svg_icon( 'lock' ) . '</span>';
		} else {
			echo '<span class="mcp-icon no tips" data-tip="' . esc_html__( 'Editable', 'memberchimp' ) . '">' . mcp_svg_icon( 'lock' ) . '</span>';
		}

	}

	/**
	 * Render columm: can_view.
	 */
	protected function render_can_view_column() {
		if ( $this->object->can_view ) {
			$can_view = array_merge( array( '_none' => esc_html__( 'No one', 'memberchimp' ), 'owner' => esc_html__( 'Owner', 'memberchimp' ) ), memberchimp_get_roles() );
			foreach( $this->object->can_view as $value ) {
				echo '<span class="mcp-tag">' . esc_html__( $can_view[ $value ] ) . '</span>';
			}
		} else {
			echo '<span class="mcp-tag">' . esc_html__( 'Everyone', 'memberchimp' ) . '</span>';
		}
	}

	/**
	 * Render columm: date.
	 */
	protected function render_mcp_date_column() {
		$date = sprintf( esc_html__( '%1$s at %2$s', 'memberchimp' ), date_i18n( mcp_date_format(), strtotime( get_the_time() ) ), date_i18n( mcp_time_format(), strtotime( get_the_time() ) ) );

		echo $date;
	}

	/**
	 * Change the label when searching
	 */
	public function search_label( $query ) {
		global $pagenow, $typenow;

		if ( 'edit.php' !== $pagenow || 'mcp_field' !== $typenow || ! get_query_var( 'field_search' ) || ! isset( $_GET['s'] ) ) {
			return $query;
		}

		return mcp_clean( wp_unslash( $_GET['s'] ) );
	}

	/**
	 * Render any custom filters and search inputs for the list table.
	 */
	protected function render_filters() {
		?>
		<select name="field_type" id="dropdown_custom_field_type">
			<option value=""><?php esc_html_e( 'Show all types', 'memberchimp' ); ?></option>
			<?php
			$types = memberchimp_get_field_types();

			foreach ( $types as $name => $type ) {
				echo '<option value="' . esc_attr( $name ) . '"';

				if ( isset( $_GET['field_type'] ) ) {
					selected( $name, mcp_clean( wp_unslash( $_GET['field_type'] ) ) );
				}

				echo '>' . esc_html( $type['label'] ) . '</option>';
			}
			?>
		</select>
		<?php
	}

	/**
	 * Handle any query filters.
	 */
	protected function query_filters( $query_vars ) {

		if ( ! empty( $_GET['field_type'] ) ) {
			$query_vars['meta_key']   = 'type';
			$query_vars['meta_value'] = mcp_clean( wp_unslash( $_GET['field_type'] ) );
		}

		if ( isset( $query_vars['orderby'] ) ) {
			if ( 'key' === $query_vars['orderby'] ) {
				$query_vars = array_merge(
					$query_vars,
					array(
						'meta_key' => 'key',
						'orderby'  => 'meta_value',
					)
				);
			}
			if ( 'type' === $query_vars['orderby'] ) {
				$query_vars = array_merge(
					$query_vars,
					array(
						'meta_key' => 'type',
						'orderby'  => 'meta_value',
					)
				);
			}
		}

		// Search.
		if ( ! empty( $query_vars['s'] ) ) {
			$data_store							= MCP_Data_Store::load( 'field' );
			$ids								= $data_store->search_fields( mcp_clean( wp_unslash( $_GET['s'] ) ) );
			$query_vars['post__in']       		= array_merge( $ids, array( 0 ) );
			$query_vars['field_search'] 		= true;
			unset( $query_vars['s'] );
		}

		return $query_vars;
	}

}