<?php
/**
 * List tables: forms.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'MCP_Admin_List_Table', false ) ) {
	include_once 'abstract-class-mcp-admin-list-table.php';
}

/**
 * MCP_Admin_List_Table_Forms class.
 */
class MCP_Admin_List_Table_Forms extends MCP_Admin_List_Table {

	/**
	 * Post type.
	 */
	protected $list_table_type = 'mcp_form';

	/**
	 * Constructor.
	 */
	public function __construct() {
		parent::__construct();
		add_filter( 'disable_months_dropdown', '__return_true' );
		add_filter( 'get_search_query', array( $this, 'search_label' ) );
	}

	/**
	 * Render blank state.
	 */
	protected function render_blank_state() {
		echo '<div class="memberchimp-BlankState">' . mcp_svg_icon( 'file-text' );
		echo '<h2 class="memberchimp-BlankState-message">' . esc_html__( 'Create registration, login and profile forms using a robust and easy-to-use drag and drop form builder.', 'memberchimp' ) . '</h2>';
		echo '<a class="memberchimp-BlankState-cta button-primary button" href="' . esc_url( admin_url( 'post-new.php?post_type=mcp_form' ) ) . '">' . esc_html__( 'Create your first form', 'memberchimp' ) . '</a>';
		echo '<a class="memberchimp-BlankState-cta button" target="_blank" href="">' . esc_html__( 'Learn more about forms', 'memberchimp' ) . '</a>';
		echo '</div>';
		if ( current_user_can( 'publish_mcp_forms' ) ) {
			echo '<a href="#mcp-create-forms" class="mcp-page-title-action button button-primary">' . esc_html__( 'Create default forms', 'memberchimp' ) . '</a>';
		}
	}

	/**
	 * Define primary column.
	 */
	protected function get_primary_column() {
		return 'name';
	}

	/**
	 * Get row actions to show in the list table.
	 */
	protected function get_row_actions( $actions, $post ) {
		if ( empty( $actions ) ) {
			$actions = array();
		}
		$actions = array_merge( array( 'id' => sprintf( esc_html__( 'ID: %d', 'memberchimp' ), $post->ID ) ), $actions );
		if ( $post->post_status == 'publish' && current_user_can( 'publish_mcp_forms' ) ) {
			$actions = mcp_array_insert_after( 'inline hide-if-no-js', $actions, 'duplicate', sprintf( '<a href="' . admin_url( 'post.php?post=' . $post->ID . '&amp;action=duplicate&amp;_wpnonce=' . wp_create_nonce( 'duplicate-form' ) ) . '" class="duplicate_form" aria-label="%s">%s</a>', esc_html__( 'Duplicate this form', 'memberchimp' ), esc_html__( 'Duplicate', 'memberchimp' ) ) );
		}
		return $actions;
	}

	/**
	 * Define which columns are sortable.
	 */
	public function define_sortable_columns( $columns ) {
		$custom = array(
			'name'  	=> 'title',
			'type'		=> 'type',
			'mcp_date'	=> 'date',
		);
		return wp_parse_args( $custom, $columns );
	}

	/**
	 * Define which columns to show on this screen.
	 */
	public function define_columns( $columns ) {
		$show_columns 				= array();
		$show_columns['cb']			= $columns['cb'];
		$show_columns['mcp_status'] = '';
		$show_columns['name']  		= esc_html__( 'Name', 'memberchimp' );
		$show_columns['type']  		= esc_html__( 'Type', 'memberchimp' );
		$show_columns['shortcode']	= esc_html__( 'Shortcode', 'memberchimp' );
		$show_columns['mcp_date']  	= esc_html__( 'Date Added', 'memberchimp' );

		return $show_columns;
	}

	/**
	 * Pre-fetch any data for the row each column has access to it. global is there for bw compat.
	 */
	protected function prepare_row_data( $post_id ) {
		global $the_form;

		if ( empty( $this->object ) || $this->object->id !== $post_id ) {
			$this->object = new MCP_Form( $post_id );
			$the_form = $this->object;
		}
	}

	/**
	 * Render column: mcp_status.
	 */
	protected function render_mcp_status_column() {
		global $post;

		if ( is_mcp_default_form( $this->object ) ) {
			echo '<span class="status-active tips" data-tip="' . esc_attr__( 'Default', 'memberchimp' ) . '">' . mcp_svg_icon( 'check' ) . '</span>';
		} else {
			echo '<span class="status-manual tips" data-tip="' . esc_attr__( 'Manual', 'memberchimp' ) . '">' . mcp_svg_icon( 'arrow-right' ) . '</span>';
		}
	}

	/**
	 * Render column: name.
	 */
	protected function render_name_column() {
		global $post;

		$edit_link = get_edit_post_link( $this->object->id );
		$title     = _draft_or_post_title();

		echo '<strong><a class="row-title" href="' . esc_url( $edit_link ) . '">' . esc_html( $title ) . '</a>';
		_post_states( $post );
		echo '</strong>';

		// Add the role label if the form is specific to a role.
		if ( $this->object->get_role_title() && $this->object->force_role === 'yes' ) {
			echo '<span class="mcp-tag">' . $this->object->get_role_title() . '</span>';
		}

		get_inline_data( $post );

		/* Custom inline data. */
		echo '
			<div class="hidden" id="memberchimp_inline_' . absint( $this->object->id ) . '">
			</div>
		';
	}

	/**
	 * Render columm: type.
	 */
	protected function render_type_column() {
		if ( $this->object->type ) {
			echo mcp_get_form_type( $this->object->type );
			if ( $this->object->endpoint && in_array( $this->object->type, array( 'account' ) ) ) {
				$endpoint = mcp()->query->get_endpoint_title( $this->object->endpoint );
				$endpoint = ! empty( $endpoint ) ? $endpoint : esc_html__( 'Unassigned', 'memberchimp' );
				echo '/ ' . $endpoint;
			}
		}
	}

	/**
	 * Render columm: shortcode.
	 */
	protected function render_shortcode_column() {
		echo $this->object->get_shortcode();
	}

	/**
	 * Render columm: date.
	 */
	protected function render_mcp_date_column() {
		$date = sprintf( esc_html__( '%1$s at %2$s', 'memberchimp' ), date_i18n( mcp_date_format(), strtotime( get_the_time() ) ), date_i18n( mcp_time_format(), strtotime( get_the_time() ) ) );

		echo $date;
	}

	/**
	 * Change the label when searching
	 */
	public function search_label( $query ) {
		global $pagenow, $typenow;

		if ( 'edit.php' !== $pagenow || 'mcp_form' !== $typenow || ! get_query_var( 'form_search' ) || ! isset( $_GET['s'] ) ) {
			return $query;
		}

		return mcp_clean( wp_unslash( $_GET['s'] ) );
	}

	/**
	 * Render any custom filters and search inputs for the list table.
	 */
	protected function render_filters() {
		?>
		<select name="form_type" id="dropdown_form_type_type">
			<option value=""><?php esc_html_e( 'Show all types', 'memberchimp' ); ?></option>
			<?php
			$types = memberchimp_get_form_types();

			foreach ( $types as $name => $type ) {
				echo '<option value="' . esc_attr( $name ) . '"';

				if ( isset( $_GET['form_type'] ) ) {
					selected( $name, mcp_clean( wp_unslash( $_GET['form_type'] ) ) );
				}

				echo '>' . esc_html( $type['label'] ) . '</option>';
			}
			?>
		</select>
		<?php
	}

	/**
	 * Handle any query filters.
	 */
	protected function query_filters( $query_vars ) {

		if ( ! empty( $_GET['form_type'] ) ) {
			$query_vars['meta_key']   = 'type';
			$query_vars['meta_value'] = mcp_clean( wp_unslash( $_GET['form_type'] ) );
		}

		if ( isset( $query_vars['orderby'] ) ) {
			if ( 'type' === $query_vars['orderby'] ) {
				$query_vars = array_merge(
					$query_vars,
					array(
						'meta_key' => 'type',
						'orderby'  => 'meta_value',
					)
				);
			}
		}

		// Search.
		if ( ! empty( $query_vars['s'] ) ) {
			$data_store							= MCP_Data_Store::load( 'form' );
			$ids								= $data_store->search_forms( mcp_clean( wp_unslash( $_GET['s'] ) ) );
			$query_vars['post__in']       		= array_merge( $ids, array( 0 ) );
			$query_vars['form_search'] 			= true;
			unset( $query_vars['s'] );
		}

		return $query_vars;
	}

}