<?php
/**
 * List tables: user roles.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'MCP_Admin_List_Table', false ) ) {
	include_once 'abstract-class-mcp-admin-list-table.php';
}

/**
 * MCP_Admin_List_Table_Memberlists class.
 */
class MCP_Admin_List_Table_Memberlists extends MCP_Admin_List_Table {

	/**
	 * Post type.
	 */
	protected $list_table_type = 'mcp_memberlist';

	/**
	 * Constructor.
	 */
	public function __construct() {
		parent::__construct();
		add_filter( 'disable_months_dropdown', '__return_true' );
		add_filter( 'get_search_query', array( $this, 'search_label' ) );
	}

	/**
	 * Render blank state.
	 */
	protected function render_blank_state() {
		echo '<div class="memberchimp-BlankState">' . mcp_svg_icon( 'users' );
		echo '<h2 class="memberchimp-BlankState-message">' . esc_html__( 'Create unlimited member lists using any criteria and allow community members to search and filter results.', 'memberchimp' ) . '</h2>';
		echo '<a class="memberchimp-BlankState-cta button-primary button" href="' . esc_url( admin_url( 'post-new.php?post_type=mcp_memberlist' ) ) . '">' . esc_html__( 'Create a new member list', 'memberchimp' ) . '</a>';
		echo '<a class="memberchimp-BlankState-cta button" target="_blank" href="">' . esc_html__( 'Learn more about member lists', 'memberchimp' ) . '</a>';
		echo '</div>';
		if ( current_user_can( 'publish_mcp_memberlists' ) ) {
			echo '<a href="#mcp-create-memberlists" class="mcp-page-title-action button button-primary">' . esc_html__( 'Create default member lists', 'memberchimp' ) . '</a>';
		}
	}

	/**
	 * Define primary column.
	 */
	protected function get_primary_column() {
		return 'name';
	}

	/**
	 * Get row actions to show in the list table.
	 */
	protected function get_row_actions( $actions, $post ) {
		$actions = array_merge( array( 'id' => sprintf( esc_html__( 'ID: %d', 'memberchimp' ), $post->ID ) ), $actions );
		if ( $post->post_status == 'publish' ) {
			$actions = mcp_array_insert_after( 'inline hide-if-no-js', $actions, 'duplicate', sprintf( '<a href="' . admin_url( 'post.php?post=' . $post->ID . '&amp;action=duplicate&amp;_wpnonce=' . wp_create_nonce( 'duplicate-memberlist' ) ) . '" class="duplicate_memberlist" aria-label="%s">%s</a>', esc_html__( 'Duplicate this member list', 'memberchimp' ), esc_html__( 'Duplicate', 'memberchimp' ) ) );
		}
		return $actions;
	}

	/**
	 * Define which columns are sortable.
	 */
	public function define_sortable_columns( $columns ) {
		$custom = array(
			'name'  	=> 'title',
			'mcp_date'	=> 'date',
		);
		return wp_parse_args( $custom, $columns );
	}

	/**
	 * Define which columns to show on this screen.
	 */
	public function define_columns( $columns ) {
		$show_columns               = array();
		$show_columns['cb']         = $columns['cb'];
		$show_columns['name']  		= esc_html__( 'Name', 'memberchimp' );
		$show_columns['show_users'] = esc_html__( 'Who to show in this list?', 'memberchimp' );
		$show_columns['shortcode']	= esc_html__( 'Shortcode', 'memberchimp' );
		$show_columns['mcp_date']  	= esc_html__( 'Date Added', 'memberchimp' );

		return $show_columns;
	}

	/**
	 * Pre-fetch any data for the row each column has access to it. global is there for bw compat.
	 */
	protected function prepare_row_data( $post_id ) {
		global $the_memberlist;

		if ( empty( $this->object ) || $this->object->id !== $post_id ) {
			$this->object = new MCP_Memberlist( $post_id );
			$the_memberlist = $this->object;
		}
	}

	/**
	 * Render column: name.
	 */
	protected function render_name_column() {
		global $post;

		$edit_link = get_edit_post_link( $this->object->id );
		$title     = _draft_or_post_title();

		echo '<strong><a class="row-title" href="' . esc_url( $edit_link ) . '">' . esc_html( $title ) . '</a>';
		_post_states( $post );
		echo '</strong>';

		get_inline_data( $post );

		/* Custom inline data. */
		echo '
			<div class="hidden" id="memberchimp_inline_' . absint( $this->object->id ) . '">
			</div>
		';
	}

	/**
	 * Render columm: show_users.
	 */
	protected function render_show_users_column() {
		if ( $this->object->roles ) {
			$roles = array_merge( array( '_all' => esc_html__( 'Everyone excluding admins', 'memberchimp' ) ), memberchimp_get_roles() );
			foreach( $this->object->roles as $value ) {
				echo '<span class="mcp-tag">' . esc_html__( $roles[ $value ] ) . '</span>';
			}
		} else {
			echo '<span class="mcp-tag">' . esc_html__( 'Everyone', 'memberchimp' ) . '</span>';
		}
	}

	/**
	 * Render columm: shortcode.
	 */
	protected function render_shortcode_column() {
		echo $this->object->get_shortcode();
	}

	/**
	 * Render columm: date.
	 */
	protected function render_mcp_date_column() {
		$date = sprintf( esc_html__( '%1$s at %2$s', 'memberchimp' ), date_i18n( mcp_date_format(), strtotime( get_the_time() ) ), date_i18n( mcp_time_format(), strtotime( get_the_time() ) ) );

		echo $date;
	}

	/**
	 * Change the label when searching
	 */
	public function search_label( $query ) {
		global $pagenow, $typenow;

		if ( 'edit.php' !== $pagenow || 'mcp_memberlist' !== $typenow || ! get_query_var( 'memberlist_search' ) || ! isset( $_GET['s'] ) ) {
			return $query;
		}

		return mcp_clean( wp_unslash( $_GET['s'] ) );
	}

	/**
	 * Handle any query filters.
	 */
	protected function query_filters( $query_vars ) {

		if ( isset( $query_vars['orderby'] ) ) {
		}

		// Search.
		if ( ! empty( $query_vars['s'] ) ) {
			$data_store							= MCP_Data_Store::load( 'memberlist' );
			$ids								= $data_store->search_memberlists( mcp_clean( wp_unslash( $_GET['s'] ) ) );
			$query_vars['post__in']       		= array_merge( $ids, array( 0 ) );
			$query_vars['memberlist_search'] 	= true;
			unset( $query_vars['s'] );
		}

		return $query_vars;
	}

}