<?php
/**
 * Meta Box Functions.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Set up field props prior to saving them.
 */
function mcp_setup_field_props( $label = 'label' ) {

	// Props.
	$props['key']         			= isset( $_POST['key'] ) ? sanitize_title( wp_unslash( $_POST['key'] ) ) : '';
	$props['type']         			= isset( $_POST['type'] ) ? mcp_clean( wp_unslash( $_POST['type'] ) ) : '';
	$props['can_view']				= isset( $_POST['can_view'] ) ? mcp_clean( wp_unslash( $_POST['can_view'] ) ) : '';
	$props['mimes']					= isset( $_POST['mimes'] ) ? mcp_clean( wp_unslash( $_POST['mimes'] ) ) : '';
	$props['is_private']			= ! empty( $_POST['is_private'] );
	$props['is_readonly']			= ! empty( $_POST['is_readonly'] );
	$props['is_required']			= ! empty( $_POST['is_required'] );
	$props['autolinks']				= ! empty( $_POST['autolinks'] );
	$props['show_hints']			= ! empty( $_POST['show_hints'] );
	$props['label']					= mcp_clean( wp_unslash( $_POST[ $label ] ) );
	$props['edit_label']			= mcp_clean( wp_unslash( $_POST['edit_label'] ) );
	$props['view_label']			= mcp_clean( wp_unslash( $_POST['view_label'] ) );
	$props['placeholder']			= mcp_clean( wp_unslash( $_POST['placeholder'] ) );
	$props['icon']					= mcp_clean( wp_unslash( $_POST['icon'] ) );
	$props['custom_error']			= mcp_clean( wp_unslash( $_POST['custom_error'] ) );
	$props['ratings']				= mcp_clean( wp_unslash( $_POST['ratings'] ) );
	$props['helper']				= wp_kses_post( wp_unslash( $_POST['helper'] ) );
	$props['blocked_emails']		= wp_kses_post( wp_unslash( $_POST['blocked_emails'] ) );
	$props['allowed_emails']		= wp_kses_post( wp_unslash( $_POST['allowed_emails'] ) );
	$props['dropdown_options']		= wp_kses_post( wp_unslash( $_POST['dropdown_options'] ) );
	$props['checkbox_options']		= wp_kses_post( wp_unslash( $_POST['checkbox_options'] ) );
	$props['radio_options']			= wp_kses_post( wp_unslash( $_POST['radio_options'] ) );

	return apply_filters( 'mcp_setup_field_props', $props );
}

/**
 * Get custom field settings on display.
 */
function mcp_init_custom_field_options() {
	$metabox = new MCP_Meta_Box_Field_Data();
	$metabox->output( new MCP_Field() );
}

/**
 * Add label field for custom field setup in modal display.
 */
function memberchimp_add_title_option() {
	global $the_field;
	if ( get_post_type() != 'mcp_field' ) {
		memberchimp_wp_text_input(
			array(
				'id'          		=> 'label',
				'value'       		=> $the_field->label,
				'label'       		=> esc_html__( 'Label', 'memberchimp' ),
				'description' 		=> esc_html__( 'Please enter a title for this custom field.', 'memberchimp' ),
				'desc_tip'			=> true,
			)
		);
	}
}
add_action( 'memberchimp_before_general_field_options', 'memberchimp_add_title_option', 10 );

/**
 * Output a switch box.
 */
function memberchimp_wp_switch( $field ) {
	global $thepostid, $post;

	$thepostid              = empty( $thepostid ) ? $post->ID : $thepostid;
	$field['class']         = isset( $field['class'] ) ? $field['class'] : '';
	$field['style']         = isset( $field['style'] ) ? $field['style'] : '';
	$field['wrapper_class'] = isset( $field['wrapper_class'] ) ? $field['wrapper_class'] : 'toggle_wrap';
	$field['value']         = isset( $field['value'] ) ? $field['value'] : get_post_meta( $thepostid, $field['id'], true );
	$field['cbvalue']       = isset( $field['cbvalue'] ) ? $field['cbvalue'] : 'yes';
	$field['name']          = isset( $field['name'] ) ? $field['name'] : $field['id'];
	$field['desc_tip']      = isset( $field['desc_tip'] ) ? $field['desc_tip'] : false;

	switch( $field['value'] ) :
		case 'yes' :
			$field['state'] = 1;
			break;
		case 'no' :
			$field['state'] = 0;
			break;
		default :
			$field['value'] = (bool) $field['value'];
			$field['state'] = (bool) $field['value'];
			break;
	endswitch;

	// This will disable toggles for administrator.
	$name = get_post_meta( $thepostid, 'name', true );
	if ( $name == 'administrator' && ( strstr( $field['id'], 'mcp_' ) || $field['id'] == 'manage_memberchimp' ) ) {
		$field['class'] = $field['class'] . ' disabled';
	}

	// Custom attribute handling
	$custom_attributes = array();

	if ( ! empty( $field['custom_attributes'] ) && is_array( $field['custom_attributes'] ) ) {

		foreach ( $field['custom_attributes'] as $attribute => $value ) {
			$custom_attributes[] = esc_attr( $attribute ) . '="' . esc_attr( $value ) . '"';
		}
	}

	echo '<fieldset class="form-field ' . esc_attr( $field['id'] ) . '_field ' . esc_attr( $field['wrapper_class'] ) . '" data-type="switch">
		<label for="' . esc_attr( $field['id'] ) . '">' . wp_kses_post( $field['label'] ) . '</label>';

	echo '<input type="checkbox" name="' . esc_attr( $field['name'] ) . '" id="' . esc_attr( $field['id'] ) . '" value="' . esc_attr( $field['cbvalue'] ) . '" ' . checked( $field['value'], $field['cbvalue'], false ) . '  ' . implode( ' ', $custom_attributes ) . '/> ';
	echo '<div class="mcp-toggle ' . esc_attr( $field['class'] ) . '" style="' . esc_attr( $field['style'] ) . '" data-toggle-on="' . $field['state'] . '"></div>';

	if ( ! empty( $field['description'] ) && false === $field['desc_tip'] ) {
		echo '<span class="description">' . wp_kses_post( $field['description'] ) . '</span>';
	}

	if ( ! empty( $field['description'] ) && false !== $field['desc_tip'] ) {
		echo mcp_help_tip( $field['description'] );
	}

	echo '</fieldset>';
}

/**
 * Output a text input box.
 */
function memberchimp_wp_text_input( $field ) {
	global $thepostid, $post;

	$thepostid              = empty( $thepostid ) ? $post->ID : $thepostid;
	$field['placeholder']   = isset( $field['placeholder'] ) ? $field['placeholder'] : '';
	$field['class']         = isset( $field['class'] ) ? $field['class'] : 'short';
	$field['style']         = isset( $field['style'] ) ? $field['style'] : '';
	$field['wrapper_class'] = isset( $field['wrapper_class'] ) ? $field['wrapper_class'] : '';
	$field['value']         = isset( $field['value'] ) ? $field['value'] : get_post_meta( $thepostid, $field['id'], true );
	$field['name']          = isset( $field['name'] ) ? $field['name'] : $field['id'];
	$field['type']          = isset( $field['type'] ) ? $field['type'] : 'text';
	$field['desc_tip']      = isset( $field['desc_tip'] ) ? $field['desc_tip'] : false;
	$data_type              = empty( $field['data_type'] ) ? '' : $field['data_type'];

	switch ( $data_type ) {
		default :
			break;
	}

	// Custom attribute handling
	$custom_attributes = array();

	if ( ! empty( $field['custom_attributes'] ) && is_array( $field['custom_attributes'] ) ) {

		foreach ( $field['custom_attributes'] as $attribute => $value ) {
			$custom_attributes[] = esc_attr( $attribute ) . '="' . esc_attr( $value ) . '"';
		}
	}

	echo '<fieldset class="form-field ' . esc_attr( $field['id'] ) . '_field ' . esc_attr( $field['wrapper_class'] ) . '" data-type="text">
		<label for="' . esc_attr( $field['id'] ) . '">' . wp_kses_post( $field['label'] ) . '</label>';

	echo '<input type="' . esc_attr( $field['type'] ) . '" class="' . esc_attr( $field['class'] ) . '" style="' . esc_attr( $field['style'] ) . '" name="' . esc_attr( $field['name'] ) . '" id="' . esc_attr( $field['id'] ) . '" value="' . esc_attr( $field['value'] ) . '" placeholder="' . esc_attr( $field['placeholder'] ) . '" ' . implode( ' ', $custom_attributes ) . ' /> ';

	if ( ! empty( $field['description'] ) && false === $field['desc_tip'] ) {
		echo '<div class="clear"></div><span class="description">' . wp_kses_post( $field['description'] ) . '</span>';
	}

	if ( ! empty( $field['description'] ) && false !== $field['desc_tip'] ) {
		echo mcp_help_tip( $field['description'] );
	}

	echo '</fieldset>';
}

/**
 * Output a select input box.
 */
function memberchimp_wp_select( $field ) {
	global $thepostid, $post;

	$thepostid = empty( $thepostid ) ? $post->ID : $thepostid;
	$field     = wp_parse_args(
		$field, array(
			'class'             => 'mcp-select short',
			'style'             => '',
			'wrapper_class'     => '',
			'value'             => get_post_meta( $thepostid, $field['id'], true ),
			'name'              => $field['id'],
			'placeholder'		=> '',
			'desc_tip'          => false,
			'custom_attributes' => array(),
		)
	);

	$wrapper_attributes = array(
		'class' => $field['wrapper_class'] . " form-field {$field['id']}_field",
	);

	$label_attributes = array(
		'for' => $field['id'],
	);

	$field_attributes          			= (array) $field['custom_attributes'];
	$field_attributes['style'] 			= $field['style'];
	$field_attributes['id']    			= $field['id'];
	$field_attributes['name']  			= $field['name'];
	$field_attributes['placeholder'] 	= $field['placeholder'];
	$field_attributes['class'] 			= $field['class'];

	// Multi.
	if ( isset( $field_attributes['multiple'] ) ) {
		$field_attributes['class'] 	= 'mcp-select-multi';
		$field_attributes['name'] 	= $field['name'] . '[]';
	}

	$tooltip     = ! empty( $field['description'] ) && false !== $field['desc_tip'] ? $field['description'] : '';
	$description = ! empty( $field['description'] ) && false === $field['desc_tip'] ? $field['description'] : '';

	if ( $field['value'] && is_array( $field['value'] ) ) {
		$field['options'] = array_replace( array_flip( $field['value'] ), $field['options'] );
	}
	?>
	<fieldset <?php echo mcp_implode_html_attributes( $wrapper_attributes ); ?> data-type="select">
		<label <?php echo mcp_implode_html_attributes( $label_attributes ); ?>><?php echo wp_kses_post( $field['label'] ); ?></label>
		<select <?php echo mcp_implode_html_attributes( $field_attributes ); ?>>
			<?php
			foreach ( $field['options'] as $key => $value ) {
				echo '<option value="' . esc_attr( $key ) . '"' . mcp_selected( $key, $field['value'] ) . '>' . esc_html( $value ) . '</option>';
			}
			?>
		</select>
		<?php if ( $description ) : ?>
			<div class="clear"></div><span class="description"><?php echo wp_kses_post( $description ); ?></span>
		<?php endif; ?>
		<?php if ( $tooltip ) : ?>
			<?php echo mcp_help_tip( $tooltip ); ?>
		<?php endif; ?>
	</fieldset>
	<?php
}

/**
 * Output a textarea input box.
 */
function memberchimp_wp_textarea( $field ) {
	global $thepostid, $post;

	$thepostid              = empty( $thepostid ) ? $post->ID : $thepostid;
	$field['placeholder']   = isset( $field['placeholder'] ) ? $field['placeholder'] : '';
	$field['class']         = isset( $field['class'] ) ? $field['class'] : 'short';
	$field['style']         = isset( $field['style'] ) ? $field['style'] : '';
	$field['wrapper_class'] = isset( $field['wrapper_class'] ) ? $field['wrapper_class'] : '';
	$field['value']         = isset( $field['value'] ) ? $field['value'] : get_post_meta( $thepostid, $field['id'], true );
	$field['desc_tip']      = isset( $field['desc_tip'] ) ? $field['desc_tip'] : false;
	$field['name']          = isset( $field['name'] ) ? $field['name'] : $field['id'];
	$field['rows']          = isset( $field['rows'] ) ? $field['rows'] : 2;
	$field['cols']          = isset( $field['cols'] ) ? $field['cols'] : 20;

	// Custom attribute handling
	$custom_attributes = array();

	if ( ! empty( $field['custom_attributes'] ) && is_array( $field['custom_attributes'] ) ) {

		foreach ( $field['custom_attributes'] as $attribute => $value ) {
			$custom_attributes[] = esc_attr( $attribute ) . '="' . esc_attr( $value ) . '"';
		}
	}

	echo '<fieldset class="form-field ' . esc_attr( $field['id'] ) . '_field ' . esc_attr( $field['wrapper_class'] ) . '" data-type="textarea">
		<label for="' . esc_attr( $field['id'] ) . '">' . wp_kses_post( $field['label'] ) . '</label>';

	echo '<textarea class="' . esc_attr( $field['class'] ) . '" style="' . esc_attr( $field['style'] ) . '"  name="' . esc_attr( $field['name'] ) . '" id="' . esc_attr( $field['id'] ) . '" placeholder="' . esc_attr( $field['placeholder'] ) . '" rows="' . esc_attr( $field['rows'] ) . '" cols="' . esc_attr( $field['cols'] ) . '" ' . implode( ' ', $custom_attributes ) . '>' . esc_textarea( $field['value'] ) . '</textarea> ';

	if ( ! empty( $field['description'] ) && false === $field['desc_tip'] ) {
		echo '<div class="clear"></div><span class="description">' . wp_kses_post( $field['description'] ) . '</span>';
	}

	if ( ! empty( $field['description'] ) && false !== $field['desc_tip'] ) {
		echo mcp_help_tip( $field['description'] );
	}

	echo '</fieldset>';
}

/**
 * Output drag-n-drop tool bar.
 */
function mcp_dragdrop_topbar() {
	global $the_form;
	?>
	<div class="mcp-bld-topbar">
		<div class="mcp-bld-left"><span class="description"></span></div>
		<div class="mcp-bld-right">
			<a href="#" class="button button-primary disabled save_form" data-id="<?php echo absint( $the_form->id ); ?>"><?php echo mcp_svg_icon( 'upload-cloud' ); ?><span><?php esc_html_e( 'Save changes', 'memberchimp' ); ?></span></a>
		</div><div class="clear"></div>
	</div>
	<?php
}

/**
 * Output drag-n-drop default row.
 */
function mcp_dragdrop_default() {
	global $the_form;
	?>
	<div class="mcp-bld-row hidden">
		<?php mcp_dragdrop_row_head(); ?>
		<div class="mcp-bld-cols">
			<div class="mcp-bld-col">
				<div class="mcp-bld-elems">
					<div class="mcp-bld-elem hidden">
						<div class="mcp-bld-left">
							<span class="mcp-bld-action"><a href="#" class="mcp-move-field"><?php echo mcp_svg_icon( 'move' ); ?></a></span>
							<span class="mcp-bld-icon"><?php echo mcp_svg_icon( 'default' ); ?></span>
							<span class="mcp-bld-label">{label}</span>
							<span class="mcp-bld-helper">{key}</span>
						</div>
						<?php mcp_dragdrop_field_actions(); ?>
					</div>
				</div>
				<?php mcp_dragdrop_add(); ?>
			</div>
		</div>

	</div>
	<?php
}

/**
 * Output drag-n-drop rows loop.
 */
function mcp_dragdrop_rows() {
	global $the_form;
	?>
	<?php if ( $the_form->row_count > 0 ) : ?>
	<?php for( $i = 1; $i <= $the_form->row_count; $i++ ) : ?>

	<div class="mcp-bld-row">
		<?php mcp_dragdrop_row_head( $i ); ?>
		<?php mcp_dragdrop_columns( $i ); ?>
	</div>

	<?php endfor; ?>
	<?php endif; ?>
	<?php
}

/**
 * Output drag-n-drop columns loop.
 */
function mcp_dragdrop_columns( $i ) {
	global $the_form;
	?>
	<div class="mcp-bld-cols">

	<?php for( $c = 0; $c < $the_form->cols[$i]['count']; $c++ ) : ?>

	<div class="mcp-bld-col">
		<div class="mcp-bld-elems">
			<?php foreach( (array) $the_form->fields_in( $i, $c ) as $k => $field ) : 
				if ( ! isset( $field['data']['type'] ) ) {
					continue;
				}
				$r = $field['data'];
			?>
			<div class="mcp-bld-elem" <?php echo mcp_get_data_attributes( $r ); ?>>
				<div class="mcp-bld-left">
					<span class="mcp-bld-action"><a href="#" class="mcp-move-field"><?php echo mcp_svg_icon( 'move' ); ?></a></span>
					<span class="mcp-bld-icon"><?php echo mcp_svg_icon( ! empty( $r['icon'] ) ? esc_attr( $r['icon'] ) : 'default' ); ?></span>
					<span class="mcp-bld-label"><?php echo ! empty( $r[ 'label' ] ) ? esc_html( $r['label'] ) : esc_html__( 'No label', 'memberchimp' ); ?></span>
					<span class="mcp-bld-helper"><?php echo esc_attr( $r['key'] ); ?></span>
				</div>
				<?php mcp_dragdrop_field_actions(); ?>
			</div>
			<?php endforeach; ?>
		</div>
		<?php mcp_dragdrop_add(); ?>
	</div>

	<?php endfor; ?>

	</div>
	<?php
}

/**
 * Output drag-n-drop add row.
 */
function mcp_dragdrop_addrow() {
	global $the_form;
	?>
	<div class="mcp-bld-new">
		<a href="#" class="mcp-add-row">
			<?php echo mcp_svg_icon( 'plus' ); ?>
		</a>
	</div>
	<?php
}

/**
 * Output drag-n-drop add element.
 */
function mcp_dragdrop_add() {
	global $the_form;
	?>
	<div class="mcp-bld-add">
		<a href="#mcp-add-element" class="mcp-add-element" rel="modal:open">
			<?php echo mcp_svg_icon( 'plus' ); ?>
		</a>
	</div>
	<?php
}

/**
 * Output drag-n-drop row header.
 */
function mcp_dragdrop_row_head( $i = null ) {
	global $the_form;
	?>
	<div class="mcp-bld-elem">
		<div class="mcp-bld-left">
			<span class="mcp-bld-action"><a href="#" class="mcp-move-row"><?php echo mcp_svg_icon( 'move' ); ?></a></span>
			<span class="mcp-bld-icon"><a href="#" class="mcp-toggle-row"><?php echo mcp_svg_icon( 'chevron-up' ); ?></a></span>
			<span class="mcp-bld-label" data-default="<?php esc_attr_e( 'Untitled Row', 'memberchimp' ); ?>"><?php echo isset( $the_form->rows[ $i - 1 ][ 'title' ] ) ? $the_form->rows[ $i - 1 ][ 'title' ] : ''; ?></span>
		</div>
		<div class="mcp-bld-right">
			<span class="mcp-bld-action"><a href="#mcp-edit-row" class="mcp-edit-row" rel="modal:open"><?php echo mcp_svg_icon( 'edit-2' ); ?></a></span>
			<span class="mcp-bld-action"><a href="#" class="mcp-duplicate-row"><?php echo mcp_svg_icon( 'copy' ); ?></a></span>
			<span class="mcp-bld-action"><a href="#" class="mcp-delete-row"><?php echo mcp_svg_icon( 'trash-2' ); ?></a></span>
		</div><div class="clear"></div>
	</div>
	<?php
}

/**
 * Output drag-n-drop field actions.
 */
function mcp_dragdrop_field_actions() {
	global $the_form;
	?>
	<div class="mcp-bld-right">
		<span class="mcp-bld-action"><a href="#mcp-add-field" class="mcp-edit-field" rel="modal:open"><?php echo mcp_svg_icon( 'edit-2' ); ?></a></span>
		<span class="mcp-bld-action"><a href="#" class="mcp-duplicate-field"><?php echo mcp_svg_icon( 'copy' ); ?></a></span>
		<span class="mcp-bld-action"><a href="#" class="mcp-delete-field"><?php echo mcp_svg_icon( 'trash-2' ); ?></a></span>
	</div>
	<div class="clear"></div>
	<?php
}