<?php
/**
 * Form data.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * MCP_Meta_Box_Form_Data class.
 */
class MCP_Meta_Box_Form_Data {

	/**
	 * Output the metabox.
	 */
	public static function output( $post ) {
		global $thepostid, $the_form;

		$thepostid      = ( isset( $post->ID ) ) ? $post->ID : 0;
		$the_form 		= $thepostid ? new MCP_Form( $thepostid ) : new MCP_Form();

		wp_nonce_field( 'memberchimp_save_data', 'memberchimp_meta_nonce' );

		include 'views/html-form-data-panel.php';
	}

	/**
	 * Return array of tabs to show.
	 */
	private static function get_tabs() {
		$tabs = apply_filters(
			'memberchimp_form_data_tabs', array(
				'general'			=> array(
					'icon'	   => 'settings',
					'label'    => esc_html__( 'General', 'memberchimp' ),
					'target'   => 'general_form_data',
					'class'    => array(),
					'priority' => 10,
				),
				'redirect'			=> array(
					'icon'	   => 'repeat',
					'label'    => esc_html__( 'Redirection', 'memberchimp' ),
					'target'   => 'redirect_form_data',
					'class'    => array(),
					'priority' => 20,
				),
			)
		);

		// Sort tabs based on priority.
		uasort( $tabs, array( __CLASS__, 'tabs_sort' ) );

		return $tabs;
	}

	/**
	 * Callback to sort data tabs on priority.
	 */
	private static function tabs_sort( $a, $b ) {
		if ( ! isset( $a['priority'], $b['priority'] ) ) {
			return -1;
		}

		if ( $a['priority'] == $b['priority'] ) {
			return 0;
		}

		return $a['priority'] < $b['priority'] ? -1 : 1;
	}

	/**
	 * Show tab content/settings.
	 */
	private static function output_tabs() {
		global $post, $thepostid, $the_form;

		include 'views/html-form-data-general.php';
		include 'views/html-form-data-redirect.php';
	}

	/**
	 * Save meta box data.
	 */
	public static function save( $post_id, $post ) {
		global $the_form;
		$props = array();

		$the_form = new MCP_Form( $post_id );

		$props['type']         			= isset( $_POST['_type'] ) ? mcp_clean( wp_unslash( $_POST['_type'] ) ) : '';
		$props['role']         			= isset( $_POST['role'] ) ? mcp_clean( wp_unslash( $_POST['role'] ) ) : '';
		$props['icons']         		= isset( $_POST['icons'] ) ? mcp_clean( wp_unslash( $_POST['icons'] ) ) : '';
		$props['endpoint']         		= isset( $_POST['endpoint'] ) ? mcp_clean( wp_unslash( $_POST['endpoint'] ) ) : '';
		$props['redirect']         		= isset( $_POST['redirect'] ) ? mcp_clean( wp_unslash( $_POST['redirect'] ) ) : '';
		$props['redirect_uri']     		= isset( $_POST['redirect_uri'] ) ? mcp_clean( wp_unslash( $_POST['redirect_uri'] ) ) : '';
		$props['use_ajax']				= isset( $_POST['use_ajax'] ) ? 'yes' : 'no';
		$props['force_role']			= isset( $_POST['force_role'] ) ? 'yes' : 'no';
		$props['hide_cover']			= isset( $_POST['hide_cover'] ) ? 'yes' : 'no';

		// Set as default form?
		if ( isset( $_POST['set_default'] ) && $_POST['set_default'] == 'yes' ) {
			update_option( 'memberchimp_' . $props[ 'type' ] . '_form', $post_id );
		}

		$the_form->save( $props );
	}

}