<?php
/**
 * Member list data.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * MCP_Meta_Box_Memberlist_Data class.
 */
class MCP_Meta_Box_Memberlist_Data {

	/**
	 * Output the metabox.
	 */
	public static function output( $post ) {
		global $thepostid, $the_memberlist;

		$thepostid      = $post->ID;
		$the_memberlist = $thepostid ? new MCP_Memberlist( $thepostid ) : new MCP_Memberlist();

		wp_nonce_field( 'memberchimp_save_data', 'memberchimp_meta_nonce' );

		include 'views/html-memberlist-data-panel.php';
	}

	/**
	 * Return array of tabs to show.
	 */
	private static function get_tabs() {
		$tabs = apply_filters(
			'memberchimp_memberlist_data_tabs', array(
				'general'        => array(
					'icon'	   => 'settings',
					'label'    => esc_html__( 'General', 'memberchimp' ),
					'target'   => 'general_memberlist_data',
					'class'    => array(),
					'priority' => 10,
				),
			)
		);

		// Sort tabs based on priority.
		uasort( $tabs, array( __CLASS__, 'tabs_sort' ) );

		return $tabs;
	}

	/**
	 * Callback to sort data tabs on priority.
	 */
	private static function tabs_sort( $a, $b ) {
		if ( ! isset( $a['priority'], $b['priority'] ) ) {
			return -1;
		}

		if ( $a['priority'] == $b['priority'] ) {
			return 0;
		}

		return $a['priority'] < $b['priority'] ? -1 : 1;
	}

	/**
	 * Show tab content/settings.
	 */
	private static function output_tabs() {
		global $post, $thepostid, $the_memberlist;

		include 'views/html-memberlist-data-general.php';
	}

	/**
	 * Save meta box data.
	 */
	public static function save( $post_id, $post ) {
		global $the_memberlist;
		$props = array();

		$the_memberlist = new MCP_Memberlist( $post_id );

		$props['roles']					= isset( $_POST['roles'] ) ? mcp_clean( wp_unslash( $_POST['roles'] ) ) : '';
		$props['login_required']		= ! empty( $_POST['login_required'] );
		$props['search']				= ! empty( $_POST['search'] );
		$props['guest_search']			= ! empty( $_POST['guest_search'] );
		$props['use_ajax']				= isset( $_POST['use_ajax'] ) ? 'yes' : 'no';
		$props['per_page']				= isset( $_POST['per_page'] ) ? absint( wp_unslash( $_POST['per_page'] ) ) : '';

		$the_memberlist->save( $props );
	}

}