<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
?>

<div id="general_field_data" class="panel memberchimp_options_panel">

	<div class="options_group">
		<?php
		do_action( 'memberchimp_before_general_field_options' );

		memberchimp_wp_text_input(
			array(
				'id'          		=> 'key',
				'value'       		=> $the_field->key,
				'label'       		=> esc_html__( 'Unique key', 'memberchimp' ),
				'placeholder' 		=> _x( 'custom_field', 'placeholder', 'memberchimp' ),
				'description' 		=> esc_html__( 'This is how the custom field will be identified in the system.', 'memberchimp' ),
			)
		);

		memberchimp_wp_select(
			array(
				'id'          		=> 'type',
				'value'       		=> $the_field->type,
				'label'       		=> esc_html__( 'Custom field type', 'memberchimp' ),
				'options'     		=> array_combine( array_keys( memberchimp_get_field_types() ), array_column( memberchimp_get_field_types(), 'label' ) ),
				'description' 		=> esc_html__( 'Controls how this custom field should be filled by the user.', 'memberchimp' ),
				'desc_tip'			=> true,
			)
		);

		// Email
		memberchimp_wp_textarea(
			array(
				'id'          		=> 'blocked_emails',
				'value'       		=> $the_field->blocked_emails,
				'label'       		=> esc_html__( 'Blocked emails', 'memberchimp' ),
				'placeholder' 		=> 'you@domain.com' . "\n" . '*@domain.com' . "\n" . 'domain.com',
				'rows'				=> 5,
				'description'		=> esc_html__( 'Use this option if you want to block specific domains/emails from being used as email.', 'memberchimp' ),
				'wrapper_class' 	=> 'show_if_type_eq_email hidden',
			)
		);

		memberchimp_wp_textarea(
			array(
				'id'          		=> 'allowed_emails',
				'value'       		=> $the_field->allowed_emails,
				'label'       		=> esc_html__( 'Allowed emails', 'memberchimp' ),
				'placeholder' 		=> 'you@domain.com' . "\n" . '*@domain.com' . "\n" . 'domain.com',
				'rows'				=> 5,
				'description'		=> esc_html__( 'Use this option if you want to allow specific domains/emails only to be used as email.', 'memberchimp' ),
				'wrapper_class' 	=> 'show_if_type_eq_email hidden',
			)
		);

		// Textarea
		memberchimp_wp_switch(
			array(
				'id'        		=> 'autolinks',
				'label'				=> esc_html__( 'Auto format links', 'memberchimp' ),
				'value'				=> $the_field->autolinks,
				'cbvalue'			=> 1,
				'description'		=> esc_html__( 'If enabled, urls will be converted to clickable links automatically.', 'memberchimp' ),
				'desc_tip'			=> true,
				'wrapper_class' 	=> 'show_if_type_eq_textarea hidden',
			)
		);

		// Select
		memberchimp_wp_textarea(
			array(
				'id'          		=> 'dropdown_options',
				'value'       		=> $the_field->dropdown_options,
				'label'       		=> esc_html__( 'Dropdown options list', 'memberchimp' ),
				'placeholder' 		=> esc_html__( 'Please enter one option per line.', 'memberchimp' ),
				'rows'				=> 5,
				'wrapper_class' 	=> 'show_if_type_eq_select hidden',
			)
		);

		// Checkbox
		memberchimp_wp_textarea(
			array(
				'id'          		=> 'checkbox_options',
				'value'       		=> $the_field->checkbox_options,
				'label'       		=> esc_html__( 'Checkbox options list', 'memberchimp' ),
				'placeholder' 		=> esc_html__( 'Please enter one option per line.', 'memberchimp' ),
				'rows'				=> 5,
				'wrapper_class' 	=> 'show_if_type_eq_checkbox hidden',
			)
		);

		// Radio
		memberchimp_wp_textarea(
			array(
				'id'          		=> 'radio_options',
				'value'       		=> $the_field->radio_options,
				'label'       		=> esc_html__( 'Radio options list', 'memberchimp' ),
				'placeholder' 		=> esc_html__( 'Please enter one option per line.', 'memberchimp' ),
				'rows'				=> 5,
				'wrapper_class' 	=> 'show_if_type_eq_radio hidden',
			)
		);

		// File
		memberchimp_wp_select(
			array(
				'id'          		=> 'mimes',
				'value'       		=> $the_field->mimes,
				'label'       		=> esc_html__( 'Accepted File Types', 'memberchimp' ),
				'options'     		=> get_allowed_mime_types(),
				'placeholder'		=> esc_html__( 'Use WordPress defaults', 'memberchimp' ),
				'description' 		=> esc_html__( 'If you want to allow specific file types for this upload.', 'memberchimp' ),
				'desc_tip'			=> true,
				'custom_attributes' => array( 'multiple' => 'multiple' ),
				'wrapper_class' 	=> 'show_if_type_eq_file hidden',
			)
		);

		// Rating
		memberchimp_wp_switch(
			array(
				'id'        		=> 'show_hints',
				'label'				=> esc_html__( 'Show rating hints', 'memberchimp' ),
				'value'				=> $the_field->show_hints,
				'cbvalue'			=> 1,
				'description'		=> esc_html__( 'Displays a hint for each rating score.', 'memberchimp' ),
				'desc_tip'			=> true,
				'wrapper_class' 	=> 'show_if_type_eq_rating hidden',
			)
		);

		memberchimp_wp_text_input(
			array(
				'id'          		=> 'ratings',
				'value'       		=> $the_field->ratings,
				'label'       		=> esc_html__( 'Rating hints', 'memberchimp' ),
				'placeholder' 		=> esc_html__( 'Poor, Below average, Average, Good, Excellent', 'memberchimp' ),
				'description' 		=> esc_html__( 'Enter a comma separated list for rating hints.', 'memberchimp' ),
				'desc_tip'			=> true,
				'wrapper_class' 	=> 'show_if_type_eq_rating hidden',
			)
		);
		?>
	</div>

	<?php do_action( 'memberchimp_field_data_general_panel' ); ?>

</div>