<?php
/**
 * Addon Settings.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( class_exists( 'MCP_Settings_Addons', false ) ) {
	return new MCP_Settings_Addons();
}

/**
 * MCP_Settings_Addons class.
 */
class MCP_Settings_Addons extends MCP_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = 'addons';
		$this->label = esc_html__( 'Addons', 'memberchimp' );

		add_filter( 'memberchimp_addon_settings', array( $this, 'addon_settings' ) );
		parent::__construct();
	}

	/**
	 * Get sections.
	 */
	public function get_sections() {
		$sections = array(
			''	=> __( 'Core Addons', 'memberchimp' ),
		);

		return apply_filters( 'memberchimp_get_sections_' . $this->id, $sections );
	}

	/**
	 * Output a color picker input box.
	 */
	public function color_picker( $name, $id, $value, $desc = '' ) {
		echo '<div class="color_box">' . mcp_help_tip( $desc ) . '
			<input name="' . esc_attr( $id ) . '" id="' . esc_attr( $id ) . '" type="text" value="' . esc_attr( $value ) . '" class="colorpick" /> <div id="colorPickerDiv_' . esc_attr( $id ) . '" class="colorpickdiv"></div>
		</div>';
	}

	/**
	 * Output the settings.
	 */
	public function output() {
		global $current_section;

		if ( 'drip' === $current_section ) {
			MCDC_Admin_Dripping::page_output();
		} else {
			$settings = $this->get_settings( $current_section );
			MCP_Admin_Settings::output_fields( $settings );
		}
	}

	/**
	 * Save settings.
	 */
	public function save() {
		global $current_section;

		$settings = $this->get_settings( $current_section );
		MCP_Admin_Settings::save_fields( $settings );

		if ( $current_section ) {
			do_action( 'memberchimp_update_options_' . $this->id . '_' . $current_section );
		} else {

			// Save or unsave activated addons.
			$activated = array();
			$addons = mcp()->addons->get_addons();
			foreach( $addons as $addon => $array ) {
				if ( get_option( 'memberchimp_' . mcp_sanitize_title( $addon ) ) === 'yes' ) {
					$activated[] = $addon;
				}
			}

			delete_option( 'memberchimp_enabled_addons' );
			update_option( 'memberchimp_enabled_addons', $activated );

			// Redirect to make the WordPress aware of newly activated or deactivated addons.
			wp_safe_redirect( add_query_arg( 'mcp_saved', 'true', admin_url( 'admin.php?page=mcp-settings&tab=addons' ) ) );
			exit;
		}
	}

	/**
	 * Get settings array.
	 */
	public function get_settings( $current_section = '' ) {
		$settings = array();

		if ( $current_section == '' ) {
			$settings = apply_filters(
				'memberchimp_addon_settings', array(

				)
			);
		}

		return apply_filters( 'memberchimp_get_settings_' . $this->id, $settings, $current_section );
	}

	/**
	 * Show settings for core addons.
	 */
	public function addon_settings( $settings ) {
		$addons = mcp()->addons;

		if ( empty( $addons ) ) {
			return $settings;
		}

		$settings[] = array(
				'title' => esc_html__( 'Activate / Deactivate Core Addons', 'memberchimp' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'Here you can enable or disable specific plugin features globally. You can turn off features you do not use to keep the core plugin lightweight and as fast as possible.', 'memberchimp' ),
				'id'    => 'addon_options',
		);

		foreach( $addons->get_addons() as $addon => $array ) {
			$settings[] = array(
				'title'    => esc_html( $array[ 'title'] ),
				'id'       => 'memberchimp_' . mcp_sanitize_title( $addon ),
				'default'  => 'no',
				'type'     => 'checkbox',
				'desc'	   => $addons->get_activated_text( $addon, $array ),
				'desc_tip' => esc_html( $array[ 'description' ] ),
			);
		}

		$settings[] = array(
				'type' => 'sectionend',
				'id'   => 'addon_options',
		);

		return $settings;
	}

}

return new MCP_Settings_Addons();