<?php
/**
 * Advanced Settings.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( class_exists( 'MCP_Settings_Advanced', false ) ) {
	return new MCP_Settings_Advanced();
}

/**
 * MCP_Settings_Advanced class.
 */
class MCP_Settings_Advanced extends MCP_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = 'advanced';
		$this->label = esc_html__( 'Advanced', 'memberchimp' );

		add_filter( 'memberchimp_account_page_settings', array( $this, 'account_endpoint_setting' ) );
		parent::__construct();
		$this->notices();
	}

	/**
	 * Get sections.
	 */
	public function get_sections() {
		$sections = array(
			''             	=> esc_html__( 'Page setup', 'memberchimp' ),
			'account'	   	=> esc_html__( 'Account', 'memberchimp' ),
			'profile'	  	=> esc_html__( 'Profile', 'memberchimp' ),
			'security'		=> esc_html__( 'Security', 'memberchimp' ),
			'keys'          => esc_html__( 'REST API', 'memberchimp' ),
		);

		return apply_filters( 'memberchimp_get_sections_' . $this->id, $sections );
	}

	/**
	 * Output a color picker input box.
	 */
	public function color_picker( $name, $id, $value, $desc = '' ) {
		echo '<div class="color_box">' . mcp_help_tip( $desc ) . '
			<input name="' . esc_attr( $id ) . '" id="' . esc_attr( $id ) . '" type="text" value="' . esc_attr( $value ) . '" class="colorpick" /> <div id="colorPickerDiv_' . esc_attr( $id ) . '" class="colorpickdiv"></div>
		</div>';
	}

	/**
	 * Notices.
	 */
	private function notices() {
		if ( isset( $_GET['section'] ) && 'keys' === $_GET['section'] ) {
			MCP_Admin_API_Keys::notices();
		}
	}

	/**
	 * Output the settings.
	 */
	public function output() {
		global $current_section;

		if ( 'keys' === $current_section ) {
			MCP_Admin_API_Keys::page_output();
		} else {
			$settings = $this->get_settings( $current_section );
			MCP_Admin_Settings::output_fields( $settings );
		}
	}

	/**
	 * Save settings.
	 */
	public function save() {
		global $current_section;

		$settings = $this->get_settings( $current_section );
		MCP_Admin_Settings::save_fields( $settings );

		if ( $current_section ) {
			do_action( 'memberchimp_update_options_' . $this->id . '_' . $current_section );
		}
	}

	/**
	 * Get settings array.
	 */
	public function get_settings( $current_section = '' ) {
		if ( 'security' === $current_section ) {
			$settings = apply_filters(
				'memberchimp_security_settings', array(

					array(
						'title' => __( 'Admin security', 'memberchimp' ),
						'type'  => 'title',
						'desc'  => '',
						'id'    => 'general_security_options',
					),

					array(
						'title'    => __( 'WP admin registration', 'memberchimp' ),
						'desc'     => __( 'Block the WordPress admin registration screen', 'memberchimp' ),
						'id'       => 'memberchimp_block_wpregister',
						'default'  => 'no',
						'type'     => 'checkbox',
						'desc_tip' => __( 'When enabled, users will no longer be able to register via WordPress admin screen.<br />Instead, users will be redirected to the front-end registration page set by the plugin.', 'memberchimp' ),
					),

					array(
						'title'    => __( 'WP admin login', 'memberchimp' ),
						'desc'     => __( 'Block the WordPress admin login screen', 'memberchimp' ),
						'id'       => 'memberchimp_block_wplogin',
						'default'  => 'no',
						'type'     => 'checkbox',
						'desc_tip' => __( 'When enabled, users will no longer be able to access the WordPress admin login screen.<br />Be careful to avoid lock out, a default login form and page must be setup already where users will get redirected.', 'memberchimp' ),
					),

					array(
						'title'    => __( 'WP admin password reset', 'memberchimp' ),
						'desc'     => __( 'Block the WordPress admin password reset screen', 'memberchimp' ),
						'id'       => 'memberchimp_block_wplostpassword',
						'default'  => 'no',
						'type'     => 'checkbox',
						'desc_tip' => __( 'When enabled, users will no longer be able to reset their password via the WordPress admin screen.<br />Instead, users will be redirected to the front-end password reset page set by the plugin.', 'memberchimp' ),
					),

					array(
						'type' => 'sectionend',
						'id'   => 'general_security_options',
					)

				)
			);
		} elseif ( 'account' === $current_section ) {
			$settings = apply_filters(
				'memberchimp_account_page_settings', array(

					array(
						'title' => __( 'Account page', 'memberchimp' ),
						'type'  => 'title',
						'desc'  => __( 'The account page needs to be set up so that users can edit their account information and settings.', 'memberchimp' ),
						'id'    => 'account_page_options',
					),

					array(
						'title'    => __( 'My account page', 'memberchimp' ),
						'desc'     => sprintf( __( 'Page contents: [%s]', 'memberchimp' ), 'memberchimp_account' ),
						'id'       => 'memberchimp_account_page_id',
						'type'     => 'single_select_page',
						'default'  => '',
						'class'    => 'mcp-select',
						'desc_tip' => true,
					),

					array(
						'title'    => __( 'Default Account Tab', 'memberchimp' ),
						'id'       => 'memberchimp_default_account_endpoint',
						'default'  => 'edit-account',
						'type'     => 'select',
						'class'    => 'mcp-select',
						'options'  => mcp_get_account_menu_items( array( 'logout' ) ),
						'desc'	   => __( 'This will be the default account tab when user access their account.', 'memberchimp' ),
					),

					array(
						'type' => 'sectionend',
						'id'   => 'account_page_options',
					)

				)
			);
		} elseif ( 'profile' === $current_section ) {
			$settings = apply_filters(
				'memberchimp_profile_page_settings', array(

					array(
						'title' => __( 'Profile page', 'memberchimp' ),
						'type'  => 'title',
						'desc'  => __( 'The profile page set up enables a frontend profile for every users of your site.', 'memberchimp' ),
						'id'    => 'profile_page_options',
					),

					array(
						'title'    => __( 'My profile page', 'memberchimp' ),
						'desc'     => sprintf( __( 'Page contents: [%s]', 'memberchimp' ), 'memberchimp_profile' ),
						'id'       => 'memberchimp_profile_page_id',
						'type'     => 'single_select_page',
						'default'  => '',
						'class'    => 'mcp-select',
						'desc_tip' => true,
					),

					array(
						'type' => 'sectionend',
						'id'   => 'profile_page_options',
					)

				)
			);
		} else {
			$settings = apply_filters(
				'memberchimp_page_setup_options', array(

					array(
						'title' => __( 'Page setup', 'memberchimp' ),
						'type'  => 'title',
						'desc'  => sprintf( wp_kses_post( __( 'These are the default user pages on the frontend. Users will need these pages to register, log in or reset password.<br />
						You can also configure <a href="%s">Account</a> and <a href="%s">Profile</a> pages.', 'memberchimp' ) ), add_query_arg( 'section', 'account' ), add_query_arg( 'section', 'profile' ) ),
						'id'    => 'page_setup_options',
					),

					array(
						'title'    => __( 'Login page', 'memberchimp' ),
						'id'       => 'memberchimp_login_page_id',
						'type'     => 'single_select_page',
						'default'  => '',
						'class'    => 'mcp-select',
					),

					array(
						'title'    => __( 'Registration page', 'memberchimp' ),
						'id'       => 'memberchimp_register_page_id',
						'type'     => 'single_select_page',
						'default'  => '',
						'class'    => 'mcp-select',
					),

					array(
						'title'    => __( 'Lost password page', 'memberchimp' ),
						'id'       => 'memberchimp_lostpassword_page_id',
						'type'     => 'single_select_page',
						'default'  => '',
						'class'    => 'mcp-select',
					),

					array(
						'title'    => __( 'Members directory page', 'memberchimp' ),
						'id'       => 'memberchimp_memberlist_page_id',
						'type'     => 'single_select_page',
						'default'  => '',
						'class'    => 'mcp-select',
					),

					array(
						'type' => 'sectionend',
						'id'   => 'page_setup_options',
					)

				)
			);
		}

		return apply_filters( 'memberchimp_get_settings_' . $this->id, $settings, $current_section );
	}

	/**
	 * Show settings for account endpoints.
	 */
	public function account_endpoint_setting( $settings ) {
		$endpoints = mcp_get_account_endpoints();

		$settings[] = array(
				'title' => esc_html__( 'Account endpoints', 'memberchimp' ),
				'type'  => 'title',
				'desc'  => esc_html__( 'These are the account page endpoints that allow users to view and edit a specific account tab.', 'memberchimp' ),
				'id'    => 'account_endpoint_options',
		);

		foreach( $endpoints as $endpoint_id => $endpoint ) {
			$settings[] = array(
				'title'    => esc_html__( mcp()->query->get_endpoint_title( $endpoint_id ) ),
				'id'       => 'memberchimp_account_' . str_replace( '-', '_', $endpoint_id ) . '_endpoint',
				'default'  => $endpoints[ $endpoint_id ],
				'type'     => 'text',
			);
		}

		$settings[] = array(
				'type' => 'sectionend',
				'id'   => 'account_endpoint_options',
		);

		return $settings;
	}

}

return new MCP_Settings_Advanced();