<?php
/**
 * Customization Settings.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( class_exists( 'MCP_Settings_Customize', false ) ) {
	return new MCP_Settings_Customize();
}

/**
 * MCP_Settings_Customize class.
 */
class MCP_Settings_Customize extends MCP_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = 'customize';
		$this->label = esc_html__( 'Customize', 'memberchimp' );

		parent::__construct();
	}

	/**
	 * Get sections.
	 */
	public function get_sections() {
		$sections = array(
			''             => esc_html__( 'Customization', 'memberchimp' ),
		);

		return apply_filters( 'memberchimp_get_sections_' . $this->id, $sections );
	}

	/**
	 * Output a color picker input box.
	 */
	public function color_picker( $name, $id, $value, $desc = '' ) {
		echo '<div class="color_box">' . mcp_help_tip( $desc ) . '
			<input name="' . esc_attr( $id ) . '" id="' . esc_attr( $id ) . '" type="text" value="' . esc_attr( $value ) . '" class="colorpick" /> <div id="colorPickerDiv_' . esc_attr( $id ) . '" class="colorpickdiv"></div>
		</div>';
	}

	/**
	 * Output the settings.
	 */
	public function output() {
		global $current_section;

		$settings = $this->get_settings( $current_section );

		MCP_Admin_Settings::output_fields( $settings );
	}

	/**
	 * Save settings.
	 */
	public function save() {
		global $current_section;

		$settings = $this->get_settings( $current_section );
		MCP_Admin_Settings::save_fields( $settings );

		if ( $current_section ) {
			do_action( 'memberchimp_update_options_' . $this->id . '_' . $current_section );
		}

	}

	/**
	 * Get settings array.
	 */
	public function get_settings( $current_section = '' ) {
		$settings = apply_filters(
			'memberchimp_customization_settings', array(

				array(
					'title' => esc_html__( 'Profiles', 'memberchimp' ),
					'type'  => 'title',
					'desc'  => '',
					'id'    => 'profile_customization',
				),

				array(
					'title'    => esc_html__( 'User posts tab', 'memberchimp' ),
					'desc'     => esc_html__( 'Show the user posts under their profile', 'memberchimp' ),
					'id'       => 'memberchimp_posts_tab',
					'default'  => 'yes',
					'type'     => 'checkbox',
				),

				array(
					'title'    => esc_html__( 'User comments tab', 'memberchimp' ),
					'desc'     => esc_html__( 'Show the user comments under their profile', 'memberchimp' ),
					'id'       => 'memberchimp_comments_tab',
					'default'  => 'yes',
					'type'     => 'checkbox',
				),

				array(
					'type' => 'sectionend',
					'id'   => 'profile_customization',
				)

			)
		);

		return apply_filters( 'memberchimp_get_settings_' . $this->id, $settings, $current_section );
	}

}

return new MCP_Settings_Customize();