<?php
/**
 * Email Settings.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( class_exists( 'MCP_Settings_Emails', false ) ) {
	return new MCP_Settings_Emails();
}

/**
 * MCP_Settings_Emails class.
 */
class MCP_Settings_Emails extends MCP_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = 'email';
		$this->label = esc_html__( 'Emails', 'memberchimp' );

		add_action( 'memberchimp_admin_field_email_notification', array( $this, 'email_notification_setting' ) );
		parent::__construct();
	}

	/**
	 * Get sections.
	 */
	public function get_sections() {
		$sections = array(
			''             => esc_html__( 'Email options', 'memberchimp' ),
		);

		return apply_filters( 'memberchimp_get_sections_' . $this->id, $sections );
	}

	/**
	 * Output a color picker input box.
	 */
	public function color_picker( $name, $id, $value, $desc = '' ) {
		echo '<div class="color_box">' . mcp_help_tip( $desc ) . '
			<input name="' . esc_attr( $id ) . '" id="' . esc_attr( $id ) . '" type="text" value="' . esc_attr( $value ) . '" class="colorpick" /> <div id="colorPickerDiv_' . esc_attr( $id ) . '" class="colorpickdiv"></div>
		</div>';
	}

	/**
	 * Output the settings.
	 */
	public function output() {
		global $current_section;

		// Define emails that can be customised here.
		$mailer          = mcp()->mailer();
		$email_templates = $mailer->get_emails();

		if ( $current_section ) {
			foreach ( $email_templates as $email_key => $email ) {
				if ( strtolower( $email_key ) === $current_section ) {
					$email->admin_options();
					break;
				}
			}
		} else {
			$settings = $this->get_settings();
			MCP_Admin_Settings::output_fields( $settings );
		}

	}

	/**
	 * Save settings.
	 */
	public function save() {
		global $current_section;

		if ( ! $current_section ) {
			MCP_Admin_Settings::save_fields( $this->get_settings() );

		} else {
			$mcp_emails = MCP_Emails::instance();

			if ( in_array( $current_section, array_map( 'sanitize_title', array_keys( $mcp_emails->get_emails() ) ), true ) ) {
				foreach ( $mcp_emails->get_emails() as $email_id => $email ) {
					if ( sanitize_title( $email_id ) === $current_section ) {
						do_action( 'memberchimp_update_options_' . $this->id . '_' . $email->id );
					}
				}
			} else {
				do_action( 'memberchimp_update_options_' . $this->id . '_' . $current_section );
			}
		}
	}

	/**
	 * Get settings array.
	 */
	public function get_settings( $current_section = '' ) {
		$settings = apply_filters(
			'memberchimp_email_settings', array(

				array(
					'title' => esc_html__( 'Email notifications', 'memberchimp' ),
					'desc'  => esc_html__( 'Email notifications sent by the plugin are listed below. Click on an email to configure it.', 'memberchimp' ),
					'type'  => 'title',
					'id'    => 'email_notification_settings',
				),

				array( 'type' => 'email_notification' ),

				array(
					'type' => 'sectionend',
					'id'   => 'email_notification_settings',
				),

				array(
					'type' => 'sectionend',
					'id'   => 'email_recipient_options',
				),

				array(
					'title' => esc_html__( 'Email sender options', 'memberchimp' ),
					'type'  => 'title',
					'desc'  => '',
					'id'    => 'email_options',
				),

				array(
					'title'    => esc_html__( '"From" name', 'memberchimp' ),
					'desc'     => esc_html__( 'How the sender name appears in outgoing emails.', 'memberchimp' ),
					'id'       => 'memberchimp_email_from_name',
					'type'     => 'text',
					'default'  => esc_attr( get_bloginfo( 'name', 'display' ) ),
					'autoload' => false,
					'desc_tip' => true,
				),

				array(
					'title'             => esc_html__( '"From" address', 'memberchimp' ),
					'desc'              => esc_html__( 'How the sender email appears in outgoing emails.', 'memberchimp' ),
					'id'                => 'memberchimp_email_from_address',
					'type'              => 'email',
					'custom_attributes' => array(
						'multiple' => 'multiple',
					),
					'default'           => get_option( 'admin_email' ),
					'autoload'          => false,
					'desc_tip'          => true,
				),

				array(
					'type' => 'sectionend',
					'id'   => 'email_options',
				),

				array(
					'title' => esc_html__( 'Email template', 'memberchimp' ),
					'type'  => 'title',
					'desc'  => sprintf( wp_kses_post( __( 'This section lets you customize the Member Chimp emails. <a href="%s" target="_blank">Click here to preview your email template</a>.', 'memberchimp' ) ), wp_nonce_url( admin_url( '?preview_memberchimp_mail=true' ), 'preview-mail' ) ),
					'id'    => 'email_template_options',
				),

				array(
					'title'       => esc_html__( 'Header image', 'memberchimp' ),
					'desc'        => esc_html__( 'URL to an image you want to show in the email header. Upload images using the media uploader (Admin > Media).', 'memberchimp' ),
					'id'          => 'memberchimp_email_header_image',
					'type'        => 'text',
					'placeholder' => esc_html__( 'N/A', 'memberchimp' ),
					'default'     => '',
					'autoload'    => false,
					'desc_tip'    => true,
				),

				array(
					'title'       => esc_html__( 'Footer text (HTML)', 'memberchimp' ),
					'desc'        => esc_html__( 'The text to appear in the footer of Member Chimp emails.', 'memberchimp' ) . ' ' . sprintf( esc_html__( 'Available placeholders: %s', 'memberchimp' ), '{site_title}' ),
					'id'          => 'memberchimp_email_footer_text',
					'css'         => 'height:75px;',
					'placeholder' => esc_html__( 'N/A', 'memberchimp' ),
					'type'        => 'textarea',
					'default'     => '{site_title}<br />Built with &#10084; by <a href="https://memberchimp.com/">Member Chimp</a>',
					'autoload'    => false,
					'desc_tip'    => true,
				),

				array(
					'title'       => esc_html__( 'Footer text (Plain)', 'memberchimp' ),
					'desc'        => esc_html__( 'The text to appear in the footer of Member Chimp plain text emails.', 'memberchimp' ) . ' ' . sprintf( esc_html__( 'Available placeholders: %s', 'memberchimp' ), '{site_title}' ),
					'id'          => 'memberchimp_email_footer_text_plain',
					'css'         => 'height:75px;',
					'placeholder' => esc_html__( 'N/A', 'memberchimp' ),
					'type'        => 'textarea',
					'default'     => sprintf( wp_kses_post( __( 'Best regards,%s%s', 'memberchimp' ) ), "\r\n", '{site_title}' ),
					'autoload'    => false,
					'desc_tip'    => true,
				),

				array(
					'title'    => esc_html__( 'Base color', 'memberchimp' ),
					'desc'     => sprintf( wp_kses_post( __( 'The base color for Member Chimp email templates. Default %s.', 'memberchimp' ) ), '<code>#5b9dd9</code>' ),
					'id'       => 'memberchimp_email_base_color',
					'type'     => 'color',
					'css'      => 'width:6em;',
					'default'  => '#5b9dd9',
					'autoload' => false,
					'desc_tip' => true,
				),

				array(
					'title'    => esc_html__( 'Background color', 'memberchimp' ),
					'desc'     => sprintf( wp_kses_post( __( 'The background color for Member Chimp email templates. Default %s.', 'memberchimp' ) ), '<code>#f7f7f7</code>' ),
					'id'       => 'memberchimp_email_background_color',
					'type'     => 'color',
					'css'      => 'width:6em;',
					'default'  => '#f7f7f7',
					'autoload' => false,
					'desc_tip' => true,
				),

				array(
					'title'    => esc_html__( 'Body background color', 'memberchimp' ),
					'desc'     => sprintf( wp_kses_post( __( 'The main body background color. Default %s.', 'memberchimp' ) ), '<code>#ffffff</code>' ),
					'id'       => 'memberchimp_email_body_background_color',
					'type'     => 'color',
					'css'      => 'width:6em;',
					'default'  => '#ffffff',
					'autoload' => false,
					'desc_tip' => true,
				),

				array(
					'title'    => esc_html__( 'Body text color', 'memberchimp' ),
					'desc'     => sprintf( wp_kses_post( __( 'The main body text color. Default %s.', 'memberchimp' ) ), '<code>#66757f</code>' ),
					'id'       => 'memberchimp_email_text_color',
					'type'     => 'color',
					'css'      => 'width:6em;',
					'default'  => '#66757f',
					'autoload' => false,
					'desc_tip' => true,
				),

				array(
					'type' => 'sectionend',
					'id'   => 'email_template_options',
				)

			)
		);

		return apply_filters( 'memberchimp_get_settings_' . $this->id, $settings, $current_section );
	}

	/**
	 * Output email notification settings.
	 */
	public function email_notification_setting() {
		// Define emails that can be customised here.
		$mailer          = mcp()->mailer();
		$email_templates = $mailer->get_emails();

		?>
		<tr valign="top">
		<td class="mcp_emails_wrapper" colspan="2">
			<table class="mcp_emails widefat striped" cellspacing="0">
				<thead>
					<tr>
						<?php
						$columns = apply_filters(
							'memberchimp_email_setting_columns', array(
								'status'     => '',
								'name'       => esc_html__( 'Email', 'memberchimp' ),
								'email_type' => esc_html__( 'Content type', 'memberchimp' ),
								'recipient'  => esc_html__( 'Recipient(s)', 'memberchimp' ),
								'actions'    => '',
							)
						);
						foreach ( $columns as $key => $column ) {
							echo '<th class="mcp-email-settings-table-' . esc_attr( $key ) . '">' . esc_html( $column ) . '</th>';
						}
						?>
						</tr>
					</thead>
					<tbody>
						<?php
						foreach ( $email_templates as $email_key => $email ) {
							echo '<tr>';

							foreach ( $columns as $key => $column ) {

								switch ( $key ) {
									case 'name':
										echo '<td class="mcp-email-settings-table-' . esc_attr( $key ) . '">
										<a href="' . esc_url( admin_url( 'admin.php?page=mcp-settings&tab=email&section=' . strtolower( $email_key ) ) ) . '">' . esc_html( $email->get_title() ) . '</a>
										' . mcp_help_tip( $email->get_description() ) . '
									</td>';
										break;
									case 'recipient':
										echo '<td class="mcp-email-settings-table-' . esc_attr( $key ) . '">
										' . esc_html( $email->is_user_email() ? __( 'User', 'memberchimp' ) : $email->get_recipient() ) . '
									</td>';
										break;
									case 'status':
										echo '<td class="mcp-email-settings-table-' . esc_attr( $key ) . '">';

										if ( $email->is_manual() ) {
											echo '<span class="status-manual tips" data-tip="' . esc_attr__( 'Manually sent', 'memberchimp' ) . '">' . mcp_svg_icon( 'arrow-right' ) . '</span>';
										} elseif ( $email->is_enabled() ) {
											echo '<span class="status-enabled tips" data-tip="' . esc_attr__( 'Enabled', 'memberchimp' ) . '">' . mcp_svg_icon( 'check' ) . '</span>';
										} else {
											echo '<span class="status-disabled tips" data-tip="' . esc_attr__( 'Disabled', 'memberchimp' ) . '">' . mcp_svg_icon( 'x' ) . '</span>';
										}

										echo '</td>';
										break;
									case 'email_type':
										echo '<td class="mcp-email-settings-table-' . esc_attr( $key ) . '">
										' . esc_html( $email->get_content_type() ) . '
									</td>';
										break;
									case 'actions':
										echo '<td class="mcp-email-settings-table-' . esc_attr( $key ) . '">
										<a class="button" href="' . esc_url( admin_url( 'admin.php?page=mcp-settings&tab=email&section=' . strtolower( $email_key ) ) ) . '">' . mcp_svg_icon( 'settings' ) . '</a>
									</td>';
										break;
									default:
										do_action( 'memberchimp_email_setting_column_' . $key, $email );
										break;
								}
							}

							echo '</tr>';
						}
						?>
					</tbody>
				</table>
			</td>
		</tr>
		<?php
	}

}

return new MCP_Settings_Emails();