<?php
/**
 * General Settings.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( class_exists( 'MCP_Settings_General', false ) ) {
	return new MCP_Settings_General();
}

/**
 * MCP_Settings_General class.
 */
class MCP_Settings_General extends MCP_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = 'general';
		$this->label = esc_html__( 'General', 'memberchimp' );

		parent::__construct();
	}

	/**
	 * Get sections.
	 */
	public function get_sections() {
		$sections = array(
			''             => esc_html__( 'General', 'memberchimp' ),
		);

		return apply_filters( 'memberchimp_get_sections_' . $this->id, $sections );
	}

	/**
	 * Output a color picker input box.
	 */
	public function color_picker( $name, $id, $value, $desc = '' ) {
		echo '<div class="color_box">' . mcp_help_tip( $desc ) . '
			<input name="' . esc_attr( $id ) . '" id="' . esc_attr( $id ) . '" type="text" value="' . esc_attr( $value ) . '" class="colorpick" /> <div id="colorPickerDiv_' . esc_attr( $id ) . '" class="colorpickdiv"></div>
		</div>';
	}

	/**
	 * Output the settings.
	 */
	public function output() {
		global $current_section;

		$settings = $this->get_settings( $current_section );

		MCP_Admin_Settings::output_fields( $settings );
	}

	/**
	 * Save settings.
	 */
	public function save() {
		global $current_section;

		// get the old cron value before its saved.
		$delete_recurrence_pre = get_option( 'memberchimp_delete_users_event_recurrence' );

		$settings = $this->get_settings( $current_section );
		MCP_Admin_Settings::save_fields( $settings );

		if ( $current_section ) {
			do_action( 'memberchimp_update_options_' . $this->id . '_' . $current_section );
		}

		// update the cron schedule for deleting rejected users.
		$delete_recurrence = get_option( 'memberchimp_delete_users_event_recurrence' );
		if ( $delete_recurrence != $delete_recurrence_pre ) {
			wp_clear_scheduled_hook( 'memberchimp_delete_rejected_users' );
			if ( $delete_recurrence != '' ) {
				wp_schedule_event( time() + 10, $delete_recurrence, 'memberchimp_delete_rejected_users' );
			}
		}
	}

	/**
	 * Get settings array.
	 */
	public function get_settings( $current_section = '' ) {
		$settings = apply_filters(
			'memberchimp_general_settings', array(

				array(
					'title' => esc_html__( 'Registration options', 'memberchimp' ),
					'type'  => 'title',
					'desc'  => '',
					'id'    => 'registration_options',
				),

				array(
					'title'    => esc_html__( 'New user default role', 'memberchimp' ),
					'desc'     => esc_html__( 'This option lets you define the default role for new users registered through Member Chimp.', 'memberchimp' ),
					'id'       => 'memberchimp_default_role',
					'default'  => 'member',
					'type'     => 'select',
					'class'    => 'mcp-select short',
					'options'  => memberchimp_get_roles(),
					'desc_tip' => true,
				),

				array(
					'title'    => esc_html__( 'Email confirmation', 'memberchimp' ),
					'desc'     => esc_html__( 'Require new users to confirm their email', 'memberchimp' ),
					'id'       => 'memberchimp_email_confirm',
					'default'  => 'no',
					'type'     => 'checkbox',
					'desc_tip' => esc_html__( 'New accounts will be required to confirm their email. This setting can be overwritten by user roles.', 'memberchimp' ),
				),

				array(
					'title'    => esc_html__( 'Admin approval', 'memberchimp' ),
					'desc'     => esc_html__( 'Manually approve new user accounts', 'memberchimp' ),
					'id'       => 'memberchimp_manual_approval',
					'default'  => 'no',
					'type'     => 'checkbox',
					'desc_tip' => esc_html__( 'New accounts will require admin approval. This setting can be overwritten by user roles.', 'memberchimp' ),
				),

				array(
					'type' => 'sectionend',
					'id'   => 'registration_options',
				),

				array(
					'title' => esc_html__( 'User Profiles', 'memberchimp' ),
					'type'  => 'title',
					'desc'  => '',
					'id'    => 'profile_options',
				),

				array(
					'title'    => esc_html__( 'Profile privacy', 'memberchimp' ),
					'desc'     => esc_html__( 'Require users to log in to view profiles', 'memberchimp' ),
					'id'       => 'memberchimp_disable_public_profiles',
					'default'  => 'no',
					'type'     => 'checkbox',
					'desc_tip' => esc_html__( 'Users must log in to view other user profiles. Check this to prevent non-logged users from viewing profiles.', 'memberchimp' ),
				),

				array(
					'type' => 'sectionend',
					'id'   => 'profile_options',
				),

				array(
					'title' => esc_html__( 'Accounts', 'memberchimp' ),
					'type'  => 'title',
					'desc'  => '',
					'id'    => 'account_options',
				),

				array(
					'title'    => esc_html__( 'Username changes', 'memberchimp' ),
					'desc'     => esc_html__( 'Allow username changes in account page', 'memberchimp' ),
					'id'       => 'memberchimp_allow_user_login_change',
					'default'  => 'no',
					'type'     => 'checkbox',
					'desc_tip' => esc_html__( 'Users can edit their username through the account page.', 'memberchimp' ),
				),

				array(
					'title'    => esc_html__( 'Automatically delete rejected users', 'memberchimp' ),
					'id'       => 'memberchimp_delete_users_event_recurrence',
					'default'  => '6_hours',
					'type'     => 'select',
					'class'    => 'mcp-select short',
					'options'  => mcp_get_schedules(),
				),

				array(
					'title'    => esc_html__( 'Automatically delete users who have not confirmed email in', 'memberchimp' ),
					'id'       => 'memberchimp_delete_unconfirmed_emails_duration',
					'default'  => 6,
					'type'     => 'text',
					'css'	   => 'width:60px;',
					'desc'	   => _x( 'hour(s) (Leave blank to never delete accounts)', 'account settings', 'memberchimp' ),
				),

				array(
					'type' => 'sectionend',
					'id'   => 'account_options',
				),

			)
		);

		return apply_filters( 'memberchimp_get_settings_' . $this->id, $settings, $current_section );
	}

}

return new MCP_Settings_General();