<?php
/**
 * Style Settings.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( class_exists( 'MCP_Settings_Style', false ) ) {
	return new MCP_Settings_Style();
}

/**
 * MCP_Settings_Style class.
 */
class MCP_Settings_Style extends MCP_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = 'style';
		$this->label = esc_html__( 'Style', 'memberchimp' );

		parent::__construct();
	}

	/**
	 * Get sections.
	 */
	public function get_sections() {
		$sections = array(
			''             => esc_html__( 'Style', 'memberchimp' ),
		);

		return apply_filters( 'memberchimp_get_sections_' . $this->id, $sections );
	}

	/**
	 * Output a color picker input box.
	 */
	public function color_picker( $name, $id, $value, $desc = '' ) {
		echo '<div class="color_box">' . mcp_help_tip( $desc ) . '
			<input name="' . esc_attr( $id ) . '" id="' . esc_attr( $id ) . '" type="text" value="' . esc_attr( $value ) . '" class="colorpick" /> <div id="colorPickerDiv_' . esc_attr( $id ) . '" class="colorpickdiv"></div>
		</div>';
	}

	/**
	 * Output the settings.
	 */
	public function output() {
		global $current_section;

		$settings = $this->get_settings( $current_section );

		MCP_Admin_Settings::output_fields( $settings );
	}

	/**
	 * Save settings.
	 */
	public function save() {
		global $current_section;

		if ( ! $current_section ) {
			$frontend_styles = MCP_Frontend_Scripts::init();
		} else {
			$settings = $this->get_settings( $current_section );
			MCP_Admin_Settings::save_fields( $settings );

			if ( $current_section ) {
				do_action( 'memberchimp_update_options_' . $this->id . '_' . $current_section );
			}
		}
	}

	/**
	 * Get settings array.
	 */
	public function get_settings( $current_section = '' ) {
		$settings = apply_filters(
			'memberchimp_style_settings', array(

				array(
					'title' => esc_html__( 'Color options', 'memberchimp' ),
					'type'  => 'title',
					'desc'  => '',
					'id'    => 'color_options',
				),

				array(
					'title'    => esc_html__( 'Base color', 'memberchimp' ),
					'desc'     => sprintf( wp_kses_post( __( 'The primary or base color for Member Chimp templates. Default %s.', 'memberchimp' ) ), '<code>#5b9dd9</code>' ),
					'id'       => 'memberchimp_primary_bg_color',
					'type'     => 'color',
					'css'      => 'width:6em;',
					'default'  => '#5b9dd9',
					'desc_tip' => true,
				),

				array(
					'title'    => esc_html__( 'Primary text color', 'memberchimp' ),
					'desc'     => sprintf( wp_kses_post( __( 'The primary text color for Member Chimp templates. Default %s.', 'memberchimp' ) ), '<code>#66757f</code>' ),
					'id'       => 'memberchimp_primary_color',
					'type'     => 'color',
					'css'      => 'width:6em;',
					'default'  => '#66757f',
					'desc_tip' => true,
				),

				array(
					'title'    => esc_html__( 'Alert color', 'memberchimp' ),
					'desc'     => sprintf( wp_kses_post( __( 'The alert color for Member Chimp templates. Default %s.', 'memberchimp.' ) ), '<code>#bb0000</code>' ),
					'id'       => 'memberchimp_alert_color',
					'type'     => 'color',
					'css'      => 'width:6em;',
					'default'  => '#bb0000',
					'desc_tip' => true,
				),

				array(
					'type' => 'sectionend',
					'id'   => 'color_options',
				)

			)
		);

		return apply_filters( 'memberchimp_get_settings_' . $this->id, $settings, $current_section );
	}

}

return new MCP_Settings_Style();