<?php
/**
 * Registers post types and taxonomies.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * MCP_Post_Types class.
 */
class MCP_Post_Types {

	/**
	 * Hook in methods.
	 */
	public static function init() {
		add_action( 'init', array( __CLASS__, 'register_post_types' ), 5 );
		add_action( 'memberchimp_after_register_post_type', array( __CLASS__, 'maybe_flush_rewrite_rules' ) );
		add_action( 'memberchimp_flush_rewrite_rules', array( __CLASS__, 'flush_rewrite_rules' ) );
	}

	/**
	 * Register core post types.
	 */
	public static function register_post_types() {
		if ( ! is_blog_installed() || post_type_exists( 'mcp_form' ) ) {
			return;
		}

		do_action( 'memberchimp_register_post_types' );

		register_post_type(
			'mcp_form',
			apply_filters(
				'memberchimp_register_post_type_form',
				array(
					'labels'             => array(
						'name'                  => esc_html__( 'Forms', 'memberchimp' ),
						'singular_name'         => esc_html__( 'Form', 'memberchimp' ),
						'menu_name'             => esc_html_x( 'Forms', 'Admin menu name', 'memberchimp' ),
						'add_new'               => esc_html__( 'Add form', 'memberchimp' ),
						'add_new_item'          => esc_html__( 'Add new form', 'memberchimp' ),
						'edit'                  => esc_html__( 'Edit', 'memberchimp' ),
						'edit_item'             => esc_html__( 'Edit form', 'memberchimp' ),
						'new_item'              => esc_html__( 'New form', 'memberchimp' ),
						'view_item'             => esc_html__( 'View form', 'memberchimp' ),
						'search_items'          => esc_html__( 'Search forms', 'memberchimp' ),
						'not_found'             => esc_html__( 'No forms found', 'memberchimp' ),
						'not_found_in_trash'    => esc_html__( 'No forms found in trash', 'memberchimp' ),
						'parent'                => esc_html__( 'Parent form', 'memberchimp' ),
						'filter_items_list'     => esc_html__( 'Filter forms', 'memberchimp' ),
						'items_list_navigation' => esc_html__( 'Forms navigation', 'memberchimp' ),
						'items_list'            => esc_html__( 'Forms list', 'memberchimp' ),
					),
					'description'         => esc_html__( 'This is where you can add new forms to customize your community pages.', 'memberchimp' ),
					'public'              => false,
					'show_ui'             => true,
					'capability_type'     => 'mcp_form',
					'map_meta_cap'        => true,
					'publicly_queryable'  => false,
					'exclude_from_search' => true,
					'show_in_menu'        => current_user_can( 'manage_memberchimp' ) ? 'memberchimp' : true,
					'hierarchical'        => false,
					'rewrite'             => false,
					'query_var'           => false,
					'supports'            => array( 'title' ),
					'show_in_nav_menus'   => false,
					'show_in_admin_bar'   => true,
				)
			)
		);

		register_post_type(
			'mcp_field',
			apply_filters(
				'memberchimp_register_post_type_field',
				array(
					'labels'             => array(
						'name'                  => esc_html__( 'Custom fields', 'memberchimp' ),
						'singular_name'         => esc_html__( 'Custom field', 'memberchimp' ),
						'menu_name'             => esc_html_x( 'Custom fields', 'Admin menu name', 'memberchimp' ),
						'add_new'               => esc_html__( 'Add custom field', 'memberchimp' ),
						'add_new_item'          => esc_html__( 'Add new custom field', 'memberchimp' ),
						'edit'                  => esc_html__( 'Edit', 'memberchimp' ),
						'edit_item'             => esc_html__( 'Edit custom field', 'memberchimp' ),
						'new_item'              => esc_html__( 'New custom field', 'memberchimp' ),
						'view_item'             => esc_html__( 'View custom field', 'memberchimp' ),
						'search_items'          => esc_html__( 'Search custom fields', 'memberchimp' ),
						'not_found'             => esc_html__( 'No custom fields found', 'memberchimp' ),
						'not_found_in_trash'    => esc_html__( 'No custom fields found in trash', 'memberchimp' ),
						'parent'                => esc_html__( 'Parent custom field', 'memberchimp' ),
						'filter_items_list'     => esc_html__( 'Filter custom fields', 'memberchimp' ),
						'items_list_navigation' => esc_html__( 'Custom fields navigation', 'memberchimp' ),
						'items_list'            => esc_html__( 'Custom fields list', 'memberchimp' ),
					),
					'description'         => esc_html__( 'This is where you can manage custom fields.', 'memberchimp' ),
					'public'              => false,
					'show_ui'             => true,
					'capability_type'     => 'mcp_field',
					'map_meta_cap'        => true,
					'publicly_queryable'  => false,
					'exclude_from_search' => true,
					'show_in_menu'        => current_user_can( 'manage_memberchimp' ) ? 'memberchimp' : true,
					'hierarchical'        => false,
					'rewrite'             => false,
					'query_var'           => false,
					'supports'            => array( 'title' ),
					'show_in_nav_menus'   => false,
					'show_in_admin_bar'   => true,
				)
			)
		);

		register_post_type(
			'mcp_role',
			apply_filters(
				'memberchimp_register_post_type_role',
				array(
					'labels'             => array(
						'name'                  => esc_html__( 'User roles', 'memberchimp' ),
						'singular_name'         => esc_html__( 'User role', 'memberchimp' ),
						'menu_name'             => esc_html_x( 'User roles', 'Admin menu name', 'memberchimp' ),
						'add_new'               => esc_html__( 'Add user role', 'memberchimp' ),
						'add_new_item'          => esc_html__( 'Add new user role', 'memberchimp' ),
						'edit'                  => esc_html__( 'Edit', 'memberchimp' ),
						'edit_item'             => esc_html__( 'Edit user role', 'memberchimp' ),
						'new_item'              => esc_html__( 'New user role', 'memberchimp' ),
						'view_item'             => esc_html__( 'View user role', 'memberchimp' ),
						'search_items'          => esc_html__( 'Search user roles', 'memberchimp' ),
						'not_found'             => esc_html__( 'No user roles found', 'memberchimp' ),
						'not_found_in_trash'    => esc_html__( 'No user roles found in trash', 'memberchimp' ),
						'parent'                => esc_html__( 'Parent user role', 'memberchimp' ),
						'filter_items_list'     => esc_html__( 'Filter user roles', 'memberchimp' ),
						'items_list_navigation' => esc_html__( 'User roles navigation', 'memberchimp' ),
						'items_list'            => esc_html__( 'User roles list', 'memberchimp' ),
					),
					'description'         => esc_html__( 'This is where you can add and manage your community roles.', 'memberchimp' ),
					'public'              => false,
					'show_ui'             => true,
					'capability_type'     => 'mcp_role',
					'map_meta_cap'        => true,
					'publicly_queryable'  => false,
					'exclude_from_search' => true,
					'show_in_menu'        => current_user_can( 'manage_memberchimp' ) ? 'memberchimp' : true,
					'hierarchical'        => false,
					'rewrite'             => false,
					'query_var'           => false,
					'supports'            => array( 'title' ),
					'show_in_nav_menus'   => false,
					'show_in_admin_bar'   => true,
				)
			)
		);

		register_post_type(
			'mcp_memberlist',
			apply_filters(
				'memberchimp_register_post_type_memberlist',
				array(
					'labels'             => array(
						'name'                  => esc_html__( 'Member lists', 'memberchimp' ),
						'singular_name'         => esc_html__( 'Member list', 'memberchimp' ),
						'menu_name'             => esc_html_x( 'Member lists', 'Admin menu name', 'memberchimp' ),
						'add_new'               => esc_html__( 'Add member list', 'memberchimp' ),
						'add_new_item'          => esc_html__( 'Add new member list', 'memberchimp' ),
						'edit'                  => esc_html__( 'Edit', 'memberchimp' ),
						'edit_item'             => esc_html__( 'Edit member list', 'memberchimp' ),
						'new_item'              => esc_html__( 'New member list', 'memberchimp' ),
						'view_item'             => esc_html__( 'View member list', 'memberchimp' ),
						'search_items'          => esc_html__( 'Search member lists', 'memberchimp' ),
						'not_found'             => esc_html__( 'No member lists found', 'memberchimp' ),
						'not_found_in_trash'    => esc_html__( 'No member lists found in trash', 'memberchimp' ),
						'parent'                => esc_html__( 'Parent member list', 'memberchimp' ),
						'filter_items_list'     => esc_html__( 'Filter member lists', 'memberchimp' ),
						'items_list_navigation' => esc_html__( 'Member lists navigation', 'memberchimp' ),
						'items_list'            => esc_html__( 'Member lists list', 'memberchimp' ),
					),
					'description'         => esc_html__( 'This is where you can add and manage your community roles.', 'memberchimp' ),
					'public'              => false,
					'show_ui'             => true,
					'capability_type'     => 'mcp_memberlist',
					'map_meta_cap'        => true,
					'publicly_queryable'  => false,
					'exclude_from_search' => true,
					'show_in_menu'        => current_user_can( 'manage_memberchimp' ) ? 'memberchimp' : true,
					'hierarchical'        => false,
					'rewrite'             => false,
					'query_var'           => false,
					'supports'            => array( 'title' ),
					'show_in_nav_menus'   => false,
					'show_in_admin_bar'   => true,
				)
			)
		);

		do_action( 'memberchimp_after_register_post_type' );
	}

	/**
	 * Flush rules if the event is queued.
	 */
	public static function maybe_flush_rewrite_rules() {
		if ( 'yes' === get_option( 'memberchimp_queue_flush_rewrite_rules' ) ) {
			update_option( 'memberchimp_queue_flush_rewrite_rules', 'no' );
			self::flush_rewrite_rules();
		}
	}

	/**
	 * Flush rewrite rules.
	 */
	public static function flush_rewrite_rules() {
		flush_rewrite_rules();
	}

}

MCP_Post_types::init();