<?php
/**
 * Member Chimp
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Main class.
 */
final class Memberchimp {

	/**
	 * Member Chimp version.
	 */
	public $version = '1.0.16';

	/**
	 * The single instance of the class.
	 */
	protected static $_instance = null;

	/**
	 * Countries instance.
	 */
	public $countries = null;

	/**
	 * Translations instance.
	 */
	public $translations = null;

	/**
	 * API Object.
	 */
	public $api;

	/**
	 * Session Object.
	 */
	public $session;

	/**
	 * Main Instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * Auto-load in-accessible properties on demand.
	 */
	public function __get( $key ) {
		if ( in_array( $key, array( 'mailer' ), true ) ) {
			return $this->$key();
		}
	}

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->define_constants();
		$this->includes();
		$this->init_hooks();

		do_action( 'memberchimp_loaded' );
	}

	/**
	 * Hook into actions and filters.
	 */
	public function init_hooks() {
		register_activation_hook( MCP_PLUGIN_FILE, array( 'MCP_Install', 'install' ) );
		add_action( 'after_setup_theme', array( $this, 'include_template_functions' ), 11 );
		add_action( 'init', array( $this, 'init' ), 0 );
		add_action( 'init', array( 'MCP_Shortcodes', 'init' ) );
	}

	/**
	 * Init when WordPress Initialises.
	 */
	public function init() {
		// Before init action.
		do_action( 'before_memberchimp_init' );

		// Set up localisation.
		$this->load_plugin_textdomain();

		// Set up core addons.
		$this->load_core_addons();

		// Load class instances.
		$this->countries      = new MCP_Countries();

		// Init action.
		do_action( 'memberchimp_init' );
	}

	/**
	 * Define Constants.
	 */
	public function define_constants() {
		$this->define( 'MCP_ABSPATH', dirname( MCP_PLUGIN_FILE ) . '/' );
		$this->define( 'MCP_PLUGIN_BASENAME', plugin_basename( MCP_PLUGIN_FILE ) );
		$this->define( 'MCP_VERSION', $this->version );
		$this->define( 'MCP_TEMPLATE_DEBUG_MODE', false );
	}

	/**
	 * Define constant if not already set.
	 */
	public function define( $name, $value ) {
		if ( ! defined( $name ) ) {
			define( $name, $value );
		}
	}

	/**
	 * What type of request is this?
	 */
	public function is_request( $type ) {
		switch ( $type ) {
			case 'admin':
				return is_admin();
			case 'ajax':
				return defined( 'DOING_AJAX' );
			case 'cron':
				return defined( 'DOING_CRON' );
			case 'frontend':
				return ( ! is_admin() || defined( 'DOING_AJAX' ) ) && ! defined( 'DOING_CRON' ) && ! defined( 'REST_REQUEST' );
		}
	}

	/**
	 * Include required core files used in admin and on the frontend.
	 */
	public function includes() {

		/**
		 * Class autoloader.
		 */
		include_once MCP_ABSPATH . 'includes/class-mcp-autoloader.php';

		/**
		 * Abstract classes.
		 */
		include_once MCP_ABSPATH . 'includes/abstracts/abstract-mcp-settings-api.php';

		/**
		 * Core classes.
		 */
		include_once MCP_ABSPATH . 'includes/mcp-core-functions.php';
		include_once MCP_ABSPATH . 'includes/class-mcp-ajax.php';
		include_once MCP_ABSPATH . 'includes/class-mcp-post-types.php';
		include_once MCP_ABSPATH . 'includes/class-mcp-install.php';
		include_once MCP_ABSPATH . 'includes/class-mcp-shortcodes.php';
		include_once MCP_ABSPATH . 'includes/class-mcp-query.php';
		include_once MCP_ABSPATH . 'includes/class-mcp-background-emailer.php';
		include_once MCP_ABSPATH . 'includes/class-mcp-countries.php';
		include_once MCP_ABSPATH . 'includes/class-mcp-session.php';
		include_once MCP_ABSPATH . 'includes/api/class-mcp-api.php';

		/**
		 * Data stores
		 */
		include_once MCP_ABSPATH . 'includes/class-mcp-data-store.php';
		include_once MCP_ABSPATH . 'includes/data-stores/class-mcp-data-store-wp.php';
		include_once MCP_ABSPATH . 'includes/data-stores/class-mcp-form-data-store.php';
		include_once MCP_ABSPATH . 'includes/data-stores/class-mcp-field-data-store.php';
		include_once MCP_ABSPATH . 'includes/data-stores/class-mcp-role-data-store.php';
		include_once MCP_ABSPATH . 'includes/data-stores/class-mcp-memberlist-data-store.php';
		include_once MCP_ABSPATH . 'includes/data-stores/class-mcp-posts-data-store.php';
		include_once MCP_ABSPATH . 'includes/data-stores/class-mcp-pages-data-store.php';
		include_once MCP_ABSPATH . 'includes/data-stores/class-mcp-categories-data-store.php';

		/**
		 * Libraries
		 */
		include_once MCP_ABSPATH . 'includes/libraries/nav-menus/menu-item-custom-fields.php';

		if ( $this->is_request( 'admin' ) ) {
			include_once MCP_ABSPATH . 'includes/admin/class-mcp-admin.php';
		}

		// Front-end use only.
		if ( $this->is_request( 'frontend' ) ) {
			$this->frontend_includes();
		}

		$this->query 	= new MCP_Query();
		$this->api   	= new MCP_API();
		$this->session	= new MCP_Session();
	}

	/**
	 * Include required frontend files.
	 */
	public function frontend_includes() {
		include_once MCP_ABSPATH . 'includes/mcp-notice-functions.php';
		include_once MCP_ABSPATH . 'includes/mcp-template-hooks.php';
		include_once MCP_ABSPATH . 'includes/mcp-upload-hooks.php';
		include_once MCP_ABSPATH . 'includes/mcp-field-hooks.php';
		include_once MCP_ABSPATH . 'includes/mcp-memberlist-hooks.php';
		include_once MCP_ABSPATH . 'includes/mcp-user-hooks.php';
		include_once MCP_ABSPATH . 'includes/class-mcp-frontend-scripts.php';
		include_once MCP_ABSPATH . 'includes/class-mcp-form-handler.php';
		include_once MCP_ABSPATH . 'includes/class-mcp-uploader.php';
	}

	/**
	 * Function used to Init Template Functions
	 */
	public function include_template_functions() {
		include_once MCP_ABSPATH . 'includes/mcp-template-functions.php';
	}

	/**
	 * Load Localisation files.
	 *
	 * Note: the first-loaded translation file overrides any following ones if the same translation is present.
	 *
	 * Locales found in:
	 *      - WP_LANG_DIR/memberchimp/memberchimp-LOCALE.mo
	 *      - WP_LANG_DIR/plugins/memberchimp-LOCALE.mo
	 */
	public function load_plugin_textdomain() {
		$locale = is_admin() && function_exists( 'get_user_locale' ) ? get_user_locale() : get_locale();
		$locale = apply_filters( 'plugin_locale', $locale, 'memberchimp' );

		unload_textdomain( 'memberchimp' );
		load_textdomain( 'memberchimp', WP_LANG_DIR . '/memberchimp/memberchimp-' . $locale . '.mo' );
		load_plugin_textdomain( 'memberchimp', false, plugin_basename( dirname( MCP_PLUGIN_FILE ) ) . '/i18n/languages' );

		// Load translations from options.
		$this->translations = get_option( 'memberchimp_translations' );
	}

	/**
	 * Load enabled addons into memory.
	 */
	public function load_core_addons() {
		$this->addons = new MCP_Addons();

		$enabled = $this->addons->get_enabled_addons();
		if ( $enabled ) {
			foreach( $enabled as $addon ) {
				$path = MCP_ABSPATH . 'includes/addons/' . $addon . '/' . $addon . '.php';
				if ( file_exists( $path ) ) {
					include_once $path;
				}
			}
		}
	}

	/**
	 * Get the plugin url.
	 */
	public function plugin_url() {
		return untrailingslashit( plugins_url( '/', MCP_PLUGIN_FILE ) );
	}

	/**
	 * Get the plugin path.
	 */
	public function plugin_path() {
		return untrailingslashit( plugin_dir_path( MCP_PLUGIN_FILE ) );
	}

	/**
	 * Get the template path.
	 */
	public function template_path() {
		return apply_filters( 'memberchimp_template_path', 'memberchimp/' );
	}

	/**
	 * Get Ajax URL.
	 */
	public function ajax_url() {
		return admin_url( 'admin-ajax.php', 'relative' );
	}

	/**
	 * Email class.
	 */
	public function mailer() {
		return MCP_Emails::instance();
	}

}