<?php
/**
 * Account Functions
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Get account endpoints.
 */
function mcp_get_account_endpoints() {
	$endpoints = array(
		'edit-account'				=> get_option( 'memberchimp_account_edit_account_endpoint', 'edit-account' ),
		'edit-password'       		=> get_option( 'memberchimp_account_edit_password_endpoint', 'edit-password' ),
		'privacy'              		=> get_option( 'memberchimp_account_privacy_endpoint', 'privacy' ),
		'email-notifications'		=> get_option( 'memberchimp_account_email_notifications_endpoint', 'email-notifications' ),
		'blocked'					=> get_option( 'memberchimp_account_blocked_endpoint', 'blocked' ),
	);

	$endpoints = apply_filters( 'memberchimp_get_account_endpoints', ( array ) $endpoints );

	return $endpoints;
}

/**
 * Get the account endpoint icon.
 */
function mcp_get_account_endpoint_icon( $endpoint ) {
	$icon = null;

	switch( $endpoint ) {
		case 'edit-account' :
			$icon = 'settings';
		break;
		case 'edit-password' :
			$icon = 'key';
		break;
		case 'privacy' :
			$icon = 'lock';
		break;
		case 'email-notifications' :
			$icon = 'mail';
		break;
		case 'blocked' :
			$icon = 'slash';
		break;
	}

	$icon = apply_filters( 'mcp_get_account_endpoint_icon', $icon );

	if ( ! empty( $icon ) ) {
		echo mcp_svg_icon( esc_attr( $icon ) );
	}
}

/**
 * Get account default endpoint.
 */
function mcp_get_account_default_endpoint() {
	$endpoint = get_option( 'memberchimp_default_account_endpoint', 'edit-account' );

	if ( empty( trim( $endpoint ) ) ) {
		$endpoint = 'edit-account';
	}

	return apply_filters( 'mcp_get_account_default_endpoint', $endpoint );
}

/**
 * Get account endpoint URL.
 */
function mcp_get_account_endpoint_url( $endpoint ) {
	if ( 'logout' === $endpoint ) {
		return mcp_logout_url();
	}

	return mcp_get_endpoint_url( $endpoint, '', mcp_get_page_permalink( 'account' ) );
}

/**
 * Get account endpoint form.
 */
function mcp_get_account_endpoint_form() {
	$endpoint = mcp()->query->get_current_endpoint();

	if ( $endpoint ) {
		return get_option( 'memberchimp_account_' . mcp_sanitize_title( $endpoint ) . '_form' );
	}

	return get_option( 'memberchimp_account_' . mcp_sanitize_title( mcp_get_account_default_endpoint() ) . '_form' );
}

/**
 * Get account menu items.
 */
function mcp_get_account_menu_items( $exclude = array() ) {

	$endpoints = mcp_get_account_endpoints();
	$default = mcp_get_account_default_endpoint();

	// Remove missing endpoints.
	foreach ( $endpoints as $endpoint_id => $endpoint ) {
		if ( empty( $endpoint ) ) {
			unset( $items[ $endpoint_id ] );
		}
		$items[ $endpoint_id ] = mcp()->query->get_endpoint_title( $endpoint_id );
	}

	// Make sure that default endpoint comes on top.
	$default_endpoint = $items[ $default ];
	unset( $items[ $default ] );
	$items = array_merge( array( $default => $default_endpoint ) , $items );

	// Exclude items from menu.
	if ( ! empty( $exclude ) ) {
		foreach( $exclude as $item ) {
			unset( $items[ $item ] );
		}
	}

	return apply_filters( 'memberchimp_account_menu_items', $items, $endpoints );
}

/**
 * Get account menu item classes.
 */
function mcp_get_account_menu_item_classes( $endpoint ) {
	global $wp;

	$classes = array(
		'memberchimp-account-navigation-link',
		'memberchimp-account-navigation-link--' . $endpoint,
	);

	// Set current item class.
	$current = isset( $wp->query_vars[ $endpoint ] );

	// Fallback to default content item.
	if ( mcp_get_account_default_endpoint() === $endpoint && ( isset( $wp->query_vars['page'] ) || empty( $wp->query_vars ) ) ) {
		$current = true;
	}

	if ( $current ) {
		$classes[] = 'is-active';
	}

	$classes = apply_filters( 'memberchimp_account_menu_item_classes', $classes, $endpoint );

	return implode( ' ', array_map( 'sanitize_html_class', $classes ) );
}