<?php
/**
 * Date Functions.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Display the post date and time within the loop.
 */
function mcb_the_date( $date = null ) {
	if ( ! $date ) {
		echo sprintf( esc_html__( '%1$s at %2$s', 'memberchimp' ), date_i18n( mcp_date_format(), strtotime( get_the_date() ) ), date_i18n( mcp_time_format(), strtotime( get_the_time() ) ) );
	} else {
		echo sprintf( esc_html__( '%1$s at %2$s', 'memberchimp' ), date_i18n( mcp_date_format(), strtotime( $date ) ), date_i18n( mcp_time_format(), strtotime( $date ) ) );
	}
}

/**
 * Display a more human readable date format for post.
 */
function mcb_the_date_diff( $time = null ) {
	if ( $time ) {
		$timestamp = strtotime( $time );
	} else {
		$timestamp = get_the_time( 'U' );
	}
	echo sprintf( __( '%s ago', 'memberchimp' ), human_time_diff( $timestamp, current_time( 'timestamp' ) ) );
}

/**
 * Get default date format. Used mostly by admin pages.
 */
function mcp_get_default_date_format() {
	return apply_filters( 'mcp_get_default_date_format', 'j/n/Y g:ia' );
}

/**
 * Get the date within the loop.
 */
function mcp_get_the_date() {
	return get_the_date( mcp_get_default_date_format() );
}

/**
 * Get date format.
 */
function mcp_get_date_format() {
	return apply_filters( 'mcp_get_date_format', 'j M Y' );
}

/**
 * Date Format - Allows to change date format for plugin use.
 */
function mcp_date_format() {
	return apply_filters( 'memberchimp_date_format', get_option( 'date_format' ) );
}

/**
 * Time Format - Allows to change time format for plugin use.
 */
function mcp_time_format() {
	return apply_filters( 'memberchimp_time_format', get_option( 'time_format' ) );
}

/**
 * Returns date with GMT difference.
 */
function mcp_get_date_from_gmt( $date, $format = '' ) {
	$date   	= strtotime( get_date_from_gmt( $date ) );
	$mcp_date 	= date_i18n( $format, $date );

	return $mcp_date;
}

/**
 * Returns years as an array.
 */
function mcp_get_years( $back_to = 1905 ) {
	return apply_filters( 'mcp_get_years', array_combine( range( date( 'Y' ), $back_to ), range( date('Y'), $back_to ) ) );
}

/**
 * Returns months as an array.
 */
function mcp_get_months() {
	$months = array(
		1  => esc_html__( 'Jan', 'memberchimp' ),
		2  => esc_html__( 'Feb', 'memberchimp' ),
		3  => esc_html__( 'Mar', 'memberchimp' ),
		4  => esc_html__( 'Apr', 'memberchimp' ),
		5  => esc_html__( 'May', 'memberchimp' ),
		6  => esc_html__( 'Jun', 'memberchimp' ),
		7  => esc_html__( 'Jul', 'memberchimp' ),
		8  => esc_html__( 'Aug', 'memberchimp' ),
		9  => esc_html__( 'Sept', 'memberchimp' ),
		10 => esc_html__( 'Oct', 'memberchimp' ),
		11 => esc_html__( 'Nov', 'memberchimp' ),
		12 => esc_html__( 'Dec', 'memberchimp' ),
	);

	return apply_filters( 'mcp_get_months', $months );
}

/**
 * Returns days as an array.
 */
function mcp_get_days() {
	$days = array();
	for( $i = 1; $i <= 31; $i++ ) {
		$days[ $i ] = $i;
	}
	return apply_filters( 'mcp_get_days', $days );
}

/**
 * Shows a select dropdown for years.
 */
function mcp_dropdown_years( $field = null ) {
	mcp_dropdown_datepick( 'year', esc_html__( 'Year', 'memberchimp' ), 1994, $field );
}

/**
 * Shows a select dropdown for months.
 */
function mcp_dropdown_months( $field = null ) {
	mcp_dropdown_datepick( 'month', esc_html__( 'Month', 'memberchimp' ), date( 'n' ), $field );
}

/**
 * Shows a select dropdown for days.
 */
function mcp_dropdown_days( $field = null ) {
	mcp_dropdown_datepick( 'day', esc_html__( 'Day', 'memberchimp' ), date( 'j' ), $field );
}

/**
 * Shows a select dropdown for day, month or year.
 */
function mcp_dropdown_datepick( $id, $name, $default = null, $field = null ) {
	$selected = $default;
	if ( ! empty( $field[ 'value' ] ) && is_array( $field[ 'value' ] ) && array_key_exists( $id, $field[ 'value'] ) ) {
		$selected = $field[ 'value' ][ $id ];
	}
	?>
	<select class="mcp-select short" data-placeholder="<?php echo esc_attr( $name ); ?>" name="<?php echo esc_attr( $field[ 'key' ] ); ?>[<?php echo $id; ?>]">
		<option value=""><?php echo esc_html( $name ); ?></option>
		<?php foreach( call_user_func( 'mcp_get_' . $id . 's' ) as $key => $value ) { ?>
		<option value="<?php echo $key; ?>" <?php selected( $selected, $key ); ?> ><?php echo $value; ?></option>
		<?php } ?>
	</select>
	<?php
}

/**
 * Convert array-based date into readable date string.
 */
function mcp_array_to_date( $array ) {
	$date = $array[ 'day' ] . '-' . $array[ 'month' ] . '-' . $array[ 'year' ];

	return date( mcp_get_date_format(), strtotime( $date ) );
}