<?php
/**
 * Dropdown Functions.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Display the dropdown caret.
 */
function mcp_dropdown_caret() {
	?>
	<div class="mcp-dropdown-caret">
		<span class="mcp-caret-outer"></span>
		<span class="mcp-caret-inner"></span>
	</div>
	<?php
}

/**
 * Print a dropdown menu content.
 */
function mcp_print_dropdown( $menu, $items ) {
	if ( empty( $items ) || empty( $menu ) ) {
		return;
	}

	// Loop through items.
	foreach( (array) $items as $id => $item ) {
		
		if ( ! empty( $item[ 'icon' ] ) ) {
			$item[ 'html' ] = preg_replace( '/<a (.*?)>(.*?)<\/a>/', '<a $1 ><span class="mcp-dropdown-icon">' . mcp_svg_icon( $item[ 'icon' ] ) . '</span>$2</a>', $item[ 'html' ] );
		}
		?>

		<?php do_action( "mcp_{$menu}_dropdown_before_{$id}" ); ?>
		<li class="<?php echo esc_attr( $item[ 'class' ] ); ?>">
			<?php echo $item[ 'html' ]; ?>
		</li>
		<?php do_action( "mcp_{$menu}_dropdown_after_{$id}" ); ?>

	<?php
	}
}


/**
 * Get dropdown items for cover.
 */
function mcp_get_cover_dropdown_items() {
	return mcp_get_photo_dropdown_items( 'cover' );
}

/**
 * Get dropdown items for avatar.
 */
function mcp_get_avatar_dropdown_items() {
	return mcp_get_photo_dropdown_items( 'avatar' );
}

/**
 * Get dropdown items for user.
 */
function mcp_get_user_dropdown_items() {
	global $current_user;

	$items = array();

	$items[ 'name' ] = array(
		'class'		=> 'profile-name',
		'html'		=> '<a href="' . memberchimp_get_profile_url( $current_user->user_login ) . '">
							<b>' . esc_attr( $current_user->get( 'display_name' ) ) . '</b>
							<span>@' . esc_attr( $current_user->get( 'user_login' ) ) . '</span>
						</a>',
	);

	$items[ 'seperator1' ] = array(
		'class'		=> 'mcp-dropdown-divider',
		'html' 		=> '',
	);

	$items[ 'profile' ] = array(
		'class'		=> '',
		'icon'		=> 'user',
		'html' 		=> '<a href="' . memberchimp_get_profile_url( $current_user->user_login ) . '">' . esc_html__( 'Profile', 'memberchimp' ) . '</a>',
	);

	$items[ 'seperator2' ] = array(
		'class'		=> 'mcp-dropdown-divider',
		'html' 		=> '',
	);

	$items[ 'settings' ] = array(
		'class'		=> '',
		'icon'		=> 'settings',
		'html'		=> '<a href="' . mcp_get_page_permalink( 'account' ) . '">' . esc_html__( 'Account and settings', 'memberchimp' ) . '</a>',
	);

	$items[ 'logout' ] = array(
		'class'		=> '',
		'icon'		=> 'log-out',
		'html'		=> '<a href="' . mcp_logout_url( mcp_get_current_url() ) . '">' . sprintf( esc_html__( 'Log out @%s', 'memberchimp' ), $current_user->user_login ) . '</a>',
	);

	return apply_filters( 'mcp_get_user_dropdown_items', $items, $current_user );
}

/**
 * Get dropdown items for user actions.
 */
function mcp_get_user_actions_dropdown_items() {
	global $the_user, $logged_user;

	$items = array();

	$user_id 	= absint( $the_user->user_id );
	$user 		= esc_attr( $the_user->get( 'user_login' ) );

	$items[ 'block' ] = array(
		'class'		=> '',
		'icon'		=> 'eye-off',
		'html' 		=> '<a href="#" data-user_id="' . $user_id . '" data-user="' . $user . '" class="mcp-modal-open mcp_block_user ' . $logged_user->get_block_class( $user_id ) . '" rel="mcp-modal-block">' . sprintf( esc_html__( 'Block @%s', 'memberchimp' ), $user ) . '</a>',
	);

	$items[ 'unblock' ] = array(
		'class'		=> '',
		'icon'		=> 'eye',
		'html' 		=> '<a href="#" data-user_id="' . $user_id . '" data-user="' . $user . '" data-action="unblock_user" class="mcp-ajax-action mcp_unblock_user ' . $logged_user->get_block_class( $user_id ) . '">' . sprintf( esc_html__( 'Unblock @%s', 'memberchimp' ), $user ) . '</a>',
	);

	return apply_filters( 'mcp_get_user_actions_dropdown_items', $items, $the_user, $logged_user );
}

/**
 * Get dropdown items for managing a user.
 */
function mcp_get_user_admin_dropdown_items() {
	global $the_user;

	$items = array();

	$user_id = absint( $the_user->user_id );
	$user = $the_user->get( 'user_login' );

	// Edit frontend profile link.
	$items[ 'edit_front' ] = array(
		'class'		=> '',
		'icon'		=> 'edit-2',
		'html' 		=> '<a href="' . esc_url( mcp_get_profile_endpoint_url( 'edit' ) ) . '">' . sprintf( esc_html__( 'Edit @%s', 'memberchimp' ), $user ) . '</a>',
	);

	// Ensure user has access to WP admin and can edit the user.
	if ( current_user_can( 'edit_user', $user_id ) ) {
		$items[ 'edit_backend' ] = array(
			'class'		=> '',
			'icon'		=> 'edit-3',
			'html' 		=> '<a href="' . esc_url ( get_edit_user_link( $user_id ) ) . '">' . sprintf( esc_html__( 'Edit @%s (WP)', 'memberchimp' ), $user ) . '</a>',
		);
	}

	// Check that user want to log in as another user.
	if ( $user_id != get_current_user_id() ) {
		$items[ 'login_as' ] = array(
			'class'		=> '',
			'icon'		=> 'log-in',
			'html' 		=> '<a href="' . add_query_arg( 'mcp_logon', mcp_md5( $user_id ), add_query_arg( 'mcp_id', $user_id ) ) . '">' . sprintf( esc_html__( 'Log in as @%s', 'memberchimp' ), $user ) . '</a>',
		);
	}

	// Super admins should not see this.
	if ( current_user_can( 'mcp_delete_users' ) && ! is_super_admin( $user_id ) ) {
		$items[ 'seperator1' ] = array(
			'class'		=> 'mcp-dropdown-divider',
			'html' 		=> '',
		);

		$items[ 'delete' ] = array(
			'class'		=> '',
			'icon'		=> 'trash',
			'html' 		=> '<a href="#" data-user_id="' . $user_id . '" data-user="' . $user . '" class="mcp-modal-open mcp_delete_user" rel="mcp-modal-user-delete">' . sprintf( esc_html__( 'Delete @%s', 'memberchimp' ), $user ) . '</a>',
		);
	}

	return apply_filters( 'mcp_get_user_admin_dropdown_items', $items, $the_user );
}

/**
 * Get dropdown items for photo.
 */
function mcp_get_photo_dropdown_items( $name ) {
	global $the_user;

	$items = array();

	$items[ 'upload' ] = array(
		'class'		=> 'mcp-dropdown-upload',
		'html' 		=> call_user_func_array( 'mcp_get_photo_upload_html', array( 'name' => $name ) ),
	);

	// Add "remove" link.
	$items[ 'remove' ] = array(
		'class' => call_user_func( "mcp_user_uploaded_{$name}" ) ? "mcp_has_{$name}" : "mcp_no_{$name}",
		'html' 	=> '<a href="#" data-user_id="' . $the_user->user_id . '" class="mcp-modal-open" rel="mcp-modal-remove-' . $name . '">' . esc_html__( 'Remove', 'memberchimp' ) . '</a>',
	);

	// Divider.
	$items[ 'seperator1' ] = array(
		'class'		=> 'mcp-dropdown-divider',
		'html' 		=> '',
	);

	$items[ 'cancel' ] = array(
		'class'		=> '',
		'html' 		=> '<a href="#" rel="mcp_dropdown_hide">' . esc_html__( 'Cancel', 'memberchimp' ) . '</a>',
	);

	return apply_filters( "mcp_get_{$name}_dropdown_items", $items, $the_user );
}

/**
 * Get photo upload html.
 */
function mcp_get_photo_upload_html( $name = 'avatar' ) {
	global $the_user;

	ob_start();
	?>
	<button type="button" class="mcp-dropdown-link"><?php esc_html_e( 'Upload photo', 'memberchimp' ); ?></button>
	<div class="mcp-photo-selector">
		<div class="mcp-image-selector">
			<form>
				<input 
					type="file" 
					name="_mcp_profile_<?php echo $name; ?>" 
					class="mcp-file-input mcp-input-<?php echo $name; ?>" 
					tabindex="-1" 
					accept="image/gif,image/jpeg,image/jpg,image/png" 
					data-user_id="<?php echo $the_user->user_id; ?>"
				>
			</form>
		</div>
	</div>
	<?php
	return ob_get_clean();
}