<?php
/**
 * Field Functions.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Get supported field types.
 */
function memberchimp_get_field_types( $type = 'default' ) {

	$array = array(
		'text'			=>	array(
			'label'		=> esc_html__( 'Text Input', 'memberchimp' ),
			'icon'		=> 'file-text',
		),
		'select'		=>	array(
			'label'		=> esc_html__( 'Select', 'memberchimp' ),
			'icon'		=> 'list',
			'no_input'	=> 1,
		),
		'textarea'		=>	array(
			'label'		=> esc_html__( 'Textarea', 'memberchimp' ),
			'icon'		=> 'clipboard',
			'no_input'	=> 1,
		),
		'checkbox'		=>	array(
			'label'		=> esc_html__( 'Checkbox', 'memberchimp' ),
			'icon'		=> 'square',
			'no_input'	=> 1,
		),
		'radio'			=>	array(
			'label'		=> esc_html__( 'Radio', 'memberchimp' ),
			'icon'		=> 'circle',
			'no_input'	=> 1,
		),
		'email'			=>	array(
			'label'		=> esc_html__( 'Email', 'memberchimp' ),
			'icon'		=> 'mail',
		),
		'url'			=>	array(
			'label'		=> esc_html__( 'URL Address', 'memberchimp' ),
			'icon'		=> 'link',
		),
		'phone'			=>	array(
			'label'		=> esc_html__( 'Phone Number', 'memberchimp' ),
			'icon'		=> 'phone',
		),
		'password'		=>	array(
			'label'		=> esc_html__( 'Password', 'memberchimp' ),
			'icon'		=> 'key',
		),
		'image'			=>	array(
			'label'		=> esc_html__( 'Image Upload', 'memberchimp' ),
			'icon'		=> 'image',
		),
		'file'			=>	array(
			'label'		=> esc_html__( 'File Upload', 'memberchimp' ),
			'icon'		=> 'file',
		),
		'toggle'		=>	array(
			'label'		=> esc_html__( 'Toggle', 'memberchimp' ),
			'icon'		=> 'toggle-left',
			'no_input'	=> 1,
		),
		'rating'		=>	array(
			'label'		=> esc_html__( 'Rating', 'memberchimp' ),
			'icon'		=> 'star',
			'no_input'	=> 1,
		),
		'date'			=> array(
			'label'		=>	__( 'Date Picker', 'memberchimp' ),
			'icon'		=> 'calendar',
			'no_input'	=> 1,
		),
		'dynamic'		=> array(
			'label'		=>	__( 'Dynamic', 'memberchimp' ),
			'icon'		=> 'code',
		),
	);

	// Probably field types without metakey requirement.
	if ( $type == 'html' ) {
		$array = array(
			'heading'		=>	array(
				'label'		=> esc_html__( 'Heading', 'memberchimp' ),
			),
			'html'			=>	array(
				'label'		=> esc_html__( 'HTML', 'memberchimp' ),
			),
			'divider'		=>	array(
				'label'		=> esc_html__( 'Divider', 'memberchimp' ),
			),
			'spacing'		=>	array(
				'label'		=> esc_html__( 'Spacing', 'memberchimp' ),
			),
		);
	}

	return apply_filters( 'memberchimp_get_field_types', $array, $type );
}

/**
 * Get field type name.
 */
function mcp_get_field_type( $type, $return = false ) {
	$types = memberchimp_get_field_types();

	if ( ! isset( $types[ $type ] ) )
		return;

	if ( $return == 'label' ) {
		return $types[ $type ][ 'label' ];
	}

	if ( $return == 'icon' ) {
		return $types[ $type ][ 'icon' ];
	}

	if ( $return == 'html' ) {
		return '<span class="mcp-tag-icon">' . mcp_svg_icon( $types[ $type ][ 'icon' ] ) . $types[ $type ][ 'label' ] . '</span>';
	}

	return $types[ $type ];
}

/**
 * Get custom fields.
 */
function memberchimp_get_custom_fields() {
	return apply_filters( 'memberchimp_get_custom_fields', get_option( 'memberchimp_fields' ) );
}

/**
 * Get a custom field from options.
 */
function memberchimp_get_field( $key ) {
	$array = (array) get_option( 'memberchimp_fields' );
	return array_key_exists( $key, $array ) ? $array[$key] : '';
}

/**
 * Get default fields.
 */
function memberchimp_get_default_fields() {
	$array = array(
		'user_login'		=>	array(
			'label'			=> esc_html__( 'Username', 'memberchimp' ),
			'type'			=> 'text',
			'icon'			=> 'user',
			'is_readonly'	=> 1,
		),
		'user_email'		=>	array(
			'label'			=> esc_html__( 'Email Address', 'memberchimp' ),
			'type'			=> 'email',
			'icon'			=> 'mail',
			'is_private'	=> 1,
			'can_view'		=> array( 'owner' ),
		),
		'first_name'		=>	array(
			'label'			=> esc_html__( 'First Name', 'memberchimp' ),
			'type'			=> 'text',
			'is_private'	=> 1,
			'can_view'		=> array( 'owner' ),
		),
		'last_name'			=>	array(
			'label'			=> esc_html__( 'Last Name', 'memberchimp' ),
			'type'			=> 'text',
			'is_private'	=> 1,
			'can_view'		=> array( 'owner' ),
		),
		'display_name'		=>	array(
			'label'			=> esc_html__( 'Display Name', 'memberchimp' ),
			'type'			=> 'text',
		),
		'description'		=>	array(
			'label'			=> esc_html__( 'Biography', 'memberchimp' ),
			'type'			=> 'textarea',
		),
		'country'			=> array(
			'label'			=> esc_html__( 'Country/Region', 'memberchimp' ),
			'type'			=> 'select',
			'icon'			=> 'map-pin',
		),
		'user_url'			=>	array(
			'label'			=> esc_html__( 'Website URL', 'memberchimp' ),
			'type'			=> 'url',
			'icon'			=> 'link',
		),
		'user_registered'	=>	array(
			'label'			=> esc_html__( 'Registration Date', 'memberchimp' ),
			'type'			=> 'dynamic',
			'is_readonly'	=> 1,
		),
		'user_pass'			=> array(
			'label'			=> esc_html__( 'Password', 'memberchimp' ),
			'type'			=> 'password',
			'icon'			=> 'lock',
			'is_private'	=> 1,
			'can_view'		=> array( '_none' ),
		),
		'_mcp_private'		=> array(
			'label'			=> esc_html__( 'Profile privacy', 'memberchimp' ),
			'type'			=> 'toggle',
			'is_private'	=> 1,
			'can_view'		=> array( '_none' ),
			'helper'		=> esc_html__( 'Protect my profile information from the public.', 'memberchimp' ),
		),
	);

	return apply_filters( 'memberchimp_get_default_fields', $array );
}

/**
 * Create default fields.
 */
function memberchimp_create_default_fields() {

	if ( ! empty( $fields = memberchimp_get_default_fields() ) ) {
		foreach( $fields as $key => $data ) {
			$the_field = new MCP_Field();
			$the_field->set( 'post_title', isset( $data['label'] ) ? mcp_clean( wp_unslash( $data['label'] ) ) : '' );
			$the_field->set( 'post_name', mcp_clean( wp_unslash( $key ) ) );
			$the_field->set(
				'meta_input',
				array_merge(
					array( 'key' => mcp_clean( wp_unslash( $key ) ) ),
					mcp_clean( $data )
				)
			);
			$the_field->insert();
			$the_field->save( $the_field->meta_input );
		}
	}

}

/**
 * Remove default fields.
 */
function memberchimp_remove_default_fields() {
	global $wpdb;

	if ( ! current_user_can( 'delete_mcp_fields' ) ) {
		wp_die( -1 );
	}

	if ( ! empty( $fields = memberchimp_get_default_fields() ) ) {
		$memberchimp_fields = get_option( 'memberchimp_fields' );

		foreach( $fields as $key => $data ) {

			if ( isset( $memberchimp_fields[ $key ] ) ) {
				unset( $memberchimp_fields[ $key ] );
			}

			$wpdb->query( $wpdb->prepare( "DELETE FROM {$wpdb->posts} WHERE post_type = 'mcp_field' AND post_name = %s AND 1=1", $key ) );
		}

		$wpdb->query( "DELETE meta FROM {$wpdb->postmeta} meta LEFT JOIN {$wpdb->posts} posts ON posts.ID = meta.post_id WHERE posts.ID IS NULL;" );

		if ( ! empty( $memberchimp_fields ) ) {
			update_option( 'memberchimp_fields', $memberchimp_fields );
		} else {
			delete_option( 'memberchimp_fields' );
		}

	}

}

/**
 * Get field data attributes.
 */
function mcp_get_data_attributes( $data ) {
	$output = '';

	if ( empty( $data ) ) {
		return;
	}

	foreach( $data as $key => $value ) {
		if ( is_array( $value ) ) {
			$value = implode( ',', $value );
		} else {
			$value = esc_attr( $value );
		}
		// Replace new line breaks with plus sign.
		$value = str_replace( ["\r\n", "\r", "\n"], '+', $value );
		$output .= ' data-' . esc_attr( $key ) . '="' . $value . '"';
	}

	return $output;
}

/**
 * Check if a field is private.
 */
function mcp_is_private_field( $field ) {
	$bool = false;

	if ( ! empty( $field[ 'is_private'] ) && $field[ 'is_private' ] == 1 ) {
		$bool = true;
	}

	return apply_filters( 'mcp_is_private_field', $bool, $field );
}

/**
 * Check if field is a password field.
 */
function mcp_is_password_field( $field ) {
	$bool = false;

	if ( ! empty( $field[ 'type'] ) && $field[ 'type' ] == 'password' ) {
		$bool = true;
	}

	return apply_filters( 'mcp_is_password_field', $bool, $field );
}

/**
 * Prepares custom field data.
 */
function mcp_get_field( $array ) {
	global $the_form, $the_user;

	if ( ! array_key_exists( 'type', ( array ) $array[ 'data' ] ) ) {
		return;
	}

	$field = $array['data'];

	$defaults = array(
		'form_type'		=> $the_form->type,
		'field_type'	=> mcp_get_field_type( $field['type'] ),
		'options'		=> mcp_get_field_options( $field ),
		'title_class'	=> array(),
		'label_class'	=> array(),
		'input_class'	=> array(),
		'field_class'	=> array(),
		'control_class'	=> array(),
		'attributes'	=> array(),
	);

	$the_field = new MCP_Field();
	foreach( $the_field->internal_meta_keys as $default ) {
		$defaults[ $default ] = '';
	}

	$field = wp_parse_args( $field, $defaults );

	// Edit label needs to override default label.
	if ( ! empty( $field['edit_label'] ) ) {
		$field['label'] = $field['edit_label'];
	}

	// View scope.
	if ( mcp_get_scope() == 'view' && ! empty( $field['view_label'] ) ) {
		$field['label'] = $field['view_label'];
	}

	// Get field value.
	if ( in_array( $field['form_type'], array( 'account', 'profile' ) ) ) {
		$field['value'] = $the_user->get( $field['key'] );
	}

	$field['value'] = ( $the_form->is_request && isset( $the_form->postdata[ $field['key'] ] ) ) ? $the_form->postdata[ $field['key'] ] : $field['value'];

	// No input field.
	if ( ! empty( $field['field_type']['no_input'] ) || mcp_get_scope() == 'view' ) {
		$field['no_input'] = 1;
	}

	// Classes.
	$field['field_class'][] = 'memberchimp-' . esc_attr( $field['type'] );
	$field['field_class'][] = esc_attr( $field['key'] ) . '_field';

	if ( empty( $field['label'] ) && is_array( $field['options'] ) && count( $field['options'] ) == 1 ) {
		$field['field_class'][] = 'mcp-single-option';
	}

	if ( $field['type'] == 'select' ) {
		$field['input_class'][] = 'mcp-select';
	}

	if ( $the_form->has_error( $field['key'] ) ) {
		$field['label_class'][] = 'mcp-error';
		$field['input_class'][] = 'mcp-error';
	}

	if ( $the_form->icons == 'label' || ( $the_form->icons == 'inside' && $field['no_input'] ) ) {
		if ( $field[ 'icon' ] ) {
			if ( in_array( $field[ 'type'], array( 'image', 'file' ) ) ) {
				if ( mcp_get_scope() == 'view' ) {
					$field['title_class'][] = 'has-icon';
				}
			} else {
				$field['title_class'][] = 'has-icon';
			}
		}
	}

	if ( $the_form->icons == 'inside' && $field['icon'] ) {
		if ( ! $field['no_input'] ) {
			$field['control_class'][] = 'has-icon';
		}
	}

	if ( mcp_get_scope() == 'view' ) {
		$field['title_class'][] = 'mcp-view';
	}

	// Attributes.
	if ( $field['key'] == 'user_login' && $field['form_type'] != 'login' ) {
		$field['attributes'][] = 'autocomplete=off';
	}

	if ( $field['type'] == 'password' && $field['form_type'] != 'login' ) {
		$field['attributes'][] = 'autocomplete=new-password';
	}

	if ( ! empty( $field['placeholder'] ) ) {
		$field['attributes'][] = 'placeholder="' . esc_attr( $field['placeholder'] ) . '"';
	} else {
		$field['attributes'][] = 'placeholder="' . esc_attr( mcp_get_default_placeholder( $field ) ) . '"';
	}

	if ( ! empty( $field['is_readonly'] ) && ! empty( $the_user->user_id ) ) {
		if ( get_option( 'memberchimp_allow_' . $field['key'] . '_change' ) != 'yes' ) {
			$field['attributes'][] = 'disabled="disabled"';
		}
	}

	if ( empty( $field['no_input'] ) ) {
		$field['attributes'][] = 'spellcheck="false"';
	}

	// Filter for field value.
	if ( mcp_get_scope() == 'view' ) {
		$field[ 'value' ] = apply_filters( 'mcp_get_' . esc_attr( $field['key'] ) . '_value', $field[ 'value' ], $field );
	}

	/**
	 * Hooks to modify field attributes and settings.
	 */
	$field = apply_filters( 'mcp_get_field', $field, $the_form );
	$field = apply_filters( 'mcp_get_' . esc_attr( $field['key'] ) . '_field', $field, $the_form );
	$field = apply_filters( 'mcp_get_' . esc_attr( $field['form_type'] ) . '_' . esc_attr( $field['key'] ) . '_field', $field, $the_form );

	return $field;
}

/**
 * Get field options.
 */
function mcp_get_field_options( $field ) {
	extract( $field );

	if ( $type == 'select' ) {
		$options = ! empty( $dropdown_options ) ? $dropdown_options : '';
	} elseif ( $type == 'radio' ) {
		$options = ! empty( $radio_options ) ? $radio_options : '';
	} elseif ( $type == 'checkbox' ) {
		$options = ! empty( $checkbox_options ) ? $checkbox_options : '';
	}

	// Get default options.
	if ( empty( $options ) && in_array( $type, array( 'select', 'checkbox', 'radio' ) ) ) {
		return mcp_get_default_field_options( $field );
	} else {
		// Explode options.
		if ( ! empty( $options ) ) {
			$options = str_replace( '++', '+', $options );
			$options = explode( '+', $options );
			$options = array_combine( array_map( 'sanitize_title', $options ), $options );
			if ( mcp_get_default_placeholder( $field ) ) {
				return array( '' => mcp_get_default_placeholder( $field ) ) + $options;
			}
			return $options;
		}
	}

	return null;
}

/**
 * Get default field options.
 */
function mcp_get_default_field_options( $field ) {
	extract( $field );

	// Get countries list.
	if ( $key == 'country' ) {
		return array( '' => mcp_get_default_placeholder( $field ) ) + mcp()->countries->countries;
	}

	// Get gender list.
	if ( $key == 'gender' ) {
		return apply_filters( 'memberchimp_gender_options', array(
			'female'	=> esc_html__( 'Female', 'memberchimp' ),
			'male'		=> esc_html__( 'Male', 'memberchimp' ),
			'none'		=> esc_html__( 'Prefer not to say', 'memberchimp' ),
		) );
	}
}

/**
 * Get default field placeholder.
 */
function mcp_get_default_placeholder( $field ) {
	extract( $field );

	if ( $key == 'country' ) {
		return ! empty( $field['placeholder'] ) ? esc_attr( $field['placeholder'] ) : esc_html__( 'Select your country...', 'memberchimp' );
	}

	if ( $key == 'gender' ) {
		return ! empty( $field['placeholder'] ) ? esc_attr( $field['placeholder'] ) : esc_html__( 'Select your gender...', 'memberchimp' );
	}

	return ! empty( $field['placeholder'] ) ? esc_attr( $field['placeholder'] ) : null;
}