<?php
/**
 * Field Hooks
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Email change.
add_action( 'memberchimp_after_email_field_input', 'memberchimp_email_pending_notification_text' );

// Form ID and nonce fields.
add_action( 'memberchimp_after_register_form_content', 'memberchimp_add_form_inputs' );
add_action( 'memberchimp_after_login_form_content', 'memberchimp_add_form_inputs' );
add_action( 'memberchimp_after_lostpassword_form_content', 'memberchimp_add_form_inputs' );
add_action( 'memberchimp_after_account_form_content', 'memberchimp_add_form_inputs' );
add_action( 'memberchimp_after_profile_form_content', 'memberchimp_add_form_inputs' );

// Core and custom forms.
add_action( 'memberchimp_after_password_reset_form_content', 'memberchimp_add_form_inputs' );

// Extra fields.
add_filter( 'mcp_get_form_fields', 'mcp_add_new_password_fields', 10, 2 );

// Account fields.
add_filter( 'mcp_get_account_user_login_field', 'mcp_get_account_user_login_field', 10, 2 );
add_filter( 'mcp_get_account_user_email_field', 'mcp_get_account_user_email_field', 10, 2 );
add_filter( 'mcp_get_account_user_pass_field', 'mcp_get_account_user_pass_field', 10, 2 );
add_filter( 'mcp_get_account_new_password_field', 'mcp_get_account_new_password_field', 10, 2 );
add_filter( 'mcp_get_account_verify_new_password_field', 'mcp_get_account_verify_new_password_field', 10, 2 );

// Registration fields.
add_filter( 'mcp_get_register_user_login_field', 'mcp_get_register_user_login_field', 10, 2 );
add_filter( 'mcp_get_register_user_email_field', 'mcp_get_register_user_email_field', 10, 2 );

// Login fields.
add_filter( 'mcp_get_login_user_pass_field', 'mcp_get_login_user_pass_field', 10, 2 );

// Add extra field icons beside label.
add_action( 'memberchimp_after_label_text', 'mcp_get_field_icons', 10 );
add_action( 'memberchimp_after_label_url', 'mcp_get_field_icons', 10 );
add_action( 'memberchimp_after_label_email', 'mcp_get_field_icons', 10 );
add_action( 'memberchimp_after_label_phone', 'mcp_get_field_icons', 10 );
add_action( 'memberchimp_after_label_password', 'mcp_get_field_icons', 10 );
add_action( 'memberchimp_after_label_image', 'mcp_get_field_icons', 10 );
add_action( 'memberchimp_after_label_file', 'mcp_get_field_icons', 10 );
add_action( 'memberchimp_after_label_checkbox', 'mcp_get_field_icons', 10 );
add_action( 'memberchimp_after_label_radio', 'mcp_get_field_icons', 10 );
add_action( 'memberchimp_after_label_select', 'mcp_get_field_icons', 10 );
add_action( 'memberchimp_after_label_textarea', 'mcp_get_field_icons', 10 );
add_action( 'memberchimp_after_label_rating', 'mcp_get_field_icons', 10 );
add_action( 'memberchimp_after_label_toggle', 'mcp_get_field_icons', 10 );

/**
 * Inform the user that his new email is unconfirmed.
 */
function memberchimp_email_pending_notification_text() {
	global $the_form;

	if ( mcp_user_has_pending_email() && $the_form->type == 'account' ) {
		mcp_get_template( 'global/new-email-change.php' );
	}
}

/**
 * Add the hidden inputs including nonce.
 */
function memberchimp_add_form_inputs() {
	global $the_form;

	// Do not add inputs when the form is in 'view' mode.
	if ( mcp_get_scope() == 'view' ) {
		return;
	}

	if ( ! empty( mcp()->query->get_current_endpoint() ) ) {
		$endpoint = mcp()->query->get_current_endpoint();
	} else {
		$endpoint = esc_attr( $the_form->type );
	}

	if ( $endpoint == 'account' ) {
		$endpoint = mcp_get_account_default_endpoint();
	}

	if ( isset( $_GET[ 'login' ] ) && $endpoint == 'mcp_user' ) {
		$endpoint = 'login';
	}

	if ( $endpoint == 'mcp_user' ) {
		$endpoint = 'edit-profile';
	}

	if ( $the_form->type == 'login' ) {
		$endpoint = 'login';
	}

	// Add hidden fields assigned to this form.
	if ( ! empty( $the_form->hidden_fields ) ) {
		foreach( $the_form->hidden_fields as $key => $value ) {
			echo '<input type="hidden" id="' . $key . '" name="' . $key . '" value="' . $value . '" />';
		}
	}

	// Allow the endpoint to be filtered.
	$endpoint = apply_filters( 'memberchimp_get_nonce_endpoint', $endpoint, $the_form );

	echo '<input type="hidden" id="_' . $endpoint . '_id" name="_' . $endpoint . '_id" value="' . absint( $the_form->id ) . '" />';
	echo '<input type="hidden" id="_endpoint" name="_endpoint" value="' . $the_form->get_endpoint() . '" />';

	// Adds the user ID as hidden input field.
	if ( $the_form->get_endpoint() == 'profile' ) {
		echo '<input type="hidden" id="_user_id" name="_user_id" value="' . mcp_get_active_profile_id() . '" />';
	}

	// Add enforced redirection.
	if ( ! empty( mcp()->_redirect ) ) {
		echo '<input type="hidden" id="_mcp_redirect" name="_mcp_redirect" value="' . esc_url_raw( mcp()->_redirect ) . '" />';
	}

	wp_nonce_field( 'memberchimp-' . $endpoint, 'memberchimp-' . $endpoint . '-nonce' );
}

/**
 * Account - Edit password.
 */
function mcp_add_new_password_fields( $fields, $the_form ) {

	if ( $the_form->get_endpoint() == 'edit-password' ) {

		$item = mcp_array_search( 'user_pass', $fields );
		if ( is_array( $item ) ) {
			$item[ 'data' ][ 'key' ] = 'new_password';
			array_push( $fields, $item );
			$item[ 'data' ][ 'key' ] = 'verify_new_password';
			array_push( $fields, $item );
		}

	}

	return $fields;
}

/**
 * Account - Username
 */
function mcp_get_account_user_login_field( $field, $the_form ) {
	if ( empty( $field[ 'helper' ] ) ) {
		$field[ 'helper' ] = memberchimp_get_profile_url( '', $ajax = true );
	}

	return $field;
}

/**
 * Account - Email
 */
function mcp_get_account_user_email_field( $field, $the_form ) {
	if ( empty( $field[ 'helper' ] ) ) {
		$field[ 'helper' ] = esc_html__( 'Email will not be publicly displayed.', 'memberchimp' );
	}

	return $field;
}

/**
 * Account - Current user password.
 */
function mcp_get_account_user_pass_field( $field, $the_form ) {
	$field = array_merge( $field, array(
		'label'			=> esc_html__( 'Current password', 'memberchimp' ),
		'helper'		=> sprintf( '<a href="%s">%s</a>', mcp_lostpassword_url(), esc_html__( 'Forgotten your password?', 'memberchimp' ) ),
		'hide_toggle'	=> true,
	) );

	return $field;
}

/**
 * Account - New user password.
 */
function mcp_get_account_new_password_field( $field, $the_form ) {
	$field = array_merge( $field, array(
		'label'			=> esc_html__( 'New password', 'memberchimp' ),
		'hide_toggle'	=> true,
	) );

	return $field;
}

/**
 * Account - Verify user password.
 */
function mcp_get_account_verify_new_password_field( $field, $the_form ) {
	$field = array_merge( $field, array(
		'label'			=> esc_html__( 'Verify password', 'memberchimp' ),
		'hide_toggle'	=> true,
	) );

	return $field;
}

/**
 * Register - Username
 */
function mcp_get_register_user_login_field( $field, $the_form ) {
	if ( empty( $field[ 'helper' ] ) ) {
		$field[ 'helper' ] = esc_html__( 'You can use letters, numbers, and underscores.', 'memberchimp' );
	}

	return $field;
}

/**
 * Register - Email
 */
function mcp_get_register_user_email_field( $field, $the_form ) {
	if ( empty( $field[ 'helper' ] ) ) {
		$field[ 'helper' ] = esc_html__( 'Your email will never be published.', 'memberchimp' );
	}

	return $field;
}

/**
 * Login - Password
 */
function mcp_get_login_user_pass_field( $field, $the_form ) {
	if ( empty( $field[ 'helper' ] ) ) {
		$field[ 'helper' ] = sprintf( '<a href="%s">%s</a>', mcp_lostpassword_url(), esc_html__( 'Forgotten your password?', 'memberchimp' ) );
	}

	return $field;
}

/**
 * Returns the field icons. e.g. private
 */
function mcp_get_field_icons( $field ) {
	extract( $field );

	$output = '';

	// Display privacy lock beside email.
	if ( mcp_is_private_field( $field ) ) {

		if ( in_array( $form_type, array( 'login', 'register', 'lostpassword' ) ) ) {
			return;
		}
		if ( in_array( $type, array( 'password' ) ) ) {
			return;
		}
		if ( in_array( $key, array( '_mcp_private' ) ) ) {
			return;
		}

		if ( apply_filters( 'mcp_show_private_field_marker', true, $field ) ) {
			$output .= '<span class="mcp-private tips" data-tip="' . esc_html__( 'People will not see this', 'memberchimp' ) . '">' . mcp_svg_icon( 'lock' ) . '</span>';
		}
	}

	$output = apply_filters( 'mcp_get_field_icons', $output, $field );

	echo $output;
}