<?php
/**
 * Form Functions.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Get a form.
 */
function mcp_get_form( $form_id = '' ) {
	return new MCP_Form( absint( $form_id ) );
}

/**
 * Get supported field types.
 */
function memberchimp_get_form_types() {
	return apply_filters( 'memberchimp_get_form_types', array(
		'register'		=>	array(
			'label'		=> esc_html__( 'Registration', 'memberchimp' ),
			'icon'		=> 'user-plus',
		),
		'login'			=>	array(
			'label'		=> esc_html__( 'Login', 'memberchimp' ),
			'icon'		=> 'lock',
		),
		'profile'		=>	array(
			'label'		=> esc_html__( 'Profile', 'memberchimp' ),
			'icon'		=> 'user',
		),
		'account'		=> array(
			'label'		=> esc_html__( 'Account', 'memberchimp' ),
			'icon'		=> 'settings',
		),
		'lostpassword'	=>	array(
			'label'		=> esc_html__( 'Lost Password', 'memberchimp' ),
			'icon'		=> 'key',
		),
	) );
}

/**
 * Get form type name.
 */
function mcp_get_form_type( $type ) {
	$types = memberchimp_get_form_types();

	if ( ! isset( $types[ $type ] ) )
		return;

	return '<span class="mcp-tag-icon">' . mcp_svg_icon( $types[ $type ][ 'icon' ] ) . $types[ $type ][ 'label' ] . '</span>';
}

/**
 * Get default forms.
 */
function memberchimp_get_default_forms() {
	$array = array();

	array_push(
		$array,
		array(
			'type'		=> 'register',
			'title'		=> esc_html__( 'Registration', 'memberchimp' ),
			'fields'	=> array(
				0		=> array( 'data' => memberchimp_get_field( 'user_email' ), 'row' => 1, 'col' => 1 ),
				1		=> array( 'data' => memberchimp_get_field( 'user_login' ), 'row' => 1, 'col' => 1 ),
				2		=> array( 'data' => memberchimp_get_field( 'user_pass' ), 'row' => 1, 'col' => 1 ),
			)
		) 
	);

	array_push(
		$array,
		array(
			'type'		=> 'login',
			'title'		=> esc_html__( 'Login', 'memberchimp' ),
			'fields'	=> array(
				0		=> array( 'data' => memberchimp_get_field( 'user_login' ), 'row' => 1, 'col' => 1 ),
				1		=> array( 'data' => memberchimp_get_field( 'user_pass' ), 'row' => 1, 'col' => 1 ),
			)
		) 
	);

	array_push(
		$array,
		array(
			'type'		=> 'profile',
			'title'		=> esc_html__( 'Profile', 'memberchimp' ),
			'fields'	=> array(
				1		=> array( 'data' => memberchimp_get_field( 'display_name' ), 'row' => 1, 'col' => 1 ),
				2		=> array( 'data' => memberchimp_get_field( 'first_name' ), 'row' => 1, 'col' => 1 ),
				3		=> array( 'data' => memberchimp_get_field( 'last_name' ), 'row' => 1, 'col' => 1 ),
			)
		)
	);

	array_push(
		$array,
		array(
			'type'		=> 'lostpassword',
			'title'		=> esc_html__( 'Lost Password', 'memberchimp' ),
			'fields'	=> array(
				0		=> array( 'data' => memberchimp_get_field( 'user_email' ), 'row' => 1, 'col' => 1 ),
			)
		)
	);

	array_push(
		$array,
		array(
			'type'		=> 'account',
			'title'		=> esc_html__( 'Account - Main', 'memberchimp' ),
			'fields'	=> array(
				0		=> array( 'data' => memberchimp_get_field( 'user_login' ), 'row' => 1, 'col' => 1 ),
				1		=> array( 'data' => memberchimp_get_field( 'user_email' ), 'row' => 1, 'col' => 1 ),
			),
			'endpoint'	=> mcp_get_account_default_endpoint(),
		)
	);

	array_push(
		$array,
		array(
			'type'		=> 'account',
			'title'		=> esc_html__( 'Account - Password', 'memberchimp' ),
			'fields'	=> array(
				1		=> array( 'data' => memberchimp_get_field( 'user_pass' ), 'row' => 1, 'col' => 1 ),
			),
			'endpoint'	=> 'edit-password',
		)
	);

	array_push(
		$array,
		array(
			'type'		=> 'account',
			'title'		=> esc_html__( 'Account - Privacy', 'memberchimp' ),
			'fields'	=> array(
				1		=> array( 'data' => memberchimp_get_field( '_mcp_private' ), 'row' => 1, 'col' => 1 ),
			),
			'endpoint'	=> 'privacy',
		)
	);

	return apply_filters( 'memberchimp_get_default_forms', $array );
}

/**
 * Create default forms.
 */
function memberchimp_create_default_forms() {
	// Ensure that default fields have created.
	memberchimp_create_default_fields();

	if ( ! empty( $forms = memberchimp_get_default_forms() ) ) {
		foreach( $forms as $key => $data ) {
			$type = mcp_clean( wp_unslash( $data[ 'type' ] ) );

			$the_form = new MCP_Form();

			$the_form->set( 'post_title', isset( $data[ 'title' ] ) ? mcp_clean( $data['title'] ) : '' );
			$the_form->set( 'post_name', sanitize_title( $the_form->post_title ) );
			$the_form->set( 'meta_input', array(
					'type'		=> $type,
					'fields'	=> isset( $data[ 'fields' ] ) ? mcp_clean( $data[ 'fields' ] ) : '',
					'row_count'	=> 1,
					'cols'		=> mcp_get_default_form_layout(),
					'endpoint'	=> isset( $data[ 'endpoint' ] ) ? sanitize_title( $data[ 'endpoint' ] ) : '',
			) );

			$the_form->insert();
			$the_form->save( $the_form->meta_input );

			// Assign the form id to an option.
			if ( ! empty( $the_form->id ) ) {
				mcp_add_default_form_id( $type, $the_form->id );
			}
		}
	}
}

/**
 * Returns default form layout.
 */
function mcp_get_default_form_layout() {
	$array = array(
		0 => array(
			'count' 	=> 0,
			'layout' 	=> 0
		),
		1 => array(
			'count' 	=> 1,
			'layout' 	=> array(
				0 => '100'
			)
		)
	);
	
	return apply_filters( 'mcp_get_default_form_layout', $array );
}

/**
 * Add a default form ID.
 */
function mcp_add_default_form_id( $type = '', $id = 0 ) {
	if ( in_array( $type, array( 'account' ) ) ) {
		return;
	}
	update_option( "memberchimp_{$type}_form", absint( $id ) );
}

/**
 * Get a default form ID.
 */
function mcp_get_default_form_id( $type = null ) {
	$form = "memberchimp_{$type}_form";

	return apply_filters( 'mcp_get_default_form_id', get_option( $form ) );
}

/**
 * Get a form linked to a specific endpoint.
 */
function mcp_get_endpoint_form( $endpoint ) {
	if ( ! $endpoint ) {
		return;
	}

	$form_id = get_option( 'memberchimp_' . $endpoint . '_form', 0 );

	return apply_filters( 'mcp_get_endpoint_form', $form_id );
}

/**
 * Get redirection url after a login.
 */
function mcp_get_login_redirect( $user = null ) {
	global $the_form;

	// By default, redirect user to profile.
	$default = memberchimp_get_profile_url( $user->user_login );

	// But admins should go to WP-admin
	if ( user_can( $user->ID, 'mcp_view_wpadmin' ) ) {
		$default = admin_url();
	}

	// Lets check if the form has specific rules.
	if ( isset( $the_form->redirect ) && $the_form->redirect !== 'none' ) {
		switch( $the_form->redirect ) {
			case 'profile' :
				$redirect = memberchimp_get_profile_url( $user->user_login );
			break;
			case 'account' :
				$redirect = mcp_get_page_permalink( 'account' );
			break;
			case 'custom' :
				$redirect = esc_url( $the_form->redirect_uri );
			break;
			case 'refresh' :
				$redirect = esc_url( remove_query_arg( mcp_get_current_url() ) );
			break;
		}
	}

	// This has top priority so it comes as the last rule.
	if ( ! empty( $_REQUEST[ '_mcp_redirect' ] ) ) {
		$redirect = esc_url_raw( $_REQUEST[ '_mcp_redirect' ] );
	}

	// No redirect set. Use default.
	if ( empty( $redirect ) ) {
		$redirect = $default;
	}

	return apply_filters( 'mcp_get_login_redirect', $redirect );
}

/**
 * Get redirection url after a registration.
 */
function mcp_get_register_redirect( $user = null ) {
	global $the_form;

	// By default, redirect user to profile.
	$default = memberchimp_get_profile_url( $user->user_login );

	// But admins should go to WP-admin
	if ( user_can( $user->ID, 'mcp_view_wpadmin' ) ) {
		$default = admin_url();
	}

	// Lets check if the form has specific rules.
	if ( isset( $the_form->redirect ) && $the_form->redirect !== 'none' ) {
		switch( $the_form->redirect ) {
			case 'profile' :
				$redirect = memberchimp_get_profile_url( $user->user_login );
			break;
			case 'account' :
				$redirect = mcp_get_page_permalink( 'account' );
			break;
			case 'custom' :
				$redirect = esc_url( $the_form->redirect_uri );
			break;
			case 'refresh' :
				$redirect = esc_url( remove_query_arg( mcp_get_current_url() ) );
			break;
		}
	}

	// This has top priority so it comes as the last rule.
	if ( ! empty( $_REQUEST[ '_mcp_redirect' ] ) ) {
		$redirect = esc_url_raw( $_REQUEST[ '_mcp_redirect' ] );
	}

	// No redirect set. Use default.
	if ( empty( $redirect ) ) {
		$redirect = $default;
	}

	return apply_filters( 'mcp_get_register_redirect', $redirect );
}

/**
 * Add a redirect property to the form.
 */
function mcp_form_set_redirect( $redirect = null ) {
	global $memberchimp;

	if ( empty( $redirect ) ) {
		$redirect = mcp_get_current_url();
	}

	mcp()->_redirect = esc_url_raw( $redirect );
}

/**
 * Show form loop template.
 */
function mcp_form_loop( $args = array() ) {
	mcp_get_template( 'form/form-loop.php', $args );
}

/**
 * Get form column part.
 */
function mcp_form_column( $args = array() ) {
	mcp_get_template( 'form/form-column.php', $args );
}

/**
 * Get form top note if available.
 */
function mcp_form_note( $args = array() ) {
	mcp_get_template( 'form/form-note.php', $args );
}

/**
 * Get form buttons.
 */
function mcp_form_buttons( $args = array() ) {
	if ( mcp_get_scope() == 'view' ) {
		return;
	}
	mcp_get_template( 'form/form-buttons.php', $args );
}

/**
 * Get classes for the form buttons container.
 */
function mcp_get_buttons_classes( $classes = array() ) {
	global $the_form;

	return apply_filters( 'mcp_get_buttons_classes', array_unique( $classes ) );
}

/**
 * Get classes for a form column.
 */
function mcp_get_column_classes( $row, $classes = array() ) {
	global $the_form;

	return apply_filters( 'mcp_get_column_classes', array_unique( $classes ) );
}

/**
 * Get form classes.
 */
function mcp_get_form_classes( $classes = array() ) {
	global $the_form;

	$type 		= esc_attr( $the_form->type );
	$endpoint 	= $the_form->get_endpoint();

	$classes[] 	= "memberchimp-{$type}";
	$classes[] 	= "memberchimp-{$endpoint}";

	// Add a class depending on form maximum columns.
	$count = mcp_get_max_column( $the_form->cols, 'count' );
	if ( $count == 1 && mcp_get_scope() == 'edit' ) {
		$classes[] = 'memberchimp-form-onecolumn';
	}

	return apply_filters( 'mcp_get_form_classes', array_unique( $classes ) );
}

/**
 * Print form inline styles data.
 */
function mcp_print_form_inline_styles() {
	if ( ! empty( $inline = mcp_get_form_inline_styles() ) ) {
		echo 'style="' . implode( ';', $inline ) . ';"';
	}
}

/**
 * Print column inline styles data.
 */
function mcp_print_column_inline_styles( $row ) {
	if ( ! empty( $inline = mcp_get_column_inline_styles( $row ) ) ) {
		echo 'style="' . implode( ';', $inline ) . ';"';
	}
}

/**
 * Get form inline styles data.
 */
function mcp_get_form_inline_styles() {
	global $the_form;

	$inline = array();

	return apply_filters( 'mcp_get_form_inline_styles', $inline, $the_form );
}

/**
 * Get column inline styles data.
 */
function mcp_get_column_inline_styles( $row ) {
	global $the_form;

	$inline = array();

	return apply_filters( 'mcp_get_column_inline_styles', $inline, $the_form );
}

/**
 * Check if the form row has a defined title.
 */
function mcp_has_row_title( $row ) {
	global $the_form;
	if ( empty( $the_form->rows ) ) {
		return false;
	}

	return isset( $the_form->rows[ $row - 1 ][ 'title' ] ) && ! empty( $the_form->rows[ $row - 1 ][ 'title' ] );
}

/**
 * Get a form row title.
 */
function mcp_get_row_title( $row ) {
	global $the_form;

	return isset( $the_form->rows[ $row - 1 ][ 'title' ] ) && ! empty( $the_form->rows[ $row - 1 ][ 'title' ] ) ? $the_form->rows[ $row - 1 ][ 'title' ] : null;
}

/**
 * The possible form redirect options.
 */
function mcp_get_form_redirect_options() {
	$array = array(
		'none'		=> __( 'Default Redirection', 'memberchimp' ),
		'profile'	=> __( 'Profile', 'memberchimp' ),
		'account'	=> __( 'Account', 'memberchimp' ),
		'refresh'   => __( 'Refresh same page', 'memberchimp' ),
		'custom'    => __( 'Custom URL', 'memberchimp' ),
	);

	return apply_filters( 'mcp_get_form_redirect_options', $array );
}