<?php
/**
 * Locale Functions.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Hooks.
add_filter( 'gettext', 'memberchimp_gettext', 200, 3 );

/**
 * Get all translations or locale specific translations.
 */
function memberchimp_get_translations( $locale = '' ) {
	if ( ! empty( $locale ) ) {
		$locale = mcp_sanitize_title( $locale );
		return isset( mcp()->translations[ $locale ] ) ? mcp()->translations[ $locale ] : null;
	}
	return mcp()->translations;
}

/**
 * Add a translation.
 */
function memberchimp_add_translation( $text = null, $translated_text = null, $locale = 'en_US' ) {
	if ( empty( $text ) || empty( $translated_text ) ) {
		return;
	}

	$locale	 = mcp_sanitize_title( $locale );
	$text	 = esc_attr( $text );

	// already added.
	if ( isset( mcp()->translations[ $locale ][ $text ] ) ) {
		return;
	}

	mcp()->translations[ $locale ][ $text ] = $translated_text;
	update_option( 'memberchimp_translations', mcp()->translations );
}

/**
 * Add bulk translations.
 */
function memberchimp_add_bulk_translation( $words = array(), $locale = 'en_US' ) {
	if ( empty( $words ) ) {
		return;
	}

	$locale = mcp_sanitize_title( $locale );

	foreach( $words as $untranslated => $translated ) {
		$untranslated = esc_attr( $untranslated );
		mcp()->translations[ $locale ][ $untranslated ] = $translated;
	}

	update_option( 'memberchimp_translations', mcp()->translations );
}

/**
 * Update translation.
 */
function memberchimp_update_translation( $text = null, $translated_text = null, $locale = 'en_US' ) {
	if ( empty( $text ) || empty( $translated_text ) ) {
		return;
	}

	$locale	 = mcp_sanitize_title( $locale );
	$text	 = esc_attr( $text );

	mcp()->translations[ $locale ][ $text ] = $translated_text;
	update_option( 'memberchimp_translations', mcp()->translations );
}

/**
 * Remove a translation.
 */
function memberchimp_remove_translation( $text = null, $locale = 'en_US' ) {
	if ( empty( $text ) ) {
		return;
	}

	$locale       = mcp_sanitize_title( $locale );
	$text	      = esc_attr( $text );

	// remove from translations.
	if ( isset( mcp()->translations[ $locale ][ $text ] ) ) {
		unset( mcp()->translations[ $locale ][ $text ] );
	}

	update_option( 'memberchimp_translations', mcp()->translations );
}

/**
 * Clear all translations.
 */
function memberchimp_clear_translations() {
	delete_option( 'memberchimp_translations' );
}

/**
 * Filter translated words.
 */
function memberchimp_gettext( $translated_text, $text, $domain ) {
	// This is our plugin textdomain.
	if ( $domain !== 'memberchimp' ) {
		return $translated_text;
	}

	$locale       = mcp_sanitize_title( get_locale() );
	$text 		  = esc_attr( $text );

	// Get custom translation if found for this locale.
	if ( isset( mcp()->translations[ $locale ][ $text ] ) ) {
		return esc_html( mcp()->translations[ $locale ][ $text ] );
	}

	return $translated_text;
}