<?php
/**
 * Member List Functions.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Get a memberlist.
 */
function mcp_get_memberlist( $id = '' ) {
	return new MCP_Memberlist( absint( $id ) );
}

/**
 * Get default member lists.
 */
function memberchimp_get_default_memberlists() {
	$array = array(
		'members'	=> array(
			'title'	=> esc_html__( 'Members', 'memberchimp' ),
		),
	);

	return apply_filters( 'memberchimp_get_default_memberlists', $array );
}

/**
 * Create default member lists.
 */
function memberchimp_create_default_memberlists() {
	if ( ! empty( $memberlists = memberchimp_get_default_memberlists() ) ) {

		foreach( $memberlists as $key => $data ) {
			$the_memberlist = new MCP_Memberlist();

			$the_memberlist->set( 'post_title', isset( $data['title'] ) ? mcp_clean( $data['title'] ) : '' );
			$the_memberlist->set( 'post_name', mcp_clean( wp_unslash( $key ) ) );
			$the_memberlist->set( 'meta_input', mcp_get_default_memberlist_args() );

			$the_memberlist->insert();
			$the_memberlist->save( $the_memberlist->meta_input );

			if ( ! empty( $the_memberlist->id ) ) {
				$the_memberlist->set_default();
			}
		}

	}
}

/**
 * Return default memberlist options.
 */
function mcp_get_default_memberlist_args() {
	$args = array(
		'per_page'		=> 20,
		'use_ajax'		=> 'yes',
		'roles'			=> array( '_all' ),
	);

	return apply_filters( 'mcp_get_default_memberlist_args', $args );
}

/**
 * Add members container styles.
 */
function mcp_memberlist_container_styles( $return = null ) {
	global $the_memberlist;

	$styles = array();

	// Loop through styles and add them.
	foreach( (array) apply_filters( 'mcp_get_memberlist_container_styles', $styles ) as $id => $style ) {
		$return .= $id . ': ' . $style . ';';
	}

	if ( $return ) {
		return apply_filters( 'mcp_memberlist_container_styles', 'style="' . $return . '"' );
	}
}

/**
 * Check if user does not have capability to view this list.
 */
function mcp_user_cant_see_memberlist() {
	global $the_memberlist;

	if ( $the_memberlist->login_required && ! is_user_logged_in() ) {
		return true;
	}

	return false;
}

/**
 * Get members.
 */
function mcp_get_members( $args = array() ) {
	global $wpdb, $the_memberlist, $logged_user, $the_user;

	if ( empty( $the_memberlist->id ) ) {
		return;
	}

	// Defaults.
	$defaults = array(
		'meta_query'	=> array( 'relation' => 'AND' ),
		'date_query'	=> array(),
		'search'		=> $the_memberlist->get_search(),
		'role__not_in'  => array(),
		'number'		=> $the_memberlist->per_page,
		'paged'			=> $the_memberlist->get_page(),
		'orderby'		=> 'user_registered',
		'order'			=> 'desc',
		'fields'		=> array( 'ID' ),
	);

	$the_memberlist->query = wp_parse_args( $args, $defaults );
	$the_memberlist->in_loop();

	do_action( 'mcp_pre_memberlist_query', $the_memberlist );

	do_action( 'mcp_pre_users_query' );

	extract( $the_memberlist->query );

	$users = new WP_User_Query( compact( 'meta_query', 'date_query', 'search', 'role__not_in', 'number', 'paged', 'orderby', 'order', 'fields' ) );

	$response = array(
		'users'		=> $users->get_results(),
		'pages'		=> $number > 0 ? absint( ceil( $users->get_total() / $number ) ) : 1,
		'page'		=> $paged,
		'total'		=> $users->get_total(),
	);

	return $response;
}