<?php
/**
 * Member List Hooks.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

add_action( 'mcp_pre_memberlist_query', 'mcp_memberlist_add_filters', 50 );
add_action( 'mcp_pre_memberlist_query', 'mcp_memberlist_add_order', 60 );
add_action( 'mcp_pre_memberlist_query', 'mcp_memberlist_exclude_admins', 70 );
add_action( 'mcp_pre_memberlist_query', 'mcp_only_show_active_users', 80 );

add_filter( 'user_search_columns', 'mcp_user_search_columns', 10, 3 );
add_action( 'mcp_pre_users_query', 'mcp_pre_users_query' );

/**
 * Add custom filters to the search results.
 */
function mcp_memberlist_add_filters( $the_memberlist ) {
	$filters = $the_memberlist->get_filters();

	if ( empty( $filters ) ) {
		return;
	}

	foreach( $filters as $filter_id => $data ) {
		switch( $filter_id ) {

			// Avatar.
			case 'avatar' :
				if ( $data ) {
					$the_memberlist->query[ 'meta_query' ][] = array(
						'key'		=> '_mcp_profile_avatar',
						'compare'	=> 'EXISTS',
					);
				}
			break;

			// Registration date.
			case 'date_registered' :
				if ( is_numeric( $data ) ) {
					$data = mcp_seconds_to_hours( $data );
				}
				$the_memberlist->query[ 'date_query' ][] = array(
					'after' => $data, 'inclusive' => true
				);
			break;

			default :
				// This hook allow custom search filters.
				do_action( 'mcp_memberlist_custom_filter', $filter_id, $data, $filters, $the_memberlist );
			break;
		}
	}

}

/**
 * Add orderby and order to user search.
 */
function mcp_memberlist_add_order( $the_memberlist ) {
	if ( empty( $sort = $the_memberlist->get_sort() ) ) {
		return;
	}

	if ( $sort == 'date_asc' ) {
		$the_memberlist->query[ 'orderby' ] = 'user_registered';
		$the_memberlist->query[ 'order' ]   = 'asc';
	}

	if ( $sort == 'date_desc' ) {
		$the_memberlist->query[ 'orderby' ] = 'user_registered';
		$the_memberlist->query[ 'order' ]   = 'desc';
	}

	if ( $sort == 'name_asc' ) {
		$the_memberlist->query[ 'orderby' ] = 'user_login';
		$the_memberlist->query[ 'order' ]   = 'asc';
	}

	if ( $sort == 'name_desc' ) {
		$the_memberlist->query[ 'orderby' ] = 'user_login';
		$the_memberlist->query[ 'order' ]   = 'desc';
	}

}

/**
 * Remove admin users from the member list.
 */
function mcp_memberlist_exclude_admins( $the_memberlist ) {
	if ( current_user_can( 'manage_options' ) || current_user_can( 'manage_memberchimp' ) ) {
		return;
	}

	if ( apply_filters( 'memberchimp_hide_admins_from_memberlist', false ) ) {
		$the_memberlist->query[ 'role__not_in' ] = memberchimp_get_admin_roles();
	}
}

/**
 * This will not show inactive users in the memberlist. (except for admins)
 */
function mcp_only_show_active_users( $the_memberlist ) {
	if ( current_user_can( 'manage_options' ) || current_user_can( 'manage_memberchimp' ) || current_user_can( 'mcp_review_users' ) ) {
		return;
	}

	$the_memberlist->query[ 'meta_query' ][] = array(
		'key'		=> '_mcp_unconfirmed_email',
		'compare'	=> 'NOT EXISTS',
	);

	$the_memberlist->query[ 'meta_query' ][] = array(
		'key'		=> '_mcp_pending',
		'compare'	=> 'NOT EXISTS',
	);
}

/**
 * Search columns for front-end.
 */
function mcp_user_search_columns( $search_columns, $search, $wp_user_query ) {

	// This is to make the filter plugin specific.
	if ( mcp_is_in_loop() ) {
		$search_columns = apply_filters( 'memberchimp_user_search_columns', array(
			'user_login',
			'user_url',
			'user_email',
			'user_nicename',
			'display_name',
		) );
	}

	return $search_columns;
}

/**
 * Fired before WP_User_Query is returned.
 */
function mcp_pre_users_query() {
	add_action( 'pre_user_query', 'mcp_memberlist_hide_blocked_users', 10 );
}

/**
 * Hide users blocked from memberlist.
 */
function mcp_memberlist_hide_blocked_users( $user_query  ) {
	global $wpdb, $logged_user, $the_memberlist;

	// This only apply to logged in users.
	if ( is_user_logged_in() ) {

		// Exclude blocked users from the list.
		$blocked = $logged_user->get( '_mcp_blocked_users' );
		if ( ! empty( $blocked ) ) {
			$user_query->query_where .= " AND {$wpdb->users}.ID NOT IN ('" . implode( "','", array_keys( $blocked ) ) . "') ";
		}

	}

}