<?php
/**
 * Message Functions
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Get the count of notices added, either for all notices (default) or for one.
 */
function mcp_notice_count( $notice_type = '' ) {

	$notice_count = 0;
	$all_notices  = (array) get_option( 'mcp_notices' );

	if ( isset( $all_notices[ $notice_type ] ) ) {

		$notice_count = count( $all_notices[ $notice_type ] );

	} elseif ( empty( $notice_type ) ) {

		foreach ( $all_notices as $notices ) {
			$notice_count += count( $notices );
		}
	}

	return $notice_count;
}

/**
 * Check if a notice has already been added.
 */
function mcp_has_notice( $message, $notice_type = 'success' ) {

	$notices = (array) get_option( 'mcp_notices' );
	$notices = isset( $notices[ $notice_type ] ) ? $notices[ $notice_type ] : array();
	return array_search( $message, $notices, true ) !== false;
}

/**
 * Add and store a notice.
 */
function mcp_add_notice( $message, $notice_type = 'success', $key = null ) {
	global $the_form;

	if ( ! empty( $key ) ) {
		if ( $the_form->has_error( $key ) ) {
			return;
		}
		$the_form->error( $key );
	}

	$notices = (array) get_option( 'mcp_notices' );

	$notices[ $notice_type ][] = apply_filters( 'memberchimp_add_' . $notice_type, $message );

	update_option( 'mcp_notices', $notices );
}

/**
 * Set all notices at once.
 */
function mcp_set_notices( $notices ) {
	update_option( 'mcp_notices', $notices );
}


/**
 * Unset all notices.
 */
function mcp_clear_notices() {
	update_option( 'mcp_notices', null );
}

/**
 * Prints messages and errors which are stored then clears them.
 */
function mcp_print_notices( $return = false ) {

	$all_notices  = (array) get_option( 'mcp_notices' );
	$notice_types = apply_filters( 'memberchimp_notice_types', array( 'error', 'success', 'notice' ) );

	// Buffer output.
	ob_start();

	foreach ( $notice_types as $notice_type ) {
		if ( mcp_notice_count( $notice_type ) > 0 ) {
			mcp_get_template( "notices/{$notice_type}.php", array(
				'messages' => array_filter( $all_notices[ $notice_type ] ),
			) );
		}
	}

	mcp_clear_notices();

	$notices = mcp_kses_notice( ob_get_clean() );

	if ( $return ) {
		return $notices;
	}

	echo $notices;
}

/**
 * Print a single notice immediately.
 */
function mcp_print_notice( $message, $notice_type = 'success' ) {
	if ( 'success' === $notice_type ) {
		$message = apply_filters( 'memberchimp_add_message', $message );
	}

	mcp_get_template( "notices/{$notice_type}.php", array(
		'messages' => array( apply_filters( 'memberchimp_add_' . $notice_type, $message ) ),
	) );
}

/**
 * Returns all queued notices, optionally filtered by a notice type.
 */
function mcp_get_notices( $notice_type = '' ) {

	$all_notices = (array) get_option( 'mcp_notices' );

	if ( empty( $notice_type ) ) {
		$notices = $all_notices;
	} elseif ( isset( $all_notices[ $notice_type ] ) ) {
		$notices = $all_notices[ $notice_type ];
	} else {
		$notices = array();
	}

	return $notices;
}

/**
 * Add notices for WP Errors.
 */
function mcp_add_wp_error_notices( $errors ) {
	if ( is_wp_error( $errors ) && $errors->get_error_messages() ) {
		foreach ( $errors->get_error_messages() as $error ) {
			mcp_add_notice( $error, 'error' );
		}
	}
}

/**
 * Filters out the same tags as wp_kses_post, but allows tabindex for <a> element.
 */
function mcp_kses_notice( $message ) {
	return html_entity_decode( $message );
}