<?php
/**
 * Page Functions.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Retrieve page permalink.
 */
function mcp_get_page_permalink( $page, $fallback = null ) {
	$page_id   = mcp_get_page_id( $page );
	$permalink = 0 < $page_id ? get_permalink( $page_id ) : '';

	if ( ! $permalink ) {
		$permalink = is_null( $fallback ) ? get_home_url() : $fallback;
	}

	return apply_filters( 'memberchimp_get_' . $page . '_page_permalink', $permalink );
}

/**
 * Retrieve page ids
 */
function mcp_get_page_id( $page ) {
	$page = apply_filters( 'memberchimp_get_' . $page . '_page_id', get_option( 'memberchimp_' . $page . '_page_id' ) );

	return $page ? absint( $page ) : -1;
}

/**
 * Get endpoint URL.
 */
function mcp_get_endpoint_url( $endpoint, $value = '', $permalink = '' ) {
	if ( ! $permalink ) {
		$permalink = get_permalink();
	}

	// Map endpoint to options.
	$query_vars = mcp()->query->get_query_vars();
	$endpoint   = ! empty( $query_vars[ $endpoint ] ) ? $query_vars[ $endpoint ] : $endpoint;

	if ( get_option( 'permalink_structure' ) ) {
		if ( strstr( $permalink, '?' ) ) {
			$query_string = '?' . wp_parse_url( $permalink, PHP_URL_QUERY );
			$permalink    = current( explode( '?', $permalink ) );
		} else {
			$query_string = '';
		}
		$url = trailingslashit( $permalink ) . untrailingslashit( $endpoint );

		if ( $value ) {
			$url .= trailingslashit( $value );
		}

		$url .= $query_string;
	} else {
		$url = add_query_arg( $endpoint, $value, $permalink );
	}

	return apply_filters( 'memberchimp_get_endpoint_url', $url, $endpoint, $value, $permalink );
}

/**
 * Get current URL.
 */
function mcp_get_current_url() {
	global $wp;

	$url = home_url( add_query_arg( array(), $wp->request ) );

	return apply_filters( 'mcp_get_current_url', $url );
}

/**
 * Get current URL without query parameters.
 */
function mcp_get_current_url_clean() {
	$url = explode( '?', esc_url_raw( add_query_arg( array() ) ) );

	return apply_filters( 'mcp_get_current_url_clean', $url[0] );
}

/**
 * Get logout endpoint.
 */
function mcp_logout_url( $redirect = '' ) {
	return wp_logout_url( $redirect );
}

/**
 * Get default login URL.
 */
function mcp_login_url() {

	return apply_filters( 'mcp_login_url', mcp_get_page_permalink( 'login' ) );
}

/**
 * Get default register URL.
 */
function mcp_register_url() {

	return apply_filters( 'mcp_register_url', mcp_get_page_permalink( 'register' ) );
}

/**
 * Get default lostpassword URL.
 */
function mcp_lostpassword_url() {

	return apply_filters( 'mcp_lostpassword_url', mcp_get_page_permalink( 'lostpassword' ) );
}