<?php
/**
 * Template Functions
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Show or hide admin bar based on user cap.
 */
function memberchimp_show_admin_bar() {
	$admin_bar = false;
	if ( current_user_can( 'mcp_view_adminbar' ) ) {
		$admin_bar = true;
	}
	return apply_filters( 'memberchimp_show_admin_bar', $admin_bar );
}

/**
 * Handle redirects before content is output - hooked into template_redirect so is_page works.
 */
function mcp_template_redirect() {
	global $wp_query, $wp;

	if ( isset( $wp->query_vars[ 'logout' ] ) ) {

		// Logout.
		$redirect = ! empty( $_REQUEST[ 'redirect_to' ] ) ? esc_url_raw( $_REQUEST[ 'redirect_to' ] ) : mcp_get_page_permalink( 'account' );
		wp_safe_redirect( str_replace( '&amp;', '&', wp_logout_url( $redirect ) ) );
		exit;

	} elseif ( isset( $wp->query_vars[ 'logout' ] ) && 'true' === $wp->query_vars[ 'logout' ] ) {
		// Redirect to the correct logout endpoint.
		wp_safe_redirect( esc_url_raw( mcp_get_account_endpoint_url( 'logout' ) ) );
		exit;

	}
}

/**
 * Profile photo dropdown template.
 */
function memberchimp_user_photo_dropdown() {
	mcp_get_template( 'dropdown/photo.php' );
}

/**
 * Profile cover dropdown template.
 */
function memberchimp_user_cover_dropdown() {
	mcp_get_template( 'dropdown/cover.php' );
}

/**
 * User dropdown template.
 */
function memberchimp_user_dropdown_menu() {
	mcp_get_template( 'dropdown/user.php' );
}

/**
 * User actions dropdown template.
 */
function memberchimp_user_actions_dropdown() {
	mcp_get_template( 'dropdown/user-actions.php' );
}

/**
 * User admin dropdown template.
 */
function memberchimp_manage_user_dropdown() {
	mcp_get_template( 'dropdown/user-admin.php' );
}

/**
 * Profile header template.
 */
function memberchimp_profile_header() {
	mcp_get_template( 'profile/header.php' );
}

/**
 * Profile info template.
 */
function memberchimp_profile_info() {
	mcp_get_template( 'profile/info.php' );
}

/**
 * Profile side meta template.
 */
function memberchimp_profile_sidemeta() {
	mcp_get_template( 'profile/meta.php' );
}

/**
 * Profile bio template.
 */
function memberchimp_profile_bio() {
	global $the_user;

	mcp_get_template( 'profile/bio.php' );
}

/**
 * Profile username template.
 */
function memberchimp_profile_username() {
	mcp_get_template( 'profile/username.php' );
}

/**
 * Profile buttons template.
 */
function memberchimp_profile_buttons() {
	mcp_get_template( 'profile/buttons.php' );
}

/**
 * Profile photo template.
 */
function memberchimp_profile_photo() {
	mcp_get_template( 'profile/photo.php' );
}

/**
 * Profile cover template.
 */
function memberchimp_profile_cover() {
	global $the_form;

	if ( $the_form->hide_cover === 'yes' ) {
		return;
	}

	mcp_get_template( 'profile/cover.php' );
}

/**
 * Profile content output.
 */
function memberchimp_profile_content() {
	global $wp, $the_form, $the_user;

	// Hook before any profile content is displayed, probably for global notices.
	do_action( 'memberchimp_pre_profile_content' );

	if ( isset( $the_user->donotshow ) ) {
		return;
	}

	$tab = mcp_clean( get_query_var( 'mcp_tab' ) );
	if ( has_action( 'memberchimp_profile_' . $tab . '_endpoint' ) ) {
		do_action( 'memberchimp_profile_' . $tab . '_endpoint' );
		return;
	}

	// If we reached thus far, load a form.
	$form_id = mcp_get_profile_endpoint_form();
	if ( ! empty( $form_id ) ) {
		mcp_get_template( 'form/form.php', array(
			'atts'			=> array(
				'first_button' => esc_html__( 'Save changes', 'memberchimp' ),
			),
			'the_form'		=> ( isset( $the_form->id ) ) ? $the_form : mcp_get_form( $form_id ),
			'the_user' 		=> $the_user,
		) );
	}
}

/**
 * Profile admin menu template.
 */
function memberchimp_profile_admin_menu() {
	// Only show this if current user can edit users.
	if ( current_user_can( 'mcp_edit_users' ) ) {
		mcp_get_template( 'profile/admin.php' );
	}
}

/**
 * Profile user actions menu template.
 */
function memberchimp_profile_actions_menu() {
	mcp_get_template( 'profile/actions.php' );
}

/**
 * Profile nav template.
 */
function memberchimp_profile_nav() {
	mcp_get_template( 'profile/nav.php' );
}

/**
 * Profile nav items template.
 */
function memberchimp_profile_nav_items() {
	mcp_get_template( 'profile/nav-items.php' );
}

/**
 * Profile nav editing template.
 */
function memberchimp_profile_nav_editing() {
	mcp_get_template( 'profile/nav-editing.php' );
}

/**
 * Profile nav not editing template.
 */
function memberchimp_profile_nav_not_editing() {
	mcp_get_template( 'profile/nav-not-editing.php' );
}

/**
 * Display user posts tab.
 */
function memberchimp_profile_posts_endpoint() {
	global $the_user;

	$args = apply_filters( 'memberchimp_profile_posts_query_args', array(
		'author'         => $the_user->ID,
		'posts_per_page' => 10,
		'post_type'		 => 'post',
		'post_status'    => 'publish',
	) );

	$items = new WP_Query( $args );

	mcp_get_template( 'posts/posts.php', array( 'items' => $items ) );

	// Let's reset the WP Query.
	wp_reset_postdata();
}

/**
 * Display user comments tab.
 */
function memberchimp_profile_comments_endpoint() {
	global $the_user;

	$args = apply_filters( 'memberchimp_profile_comments_query_args', array(
		'user_id'        => $the_user->ID,
		'number' 		 => 10,
		'offset'		 => 0,
	) );

	$items = get_comments( $args );

	mcp_get_template( 'comments/comments.php', array( 'items' => $items ) );
}

/**
 * Include modals for user profile.
 */
function memberchimp_after_profile_template() {
	mcp_get_template( 'modals/view-image.php' );
	mcp_get_template( 'modals/photo.php' );
	mcp_get_template( 'modals/remove-photo.php' );
	mcp_get_template( 'modals/remove-cover.php' );
	mcp_get_template( 'modals/block-user.php' );
	mcp_get_template( 'modals/delete-user.php' );
	mcp_get_template( 'modals/error.php' );
}

/**
 * Display profile tabs.
 */
function memberchimp_profile_tabs() {
	mcp_get_template( 'profile/tabs.php' );
}

/**
 * Display notice if user has blocked profile.
 */
function memberchimp_show_if_blocked() {
	global $the_user;
	if ( isset( $the_user->donotshow ) ) {
		return;
	}

	// When the logged in user has blocked someone.
	if ( mcp_user_has_blocked( $the_user->user_id ) ) {
		mcp_get_template( 'global/blocked.php' );
		$the_user->donotshow = true;
	// When the profile owner has blocked current user.
	} else if ( mcp_user_has_blocked_me( $the_user->user_id ) ) {
		mcp_get_template( 'global/blocked-me.php' );
		$the_user->donotshow = true;
	}
}

/**
 * Display notice if current profile is private.
 */
function memberchimp_show_if_private() {
	global $the_user;
	if ( isset( $the_user->donotshow ) ) {
		return;
	}

	if ( get_current_user_id() != $the_user->user_id ) {
		if ( $the_user->is_private() && ! current_user_can( 'mcp_view_private' ) ) {
			mcp_get_template( 'global/private-profile.php' );
			$the_user->donotshow = true;
		}
	}
}

/**
 * Shows an icon next to username whose profile is private.
 */
function memberchimp_show_private_profile_icon() {
	global $the_user;

	if ( get_current_user_id() != $the_user->user_id ) {
		if ( $the_user->is_private() && ! current_user_can( 'mcp_view_private' ) ) {
			echo '<span class="memberchimp-profile-icon memberchimp-profile-is-private tips" data-tip="' . esc_html__( 'Private Account', 'memberchimp' ) . '">' . mcp_svg_icon( 'lock' ) . '</span>';
		}
	}
}

/**
 * Add profile nav buttons.
 */
function memberchimp_profile_nav_buttons() {
	?>
	<div class="memberchimp-nav-buttons">
		<?php do_action( 'memberchimp_profile_buttons' ); ?>
		<div class="memberchimp-action-menudrop-wrap">
			<?php do_action( 'memberchimp_profile_admin_menu' ); ?>
			<?php do_action( 'memberchimp_profile_actions_menu' ); ?>
		</div>
	</div>
	<?php
}

/**
 * Memberlist user actions.
 */
function memberchimp_memberlist_actions() {
	mcp_get_template( 'memberlist/actions.php' );
}

/**
 * Memberlist search bar template.
 */
function memberchimp_memberlist_search( $memberlist ) {
	global $the_memberlist;

	if ( $the_memberlist->search ) {
		mcp_get_template( 'memberlist/search.php', array( 'memberlist' => $memberlist ) );
	}
}

/**
 * Memberlist loop template.
 */
function memberchimp_memberlist_loop( $memberlist ) {
	mcp_get_template( 'memberlist/loop.php', array( 'memberlist' => $memberlist ) );
}

/**
 * Display memberlist pagination.
 */
function memberchimp_memberlist_pagination( $memberlist = array() ) {
	$page_links = paginate_links(
		apply_filters( 'mcp_memberlist_pagination_args', array(
			'base' 		=> add_query_arg( 'wpage', '%#%' ),
			'format' 	=> '',
			'prev_text' => sprintf( wp_kses_post( __( '%s Previous', 'memberchimp' ) ), mcp_svg_icon( 'chevron-left' ) ),
			'next_text' => sprintf( wp_kses_post( __( 'Next %s', 'memberchimp' ) ), mcp_svg_icon( 'chevron-right' ) ),
			'total' 	=> $memberlist[ 'pages' ],
			'current' 	=> $memberlist[ 'page' ],
		)
	) );

	// Current page can't be above the total pages number.
	if ( $memberlist[ 'page' ] > $memberlist[ 'pages' ] ) {
		return;
	}

	if ( apply_filters( 'memberchimp_memberlist_page_links', $page_links, $memberlist ) ) {
		mcp_get_template( 'memberlist/pagination.php', array( 'memberlist' => $memberlist, 'page_links' => $page_links ) );
	}
}

/**
 * Display this template when no users were found.
 */
function memberchimp_memberlist_no_users( $memberlist = array() ) {
	mcp_get_template( 'memberlist/no-users.php', array( 'memberlist' => $memberlist ) );
}

/**
 * Include modals for memberlist.
 */
function memberchimp_after_memberlist_template() {
	mcp_get_template( 'modals/block-user.php' );
	mcp_get_template( 'modals/delete-user.php' );
	mcp_get_template( 'modals/error.php' );
}

/**
 * Account nav template.
 */
function memberchimp_account_nav() {
	mcp_get_template( 'account/nav.php' );
}

/**
 * Account content output.
 */
function memberchimp_account_content() {
	global $wp, $the_form, $the_user;

	if ( ! empty( $wp->query_vars ) ) {
		foreach ( $wp->query_vars as $key => $value ) {
			// Ignore pagename param.
			if ( 'pagename' === $key ) {
				continue;
			}

			// Action hooks has the first priority.
			if ( has_action( 'memberchimp_account_' . $key . '_endpoint' ) ) {
				do_action( 'memberchimp_account_' . $key . '_endpoint', $value );
				return;
			}
		}
	}

	// If we do not have an action hook, load the respective form.
	$form_id = mcp_get_account_endpoint_form();

	if ( ! empty( $form_id ) ) {
		mcp_get_template( 'form/form.php', array(
			'atts'			=> array(
				'first_button' => esc_html__( 'Save changes', 'memberchimp' ),
			),
			'the_form'		=> ( isset( $the_form->id ) ) ? $the_form : mcp_get_form( $form_id ),
			'the_user' 		=> mcp_get_user( get_current_user_id() ),
		) );
	}
}

/**
 * Display the endpoint title above account content.
 */
function memberchimp_show_endpoint_title() {
	$endpoint       = mcp()->query->get_current_endpoint();
	if ( ! $endpoint ) {
		$endpoint = mcp_get_account_default_endpoint();
	}
	$endpoint_title = mcp()->query->get_endpoint_title( $endpoint );
	$endpoint_desc	= mcp()->query->get_endpoint_desc( $endpoint );
	?>
	<h3>
		<?php esc_html_e( $endpoint_title ); ?>
		<?php if ( ! empty( $endpoint_desc ) ) : ?>
		<span><?php echo esc_html( $endpoint_desc ); ?></span>
		<?php endif; ?>
	</h3>
	<?php
}

/**
 * Replace a page title with the endpoint title.
 */
function mcp_page_endpoint_title( $title ) {
	global $wp_query;

	// For title inside account endpoint.
	if ( ! is_null( $wp_query ) && ! is_admin() && is_main_query() && in_the_loop() && is_page() && is_mcp_endpoint_url() ) {
		$endpoint       = mcp()->query->get_current_endpoint();
		$endpoint_title = mcp()->query->get_endpoint_title( $endpoint );
		$title          = $endpoint_title ? $endpoint_title : $title;

		remove_filter( 'the_title', 'mcp_page_endpoint_title' );
	}

	// Remove 'profile' title from template.
	if ( ! is_null( $wp_query ) && ! is_admin() && is_main_query() && in_the_loop() && is_page() && is_mcp_profile_page() ) {
		$profile_id = mcp_get_active_profile_id();
		$user_data = get_userdata( $profile_id );
		$title = '@' . $user_data->user_login;

		remove_filter( 'the_title', 'mcp_page_endpoint_title' );
	}

	return $title;
}

/**
 * Replace browser title with the profile page title.
 */
function mcp_profile_page_title( $title_parts ) {
	global $wp_query;

	$user = esc_attr( get_query_var( 'mcp_user' ) );

	// Check if username exists in query and is not empty.
	if ( isset( $wp_query->query[ 'mcp_user'] ) && $wp_query->query[ 'mcp_user'] != '' ) {
		if ( $user_id = username_exists( $user ) ) {
			$the_user = mcp_get_user( $user_id );
			unset( $title_parts[ 'site' ] );
			$title_parts[ 'title' ] = $the_user->get( 'display_name' ) . ' (@' . $the_user->get( 'user_login' ) . ')';
		}
	}

	return $title_parts;
}

/**
 * Show meta counts for 3rd party integrations or addons.
 */
function mcp_show_meta_counts() {
	$meta_counts = apply_filters( 'memberchimp_profile_meta_counts', array() );
	
	if ( $meta_counts ) {
		echo '<div class="memberchimp-profile-meta mcp-extra-meta">';
		foreach( $meta_counts as $meta_count ) {
			echo wp_kses_post( $meta_count );
		}
		echo '</div>';
	}
}