<?php
/**
 * Upload Hooks.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

add_action( 'memberchimp_pre_avatar_update', 'memberchimp_pre_avatar_update', 10, 2 );
add_action( 'memberchimp_pre_cover_update', 'memberchimp_pre_cover_update', 10, 2 );

/**
 * Before updating an avatar.
 */
function memberchimp_pre_avatar_update( $user_id, $file ) {
	mcp_delete_user_avatar( $user_id );
}

/**
 * Before updating cover photo.
 */
function memberchimp_pre_cover_update( $user_id, $file ) {
	mcp_delete_user_cover( $user_id );
}

/**
 * Set avatar upload quality.
 */
function mcp_editor_set_avatar_quality( $quality, $mime ) {
	return 100;
}

/**
 * Set cover upload quality.
 */
function mcp_editor_set_cover_quality( $quality, $mime ) {
	return 75;
}

/**
 * Re-generate avatar filenames.
 */
function mcp_rename_avatar_thumbnails( $image ) {
	return mcp_rename_thumbnails( 'avatar', $image );
}

/**
 * Re-generate cover photo filenames.
 */
function mcp_rename_cover_thumbnails( $image ) {
	return mcp_rename_thumbnails( 'cover', $image );
}

/**
 * Re-generate filenames to replace the (-) with (_)
 */
function mcp_rename_thumbnails( $name = 'avatar', $image ) {
	$sizes = call_user_func( "mcp_get_{$name}_sizes" );

	foreach( $sizes as $width ) {
		$height = $width;
		if ( $name == 'cover' ) {
			$height = floor( $width / 2.70 );
		}
		if ( strstr( $image, "{$width}x{$height}" ) ) {
			$new_name = str_replace( "-{$width}x{$height}", "_{$width}x{$height}", $image );

			$did_it = rename( $image, $new_name );

			if ( $did_it )
				return $new_name;
		}
	}

	return $image;
}

/**
 * A filter for WP uploads to change upload destination.
 */
function mcp_upload_dir( $upload_dir ) {
	global $the_upload;

	$subdir = null;

	// Maybe add upload to plugin sub-directory.
	if ( isset( $the_upload->type ) && in_array( $the_upload->type, mcp_supported_upload_types() ) ) {
		$subdir = mcp_get_upload_folder( $the_upload->type );
	}

	$mcp_upload_dir = array(
		'path'   => $upload_dir['basedir'] . '/mcp_uploads' . $subdir,
		'url'    => $upload_dir['baseurl'] . '/mcp_uploads' . $subdir,
		'subdir' => '/mcp_uploads' . $subdir,
	) + $upload_dir;

	return $mcp_upload_dir;
}

/**
 * Fixes bug with some upload mimes. Should be used within plugin scope only.
 */
function mcp_check_filetype_and_ext( $data, $file, $filename, $mimes ) {
	global $the_upload;

	$filetype = wp_check_filetype( $filename, $mimes );

	// This code ensures that we can only upload safe listed files.
	$mimes = get_allowed_mime_types();
	if ( ! in_array( $filetype['type'], $mimes ) ) {
		return false;
	}

	// Image uploads, to allow only image uploads.
	if ( $the_upload->type == 'image' ) {
		$image_mimes = mcp_get_image_mimes();
		if ( ! in_array( $filetype['type'], $image_mimes ) ) {
			return false;
		}
	}

	// Should not allow images here.
	if ( $the_upload->type == 'file' ) {
		$image_mimes = mcp_get_image_mimes();
		if ( in_array( $filetype['type'], $image_mimes ) ) {
			return false;
		}
	}

	return [
		'ext'             => $filetype['ext'],
		'type'            => $filetype['type'],
		'proper_filename' => $data['proper_filename']
    ];
}