<?php
/**
 * Register
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * MCP_Shortcode_Form_Register class.
 */
class MCP_Shortcode_Form_Register {

	/**
	 * Output the shortcode.
	 */
	public static function output( $atts ) {
		global $the_form;

		// Fall back to defaults.
		if ( empty( $the_form->id ) ) {
			$default  = get_option( 'memberchimp_register_form' );
			$the_form = mcp_get_form( $default );
			if ( empty( $the_form->id ) ) {
				return;
			}
		}

		$atts = array_merge( array(
			'top_note'				=> '',
			'first_button'			=> esc_html__( 'Let&#39;s get started!', 'memberchimp' ),
			'second_button'			=> esc_html__( 'Got an account?', 'memberchimp' ),
		), (array) $atts );

		// Email unconfirmed.
		if ( ! empty( $_GET['checkmail'] ) ) {
			if ( isset( $_COOKIE[ 'wp-regconfirm-' . COOKIEHASH ] ) && 0 < strpos( $_COOKIE[ 'wp-regconfirm-' . COOKIEHASH ], ':' ) ) {
				list( $id, $login ) = array_map( 'mcp_clean', explode( ':', wp_unslash( $_COOKIE[ 'wp-regconfirm-' . COOKIEHASH ] ), 2 ) );
				$user_data = get_userdata( absint( $id ) );

				// Display account confirmation code template.
				if ( $user_data != false ) {
					ob_start();
					mcp_get_template( 'global/new-account-confirmation.php', array( 'user' => $user_data ) );
					return ob_end_flush();
				}
			}
		}

		// Pending review.
		if ( ! empty( $_GET[ 'pending' ] ) ) {
			ob_start();
			mcp_get_template( 'global/new-account-pending.php' );
			return ob_end_flush();
		}

		// Registration is disabled.
		if ( ! get_option( 'users_can_register' ) ) {
			ob_start();
			mcp_add_notice( esc_html__( 'Registration is currently disabled for this site.', 'memberchimp' ), 'notice' );
			mcp_print_notices();
			return ob_end_flush();
		}

		mcp_get_template( 'form/form.php', array( 'atts' => $atts ) );
	}

	/**
	 * Save.
	 */
	public static function save( $object = null ) {
		global $the_form;

		if ( $object ) {
			$the_form = $object;
		}

		$the_form->is_request = true;

		/**
		 * Form validation.
		 */
		$the_form->validate();

		/**
		 * No errors so far.
		 */
		if ( ! $the_form->has_errors() ) {
			$the_form->is_request = false;

			$user = mcp_create_user( $the_form->get_postdata() );

			if ( is_wp_error( $user ) ) {

				mcp_add_notice( esc_html__( 'We could not create your account. Please try again later.', 'memberchimp' ), 'error', 'global' );

			} else {

				// This is triggered after user creation.
				self::after_registration( $user );

			}
		}

	}

	/**
	 * This controls what action is taken after registering.
	 */
	public static function after_registration( $user ) {
		global $the_form, $the_role;

		$role_id = $user->get_role_id();

		if ( ! $role_id ) {
			$the_role = null;
		}

		$the_role = new MCP_Role( $role_id );

		/**
		 * Allow 3rd party plugins to hook custom process after registration.
		 */
		do_action( 'memberchimp_after_registration', $user );

		// Needs email confirmation.
		if ( $user->needs_email_confirmation() ) {
			$confirmation_code = $user->create_confirmation_code();

			if ( $confirmation_code ) {
				$user->save_registration( $the_form->get_postdata(), $the_form->id, $role_id, $the_form->password_generated );
			}

			$the_form->get_redirect( add_query_arg( array( 'checkmail' => 'true' ) ) );
		}

		// Needs manual approval.
		if ( $user->needs_manual_review() ) {
			$user->create_pending_user();

			$user->save_registration( $the_form->get_postdata(), $the_form->id, $role_id, $the_form->password_generated );

			$the_form->get_redirect( add_query_arg( array( 'pending' => 'true' ) ) );
		}

		// No action needed, login user and send a confirmation mail.
		if ( $user->is_auto_approved() ) {

			// Send an email.
			mcp()->mailer();
			do_action( 'memberchimp_new_user_notification', $user, $the_form->get_postdata(), $the_form, $the_role );

			// Login.
			$user->log_in();

			$the_form->get_redirect( mcp_get_register_redirect( $user ) );
		}

	}

}