<?php
/**
 * Profile Shortcodes
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * MCP_Shortcode_Profile class.
 */
class MCP_Shortcode_Profile {

	/**
	 * Get the shortcode content.
	 */
	public static function get( $atts ) {
		return MCP_Shortcodes::shortcode_wrapper( array( __CLASS__, 'output' ), $atts );
	}

	/**
	 * Output the shortcode.
	 */
	public static function output( $atts ) {
		
		if ( ! is_user_logged_in() && get_option( 'memberchimp_disable_public_profiles' ) == 'yes' ) {

			ob_start();

			if ( mcp_notice_count( 'error' ) == 0 ) {
				mcp_add_notice( esc_html__( 'Please log in to view this profile.', 'memberchimp' ), 'notice' );
			}

			// To force page refresh after login.
			mcp_form_set_redirect();

			return MCP_Shortcode_Form::output( array( 'id' => mcp_get_default_form_id( 'login' ) ) );

		} else {

			ob_start();

			self::profile( $atts );

			// Send output buffer.
			ob_end_flush();

		}
	}

	/**
	 * Profile page.
	 */
	private static function profile( $atts ) {
		global $the_user, $the_form;

		// Setup user and form ID.
		$the_user = mcp_get_user( mcp_get_active_profile_id() );
		$form_id  = mcp_get_profile_endpoint_form();
		if ( ! $form_id ) {
			$form_id = absint( get_option( 'memberchimp_profile_form_' . esc_attr( $the_user->get_role() ) ) );
			if ( ! $form_id ) {
				$form_id = mcp_get_default_form_id( 'profile' );
			}
		}
		$the_form = ( isset( $the_form->id ) ) ? $the_form : mcp_get_form( $form_id );

		// Attributes.
		$atts = array_merge( array(

		), (array) $atts );

		mcp_get_template(
			'profile/profile.php',
			array(
				'the_user' 			=> $the_user,
				'logged_user'		=> is_user_logged_in() ? mcp_get_user( get_current_user_id() ) : '',
			)
		);

		do_action( 'memberchimp_after_profile_template' );
	}

	/**
	 * Save.
	 */
	public static function save( $object = null ) {
		global $the_form;

		if ( $object ) {
			$the_form = $object;
		}

		if ( ! mcp_user_can_edit_profile() ) {
			return;
		}

		$the_form->is_request = true;

		/**
		 * Form validation.
		 */
		$the_form->validate();

		/**
		 * Show success message.
		 */
		if ( ! $the_form->has_errors() ) {
			mcp_update_profile( mcp_get_active_profile_id(), $the_form->get_postdata() );

			$the_form->is_request = false;
			$the_form->profile_redirect();
		}

	}

}